@@ -18,21 +18,32 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 5872 2006-02-03 15:49:59Z hippy $
+# $Id: __init__.py 9912 2008-01-22 09:17:46Z acraphae $
 
 """
 This package implements access to GRAMPS configuration.
 It provides the choice between different storage backends.
+
 """
 
-import const
-
 from _GrampsConfigKeys import *
+from _GrampsIniKeys import *
 
-if const.no_gconf:
-   from _GrampsIniKeys import *
-else:
-   try:
-      from _GrampsGconfKeys import *
-   except:
-      from _GrampsIniKeys import *
+import os
+
+def __upgrade_gconf():
+    import _GrampsGconfKeys as GconfKeys
+    print "Upgrading INI file"
+    for key in default_value.keys():
+        data = GconfKeys.get(key)
+        set(key, data)
+
+if not os.path.exists(INIFILE):
+    try:
+        __upgrade_gconf()
+    except ImportError:
+        print "Cannot upgrade GCONF settings"
+
+
+
+   
