@@ -9,7 +9,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# This program is distributed in the hope that it will be useful, 
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_es.py 6504 2006-05-01 21:11:26Z rshura $
+# $Id:_Date_es.py 9912 2008-01-22 09:17:46Z acraphae $
 
 """
 Spanish-specific classes for parsing and displaying dates.
@@ -37,7 +37,7 @@ import re
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from RelLib import Date
+from gen.lib import Date
 from _DateParser import DateParser
 from _DateDisplay import DateDisplay
 from _DateHandler import register_datehandler
@@ -54,57 +54,57 @@ class DateParserES(DateParser):
         u'antes'      : Date.MOD_BEFORE, 
         u'ant.'       : Date.MOD_BEFORE, 
         u'ant'        : Date.MOD_BEFORE, 
-        u'después de' : Date.MOD_AFTER,
-        u'después'    : Date.MOD_AFTER,
-        u'desp.'      : Date.MOD_AFTER,
-        u'desp'       : Date.MOD_AFTER,
-        u'aprox.'     : Date.MOD_ABOUT,
-        u'aprox'      : Date.MOD_ABOUT,
-        u'apr.'       : Date.MOD_ABOUT,
-        u'apr'        : Date.MOD_ABOUT,
-        u'circa'      : Date.MOD_ABOUT,
-        u'ca.'        : Date.MOD_ABOUT,
-        u'ca'         : Date.MOD_ABOUT,
-        u'c.'         : Date.MOD_ABOUT,
-        u'hacia'       : Date.MOD_ABOUT,
+        u'después de' : Date.MOD_AFTER, 
+        u'después'    : Date.MOD_AFTER, 
+        u'desp.'      : Date.MOD_AFTER, 
+        u'desp'       : Date.MOD_AFTER, 
+        u'aprox.'     : Date.MOD_ABOUT, 
+        u'aprox'      : Date.MOD_ABOUT, 
+        u'apr.'       : Date.MOD_ABOUT, 
+        u'apr'        : Date.MOD_ABOUT, 
+        u'circa'      : Date.MOD_ABOUT, 
+        u'ca.'        : Date.MOD_ABOUT, 
+        u'ca'         : Date.MOD_ABOUT, 
+        u'c.'         : Date.MOD_ABOUT, 
+        u'hacia'      : Date.MOD_ABOUT, 
         }
 
     calendar_to_int = {
-        u'gregoriano'     : Date.CAL_GREGORIAN,
-        u'g'                     : Date.CAL_GREGORIAN,
-        u'juliano'                : Date.CAL_JULIAN,
-        u'j'                     : Date.CAL_JULIAN,
-        u'hebreo'         : Date.CAL_HEBREW,
-        u'h'                     : Date.CAL_HEBREW,
-        u'islámico'             : Date.CAL_ISLAMIC,
-        u'i'                     : Date.CAL_ISLAMIC,
-        u'revolucionario': Date.CAL_FRENCH,
-        u'r'                     : Date.CAL_FRENCH,
-        u'persa'                 : Date.CAL_PERSIAN,
-        u'p'                     : Date.CAL_PERSIAN,
+        u'gregoriano'     : Date.CAL_GREGORIAN, 
+        u'g'              : Date.CAL_GREGORIAN, 
+        u'juliano'        : Date.CAL_JULIAN, 
+        u'j'              : Date.CAL_JULIAN, 
+        u'hebreo'         : Date.CAL_HEBREW, 
+        u'h'              : Date.CAL_HEBREW, 
+        u'islámico'       : Date.CAL_ISLAMIC, 
+        u'i'              : Date.CAL_ISLAMIC, 
+        u'revolucionario' : Date.CAL_FRENCH, 
+        u'r'              : Date.CAL_FRENCH, 
+        u'persa'          : Date.CAL_PERSIAN, 
+        u'p'              : Date.CAL_PERSIAN, 
         }
 
     quality_to_int = {
-        u'estimado'   : Date.QUAL_ESTIMATED,
-        u'est.'       : Date.QUAL_ESTIMATED,
-        u'est'        : Date.QUAL_ESTIMATED,
-        u'calc.'      : Date.QUAL_CALCULATED,
-        u'calc'       : Date.QUAL_CALCULATED,
-        u'calculado'  : Date.QUAL_CALCULATED,
+        u'estimado'   : Date.QUAL_ESTIMATED, 
+        u'est.'       : Date.QUAL_ESTIMATED, 
+        u'est'        : Date.QUAL_ESTIMATED, 
+        u'calc.'      : Date.QUAL_CALCULATED, 
+        u'calc'       : Date.QUAL_CALCULATED, 
+        u'calculado'  : Date.QUAL_CALCULATED, 
         }
 
     def init_strings(self):
         DateParser.init_strings(self)
         _span_1 = [u'de']
         _span_2 = [u'a']
-        _range_1 = [u'entre',u'ent\.',u'ent']
+        _range_1 = [u'entre', u'ent\.', u'ent']
         _range_2 = [u'y']
-        self._span     = re.compile("(%s)\s+(?P<start>.+)\s+(%s)\s+(?P<stop>.+)" % 
-                                   ('|'.join(_span_1),'|'.join(_span_2)),
-                           re.IGNORECASE)
-        self._range    = re.compile("(%s)\s+(?P<start>.+)\s+(%s)\s+(?P<stop>.+)" %
-                                   ('|'.join(_range_1),'|'.join(_range_2)),
-                           re.IGNORECASE)
+        self._span  = re.compile("(%s)\s+(?P<start>.+)\s+(%s)\s+(?P<stop>.+)" % 
+                                 ('|'.join(_span_1), '|'.join(_span_2)), 
+                                 re.IGNORECASE)
+        self._range = re.compile("(%s)\s+(?P<start>.+)\s+(%s)\s+(?P<stop>.+)" %
+                                 ('|'.join(_range_1), '|'.join(_range_2)), 
+                                 re.IGNORECASE)
 
 #-------------------------------------------------------------------------
 #
@@ -118,18 +118,18 @@ class DateDisplayES(DateDisplay):
         u" (Revolucionario)", u" (Persa)", u" (Islámico)"
         )
 
-    _mod_str = ("",u"antes de ",u"después de ",u"hacia ","","","")
+    _mod_str = ("", u"antes de ", u"después de ", u"hacia ", "", "", "")
 
-    _qual_str = ("","estimado ","calculado ")
+    _qual_str = ("", "estimado ", "calculado ")
 
     formats = (
-        "AAAA-MM-DD (ISO)", "Numérica", "Mes Día, Año",
+        "AAAA-MM-DD (ISO)", "Numérica", "Mes Día, Año", 
         "MES Día, Año", "Día Mes, Año", "Día MES, Año"
         )
     
-    def display(self,date):
+    def display(self, date):
         """
-        Returns a text string representing the date.
+        Return a text string representing the date.
         """
         mod = date.get_modifier()
         cal = date.get_calendar()
@@ -145,18 +145,18 @@ class DateDisplayES(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str,u'de',d1,u'a',d2,self.calendar[cal])
+            return "%s%s %s %s %s%s" % (qual_str, u'de', d1, u'a', d2, self.calendar[cal])
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str,u'entre',d1,u'y',d2,self.calendar[cal])
+            return "%s%s %s %s %s%s" % (qual_str, u'entre', d1, u'y', d2, self.calendar[cal])
         else:
             text = self.display_cal[date.get_calendar()](start)
-            return "%s%s%s%s" % (qual_str,self._mod_str[mod],text,self.calendar[cal])
+            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, self.calendar[cal])
 
 #-------------------------------------------------------------------------
 #
 # Register classes
 #
 #-------------------------------------------------------------------------
-register_datehandler(('es_ES','es','spanish'),DateParserES, DateDisplayES)
+register_datehandler(('es_ES', 'es', 'spanish'), DateParserES, DateDisplayES)
