@@ -9,7 +9,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# This program is distributed in the hope that it will be useful, 
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -19,10 +19,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_nb.py 2007-05-10 13:37:16Z espenbe $
+# $Id: _Date_nb.py 10103 2008-02-24 13:55:55Z acraphae $
 
 """
-Nowegian-specific classes for parsing and displaying dates.
+Norwegian-specific classes for parsing and displaying dates.
 """
 
 #-------------------------------------------------------------------------
@@ -37,7 +37,7 @@ import re
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from RelLib import Date
+from gen.lib import Date
 from _DateParser import DateParser
 from _DateDisplay import DateDisplay
 from _DateHandler import register_datehandler
@@ -49,59 +49,54 @@ from _DateHandler import register_datehandler
 #-------------------------------------------------------------------------
 class DateParserNb(DateParser):
     """
-    Converts a text string into a Date object, expecting a date
-    notation in the swedish language. If the date cannot be converted,
+    Convert a text string into a Date object, expecting a date
+    notation in the Norwegian language. If the date cannot be converted, 
     the text string is assigned.
     """
 
     # modifiers before the date
     modifier_to_int = {
-        u'før'    : Date.MOD_BEFORE,
-        u'innen'   : Date.MOD_BEFORE,
-        u'etter'   : Date.MOD_AFTER,
-        u'omkring' : Date.MOD_ABOUT,
-        u'ca'      : Date.MOD_ABOUT,
-        u'ca'     : Date.MOD_ABOUT
+        u'før'    : Date.MOD_BEFORE, 
+        u'innen'  : Date.MOD_BEFORE, 
+        u'etter'   : Date.MOD_AFTER, 
+        u'omkring' : Date.MOD_ABOUT, 
+        u'ca'      : Date.MOD_ABOUT
         }
 
     bce = ["f Kr"]
 
     calendar_to_int = {
-        u'gregoriansk   '      : Date.CAL_GREGORIAN,
-        u'g'                   : Date.CAL_GREGORIAN,
-        u'juliansk'            : Date.CAL_JULIAN,
-        u'j'                   : Date.CAL_JULIAN,
-        u'hebraisk'            : Date.CAL_HEBREW,
-        u'h'                   : Date.CAL_HEBREW,
-        u'islamisk'            : Date.CAL_ISLAMIC,
-        u'muslimsk'            : Date.CAL_ISLAMIC,
-        u'i'                   : Date.CAL_ISLAMIC,
-        u'fransk'              : Date.CAL_FRENCH,
-        u'fransk republikansk' : Date.CAL_FRENCH,
-        u'f'                   : Date.CAL_FRENCH,
-        u'persisk'             : Date.CAL_PERSIAN,
-        u'p'                   : Date.CAL_PERSIAN,
+        u'gregoriansk   '      : Date.CAL_GREGORIAN, 
+        u'g'                   : Date.CAL_GREGORIAN, 
+        u'juliansk'            : Date.CAL_JULIAN, 
+        u'j'                   : Date.CAL_JULIAN, 
+        u'hebraisk'            : Date.CAL_HEBREW, 
+        u'h'                   : Date.CAL_HEBREW, 
+        u'islamisk'            : Date.CAL_ISLAMIC, 
+        u'muslimsk'            : Date.CAL_ISLAMIC, 
+        u'i'                   : Date.CAL_ISLAMIC, 
+        u'fransk'              : Date.CAL_FRENCH, 
+        u'fransk republikansk' : Date.CAL_FRENCH, 
+        u'f'                   : Date.CAL_FRENCH, 
+        u'persisk'             : Date.CAL_PERSIAN, 
+        u'p'                   : Date.CAL_PERSIAN, 
         }
     
     quality_to_int = {
-        u'estimert' : Date.QUAL_ESTIMATED,
-        u'estimert' : Date.QUAL_ESTIMATED,
-        u'antatt'     : Date.QUAL_ESTIMATED,
-        u'antatt'     : Date.QUAL_ESTIMATED,
-        u'beregnet'   : Date.QUAL_CALCULATED,
-        u'beregnet'   : Date.QUAL_CALCULATED,
+        u'estimert' : Date.QUAL_ESTIMATED, 
+        u'beregnet'   : Date.QUAL_CALCULATED, 
         }
     
     def init_strings(self):
         DateParser.init_strings(self)
-        self._span     = re.compile(u"(fra)?\s*(?P<start>.+)\s*(til|--|–)\s*(?P<stop>.+)",
+        self._span     = re.compile(u"(fra)?\s*(?P<start>.+)\s*(til|--|–)\s*(?P<stop>.+)", 
                                     re.IGNORECASE)
-        self._range    = re.compile(u"(mellom)\s+(?P<start>.+)\s+og\s+(?P<stop>.+)",
+        self._range    = re.compile(u"(mellom)\s+(?P<start>.+)\s+og\s+(?P<stop>.+)", 
                                     re.IGNORECASE)
 
 #-------------------------------------------------------------------------
 #
-# Swedish display class
+# Norwegian display class
 #
 #-------------------------------------------------------------------------
 class DateDisplayNb(DateDisplay):
@@ -110,32 +105,32 @@ class DateDisplayNb(DateDisplay):
     """
 
     formats = (
-        u"YYYY-MM-DD (ISO)",
-        u"Numerisk",
-        u"Måned dag, år",
-        u"MND DAG ÅR",
-        u"Dag måned år",
-        u"DAG MND ÅR",
+        u"ÅÅÅÅ-MM-DD (ISO)", 
+        u"Numerisk", 
+        u"Måned dag, år", 
+        u"Mån Dag År", 
+        u"Dag måned år", 
+        u"Dag Mån År", 
         )
 
     calendar = (
-        "",
-        " (juliansk)",
-        " (hebraisk)",
-        " (fransk republikansk)",
-        " (persisk)",
+        "", 
+        " (juliansk)", 
+        " (hebraisk)", 
+        " (fransk republikansk)", 
+        " (persisk)", 
         " (islamisk)"
         )
     
-    _mod_str = ("",u"før ",u"etter ",u"ca ","","","")
+    _mod_str = ("", u"før ", u"etter ", u"ca ", "", "", "")
 
-    _qual_str = ("",u"estimert ",u"beregnet ")
+    _qual_str = ("", u"beregnet ", u"beregnet ")
     
     _bce_str = "%s f Kr"
 
-    def display(self,date):
+    def display(self, date):
         """
-        Returns a text string representing the date.
+        Return a text string representing the date.
         """
         mod = date.get_modifier()
         cal = date.get_calendar()
@@ -151,21 +146,20 @@ class DateDisplayNb(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return u"%sfra %s til %s%s" % (qual_str,d1,d2,self.calendar[cal])
+            return u"%sfra %s til %s%s" % (qual_str, d1, d2, self.calendar[cal])
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return u"%smellom %s og %s%s" % (qual_str,d1,d2,
+            return u"%smellom %s og %s%s" % (qual_str, d1, d2, 
                                               self.calendar[cal])
         else:
             text = self.display_cal[date.get_calendar()](start)
-            return u"%s%s%s%s" % (qual_str,self._mod_str[mod],
-                                 text,self.calendar[cal])
+            return u"%s%s%s%s" % (qual_str, self._mod_str[mod], 
+                                 text, self.calendar[cal])
 
 #-------------------------------------------------------------------------
 #
 # Register classes
 #
 #-------------------------------------------------------------------------
-register_datehandler(('nb_NO','nb','norsk'),DateParserNb, DateDisplayNb)
-
+register_datehandler(('nb_NO', 'nb', 'norsk'), DateParserNb, DateDisplayNb)
