@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,15 +18,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _PeopleModel.py 7946 2007-01-21 05:17:06Z dallingham $
+# $Id: _PeopleModel.py 10103 2008-02-24 13:55:55Z acraphae $
 
 """
 TreeModel for the GRAMPS Person tree.
 """
 
-__author__ = "Donald N. Allingham"
-__revision__ = "$Revision: 7946 $"
-
 #-------------------------------------------------------------------------
 #
 # Standard python modules
@@ -35,7 +32,6 @@ __revision__ = "$Revision: 7946 $"
 from gettext import gettext as _
 import time
 import cgi
-import sys
 import locale
 
 #-------------------------------------------------------------------------
@@ -59,41 +55,157 @@ import gtk
 #
 #-------------------------------------------------------------------------
 import const
-from RelLib import *
-import NameDisplay
+from gen.lib import Name, EventRef, EventType, EventRoleType, MarkerType
+from BasicUtils import name_displayer
 import DateHandler
 import ToolTips
 import GrampsLocale
 import Config
+from gen.utils.longop import LongOpStatus
 from Filters import SearchFilter, ExactSearchFilter
 from Lru import LRU
 
 _CACHE_SIZE = 250
 
-#-------------------------------------------------------------------------
-#
-# python 2.3 has a bug in the unicode sorting using locale.strcoll. Seems
-# to have a buffer overrun. We can convince it to do the right thing by
-# forcing the string to be nul terminated, sorting, then stripping off the
-# nul.
-#
-#-------------------------------------------------------------------------
+def locale_sort(mylist):
+    """
+    Normal sort routine
+    """
+    l = [ (locale.strxfrm(x),x) for x in mylist ]
+    l.sort()
+    return [ x[1] for x in l ]
 
-if sys.version_info[0:2] == (2, 3):
-    def locale_sort(mylist):
-        """
-        Sort version to get around a python2.3 bug with unicode strings
-        """
-        mylist = [ value + "\x00" for value in mylist ]
-        mylist.sort(locale.strcoll)
-        return [ value[:-1] for value in mylist ]
-else:
-    def locale_sort(mylist):
-        """
-        Normal sort routine
-        """
-        mylist.sort(locale.strcoll)
-        return mylist
+class NodeTreeMap:
+
+    def __init__(self):
+
+        self.sortnames = {}
+        self.temp_top_path2iter = []
+
+        self.iter2path = {}
+        self.path2iter = {}
+        self.sname_sub = {}
+
+        self.temp_iter2path = {}
+        self.temp_path2iter = {}
+        self.temp_sname_sub = {}
+
+    def clear_sort_names(self):
+        self.sortnames = {}
+
+    def clear_temp_data(self):
+        self.temp_iter2path = {}
+        self.temp_path2iter = {}
+        self.temp_sname_sub = {}
+
+    def build_toplevel(self):
+        self.temp_top_path2iter = locale_sort(self.temp_sname_sub.keys())
+        for name in self.temp_top_path2iter:
+            self.build_sub_entry(name)
+
+    def get_group_names(self):
+        return self.temp_top_path2iter
+
+    def assign_sort_name(self, handle, sorted_name, group_name):
+        self.sortnames[handle] = sorted_name
+        try:
+            self.temp_sname_sub[group_name].append(handle)
+        except:
+            self.temp_sname_sub[group_name] = [handle]
+
+    def assign_data(self):
+        self.top_path2iter = self.temp_top_path2iter
+        self.iter2path = self.temp_iter2path
+        self.path2iter = self.temp_path2iter
+        self.sname_sub = self.temp_sname_sub
+        self.top_iter2path = {}
+        i = 0
+        for item in self.top_path2iter:
+            self.top_iter2path[item] = i
+            i+=1
+
+    def get_path(self, node):
+        try:
+            return (self.top_iter2path[node], )
+        except:
+            (surname, index) = self.iter2path[node]
+            return (self.top_iter2path[surname], index)
+
+    def has_entry(self, handle):
+        return self.iter2path.has_key(handle)
+
+    def get_iter(self, path):
+        try:
+            if len(path)==1: # Top Level
+                return self.top_path2iter[path[0]]
+            else: # Sublevel
+                surname = self.top_path2iter[path[0]]
+                return self.path2iter[(surname, path[1])]
+        except:
+            return None
+        
+    def has_top_node(self, node):
+        return self.sname_sub.has_key(node)
+
+    def find_next_node(self, node):
+        try:
+            path = self.top_iter2path[node]
+            if path+1 == len(self.top_path2iter):
+                return None
+            return self.top_path2iter[path+1]
+        except:
+            (surname, val) = self.iter2path[node]
+            return self.path2iter.get((surname, val+1))
+
+    def first_child(self, node):
+        if node == None:
+            return self.top_path2iter[0]
+        else:
+            return self.path2iter.get((node, 0))
+
+    def has_child(self, node):
+        if node == None:
+            return len(self.sname_sub)
+        if self.sname_sub.has_key(node) and len(self.sname_sub[node]) > 0:
+            return True
+        return False
+
+    def number_of_children(self, node):
+        if node == None:
+            return len(self.sname_sub)
+        try:
+            return len(self.sname_sub[node])
+        except:
+            return 0
+
+    def get_nth_child(self, node, n):
+        try:
+            if node == None:
+                return self.top_path2iter[n]
+            try:
+                return self.path2iter[(node, n)]
+            except:
+                return None
+        except IndexError:
+            return None
+
+    def get_parent_of(self, node):
+        path = self.iter2path.get(node)
+        if path:
+            return path[0]
+        return None
+
+    def build_sub_entry(self, name):
+        slist = [ (locale.strxfrm(self.sortnames[x]), x) \
+                  for x in self.temp_sname_sub[name] ]
+        slist.sort()
+
+        val = 0
+        for (junk, person_handle) in slist:
+            tpl = (name, val)
+            self.temp_iter2path[person_handle] = tpl
+            self.temp_path2iter[tpl] = person_handle
+            val += 1
 
 #-------------------------------------------------------------------------
 #
@@ -122,7 +234,6 @@ class PeopleModel(gtk.GenericTreeModel):
     _CHANGE_COL = 17
     _MARKER_COL = 18
 
-
     _GENDER = [ _(u'female'), _(u'male'), _(u'unknown') ]
 
     # dynamic calculation of column indices, for use by various Views
@@ -140,7 +251,7 @@ class PeopleModel(gtk.GenericTreeModel):
         gtk.GenericTreeModel.__init__(self)
 
         self.db = db
-	self.in_build = False
+        self.in_build = False
 
         Config.client.notify_add("/apps/gramps/preferences/todo-color",
                                  self.update_todo)
@@ -153,13 +264,13 @@ class PeopleModel(gtk.GenericTreeModel):
         self.todo_color = Config.get(Config.TODO_COLOR)
         self.custom_color = Config.get(Config.CUSTOM_MARKER_COLOR)
 
-        self.sortnames = {}
         self.marker_color_column = 10
         self.tooltip_column = 11
-        self.temp_top_path2iter = []
-        self.iter2path = {}
-        self.path2iter = {}
-        self.sname_sub = {}
+
+        self.mapper = NodeTreeMap()
+
+        self.total = 0
+        self.displayed = 0
 
         if filter_info and filter_info != (1, (0, u'', False)):
             if filter_info[0] == PeopleModel.GENERIC:
@@ -204,74 +315,93 @@ class PeopleModel(gtk.GenericTreeModel):
         self.current_filter = data_filter
         
     def _build_search_sub(self,dfilter, skip):
-        self.sortnames = {}
 
-        ngn = NameDisplay.displayer.name_grouping_data
-        nsn = NameDisplay.displayer.raw_sorted_name
+        ngn = name_displayer.name_grouping_data
+        nsn = name_displayer.raw_sorted_name
+
+        self.mapper.clear_sort_names()
 
         cursor = self.db.get_person_cursor()
         node = cursor.first()
 
+        self.total = 0
+        self.displayed = 0
+
         while node:
+            self.total += 1
             handle, d = node
-            if not (handle in skip or (dfilter and not dfilter.match(handle))):
+            if not (handle in skip or (dfilter and not dfilter.match(handle,self.db))):
                 name_data = d[PeopleModel._NAME_COL]
-                sn = ngn(self.db, name_data)
-                self.sortnames[handle] = nsn(name_data)
-                try:
-                    self.temp_sname_sub[sn].append(handle)
-                except:
-                    self.temp_sname_sub[sn] = [handle]
+
+                group_name = ngn(self.db, name_data)
+                sorted_name = nsn(name_data)
+                self.displayed += 1
+                self.mapper.assign_sort_name(handle, sorted_name, group_name)
             node = cursor.next()
         cursor.close()
 
     def _build_filter_sub(self,dfilter, skip):
-        self.sortnames = {}
 
-        ngn = NameDisplay.displayer.name_grouping_data
-        nsn = NameDisplay.displayer.raw_sorted_name
+        ngn = name_displayer.name_grouping_data
+        nsn = name_displayer.raw_sorted_name
+
+        plist = self.db.get_person_handles()
+
+        self.total = len(plist)
 
         if dfilter:
             handle_list = dfilter.apply(self.db, self.db.get_person_handles())
         else:
             handle_list = self.db.get_person_handles()
 
+        self.displayed = len(handle_list)
+
+        self.mapper.clear_sort_names()
+
+        status = LongOpStatus(msg="Loading People",
+                              total_steps=len(handle_list),
+                              interval=len(handle_list)/10)
+        self.db.emit('long-op-start', (status,))
+        
         for handle in handle_list:
+            status.heartbeat()
             d = self.db.get_raw_person_data(handle)
-            if not (handle in skip or (dfilter and not dfilter.match(handle))):
+            if not handle in skip:
                 name_data = d[PeopleModel._NAME_COL]
-                sn = ngn(self.db, name_data)
-                self.sortnames[handle] = nsn(name_data)
-                try:
-                    self.temp_sname_sub[sn].append(handle)
-                except:
-                    self.temp_sname_sub[sn] = [handle]
+
+                group_name = ngn(self.db, name_data)
+                sorted_name = nsn(name_data)
+
+                self.mapper.assign_sort_name(handle, sorted_name, group_name)
+        
+        status.end()
         
     def calculate_data(self, dfilter=None, skip=[]):
         """
-        Calculates the new path to node values for the model.
+        Calculate the new path to node values for the model.
         """
-	self.in_build  = True
+        self.in_build  = True
         self.lru_data  = LRU(_CACHE_SIZE)
         self.lru_name  = LRU(_CACHE_SIZE)
         self.lru_bdate = LRU(_CACHE_SIZE)
         self.lru_ddate = LRU(_CACHE_SIZE)
 
+        self.total = 0
+        self.displayed = 0
+
         if dfilter:
             self.dfilter = dfilter
-        self.temp_iter2path = {}
-        self.temp_path2iter = {}
-        self.temp_sname_sub = {}
+            
+        self.mapper.clear_temp_data()
 
         if not self.db.is_open():
             return
 
         self._build_data(dfilter, skip)
 
-        self.temp_top_path2iter = locale_sort(self.temp_sname_sub.keys())
-        for name in self.temp_top_path2iter:
-            self.build_sub_entry(name)
-	self.in_build  = False
+        self.mapper.build_toplevel()
+
+        self.in_build  = False
 
     def clear_cache(self):
         self.lru_data  = LRU(_CACHE_SIZE)
@@ -280,63 +410,35 @@ class PeopleModel(gtk.GenericTreeModel):
         self.lru_ddate = LRU(_CACHE_SIZE)
 
     def build_sub_entry(self, name):
-        slist = [ (locale.strxfrm(self.sortnames[x]), x) \
-                  for x in self.temp_sname_sub[name] ]
-        slist.sort()
-
-        val = 0
-        for (junk, person_handle) in slist:
-            tpl = (name, val)
-            self.temp_iter2path[person_handle] = tpl
-            self.temp_path2iter[tpl] = person_handle
-            val += 1
+        self.mapper.build_sub_entry(name)
 
     def assign_data(self):
-        self.top_path2iter = self.temp_top_path2iter
-        self.iter2path = self.temp_iter2path
-        self.path2iter = self.temp_path2iter
-        self.sname_sub = self.temp_sname_sub
-        self.top_iter2path = {}
-        i = 0
-        for item in self.top_path2iter:
-            self.top_iter2path[item] = i
-            i+=1
+        self.mapper.assign_data()
 
     def on_get_flags(self):
-        '''returns the GtkTreeModelFlags for this particular type of model'''
+        """returns the GtkTreeModelFlags for this particular type of model"""
         return gtk.TREE_MODEL_ITERS_PERSIST
 
     def on_get_n_columns(self):
         return len(PeopleModel.COLUMN_DEFS)
 
     def on_get_path(self,  node):
-        '''returns the tree path (a tuple of indices at the various
-        levels) for a particular node.'''
-        try:
-            return (self.top_iter2path[node], )
-        except:
-            (surname, index) = self.iter2path[node]
-            return (self.top_iter2path[surname], index)
+        """returns the tree path (a tuple of indices at the various
+        levels) for a particular node."""
+        return self.mapper.get_path(node)
 
     def is_visable(self, handle):
-        return self.iter2path.has_key(handle)
+        return self.mapper.has_entry(handle)
 
     def on_get_column_type(self, index):
         return PeopleModel.COLUMN_DEFS[index][PeopleModel.COLUMN_DEF_TYPE]
 
     def on_get_iter(self, path):
-        try:
-            if len(path)==1: # Top Level
-                return self.top_path2iter[path[0]]
-            else: # Sublevel
-                surname = self.top_path2iter[path[0]]
-                return self.path2iter[(surname, path[1])]
-        except:
-            return None
+        return self.mapper.get_iter(path)
 
     def on_get_value(self, node, col):
         # test for header or data row-type
-        if self.sname_sub.has_key(node):
+        if self.mapper.has_top_node(node):
             # Header rows dont get the foreground color set
             if col == self.marker_color_column:
                 return None
@@ -355,69 +457,38 @@ class PeopleModel(gtk.GenericTreeModel):
                     data = self.lru_data[node]
                 except:
                     data = self.db.get_raw_person_data(str(node))
-		    if not self.in_build:
-			self.lru_data[node] = data
-                return PeopleModel.COLUMN_DEFS[col][PeopleModel.COLUMN_DEF_LIST](self,
-                                                                                 data, node)
+                    if not self.in_build:
+                        self.lru_data[node] = data
+                return PeopleModel.COLUMN_DEFS[col][PeopleModel.COLUMN_DEF_LIST](self, data, node)
             except:
                 return None
 
     def on_iter_next(self,  node):
-        '''returns the next node at this level of the tree'''
-        try:
-            path = self.top_iter2path[node]
-            if path+1 == len(self.top_path2iter):
-                return None
-            return self.top_path2iter[path+1]
-        except:
-            (surname, val) = self.iter2path[node]
-            return self.path2iter.get((surname, val+1))
+        """returns the next node at this level of the tree"""
+        return self.mapper.find_next_node(node)
 
     def on_iter_children(self, node):
         """Return the first child of the node"""
-        if node == None:
-            return self.top_path2iter[0]
-        else:
-            return self.path2iter.get((node, 0))
+        return self.mapper.first_child(node)
 
     def on_iter_has_child(self, node):
-        '''returns true if this node has children'''
-        if node == None:
-            return len(self.sname_sub)
-        if self.sname_sub.has_key(node) and len(self.sname_sub[node]) > 0:
-            return True
-        return False
+        """returns true if this node has children"""
+        return self.mapper.has_child(node)
 
     def on_iter_n_children(self, node):
-        if node == None:
-            return len(self.sname_sub)
-        try:
-            return len(self.sname_sub[node])
-        except:
-            return 0
+        return self.mapper.number_of_children(node)
 
     def on_iter_nth_child(self, node, n):
-        try:
-            if node == None:
-                return self.top_path2iter[n]
-            try:
-                return self.path2iter[(node, n)]
-            except:
-                return None
-        except IndexError:
-            return None
+        return self.mapper.get_nth_child(node, n)
 
     def on_iter_parent(self, node):
-        '''returns the parent of this node'''
-        path = self.iter2path.get(node)
-        if path:
-            return path[0]
-        return None
+        """returns the parent of this node"""
+        return self.mapper.get_parent_of(node)
 
     def column_sort_name(self, data, node):
         n = Name()
         n.unserialize(data[PeopleModel._NAME_COL])
-        return NameDisplay.displayer.sort_string(n)
+        return name_displayer.sort_string(n)
 
     def column_spouse(self, data, node):
         spouses_names = u""
@@ -433,16 +504,16 @@ class PeopleModel(gtk.GenericTreeModel):
                 spouse = self.db.get_person_from_handle(spouse_id)
                 if len(spouses_names) > 0:
                     spouses_names += ", "
-                spouses_names += NameDisplay.displayer.display(spouse)
+                spouses_names += name_displayer.display(spouse)
         return spouses_names
 
     def column_name(self, data, node):
-	try:
-	    name = self.lru_name[node]
-	except:
-	    name = NameDisplay.displayer.raw_sorted_name(data[PeopleModel._NAME_COL])
-	    if not self.in_build:
-		self.lru_name[node] = name
+        try:
+            name = self.lru_name[node]
+        except:
+            name = name_displayer.raw_sorted_name(data[PeopleModel._NAME_COL])
+            if not self.in_build:
+                self.lru_name[node] = name
         return name
 
     def column_id(self, data, node):
@@ -458,12 +529,12 @@ class PeopleModel(gtk.GenericTreeModel):
         return PeopleModel._GENDER[data[PeopleModel._GENDER_COL]]
 
     def column_birth_day(self, data, node):
-	try:
-	    value = self.lru_bdate[node]
-	except:
-	    value = self._get_birth_data(data,node)
-	    if not self.in_build:
-		self.lru_bdate[node] = value
+        try:
+            value = self.lru_bdate[node]
+        except:
+            value = self._get_birth_data(data, node)
+            if not self.in_build:
+                self.lru_bdate[node] = value
         return value
 
     def _get_birth_data(self, data, node):
@@ -489,17 +560,17 @@ class PeopleModel(gtk.GenericTreeModel):
             if (etype in [EventType.BAPTISM, EventType.CHRISTEN]
                 and er.get_role() == EventRoleType.PRIMARY
                 and date_str != ""):
-                return "<i>" + cgi.escape(date_str) + "</i>"
+                return "<i>%s</i>" % cgi.escape(date_str)
         
         return u""
 
     def column_death_day(self, data, node):
-	try:
-	    value = self.lru_ddate[node]
-	except:
-	    value = self._get_death_data(data,node)
-	    if not self.in_build:
-		self.lru_ddate[node] = value
+        try:
+            value = self.lru_ddate[node]
+        except:
+            value = self._get_death_data(data, node)
+            if not self.in_build:
+                self.lru_ddate[node] = value
         return value
 
     def _get_death_data(self, data, node):
@@ -524,8 +595,8 @@ class PeopleModel(gtk.GenericTreeModel):
             date_str = DateHandler.get_date(event)
             if (etype in [EventType.BURIAL, EventType.CREMATION]
                 and er.get_role() == EventRoleType.PRIMARY
-                and date_str != ""):
-                return "<i>" + cgi.escape(date_str) + "</i>"
+                and date_str):
+                return "<i>%s</i>" % cgi.escape(date_str)
         
         return u""
 
@@ -542,7 +613,7 @@ class PeopleModel(gtk.GenericTreeModel):
                     if place_handle:
                         place = self.db.get_place_from_handle(place_handle)
                         place_title = place.get_title()
-                        if place_title != "":
+                        if place_title:
                             return cgi.escape(place_title)
             except:
                 return u''
@@ -558,8 +629,8 @@ class PeopleModel(gtk.GenericTreeModel):
                 if place_handle:
                     place = self.db.get_place_from_handle(place_handle)
                     place_title = place.get_title()
-                    if place_title != "":
-                        return "<i>" + cgi.escape(place_title) + "</i>"
+                    if place_title:
+                        return "<i>%s</i>" % cgi.escape(place_title)
         
         return u""
 
@@ -576,7 +647,7 @@ class PeopleModel(gtk.GenericTreeModel):
                     if place_handle:
                         place = self.db.get_place_from_handle(place_handle)
                         place_title = place.get_title()
-                        if place_title != "":
+                        if place_title:
                             return cgi.escape(place_title)
             except:
                 return u''
@@ -619,7 +690,7 @@ class PeopleModel(gtk.GenericTreeModel):
         return None
 
     def column_tooltip(self, data, node):
-        if const.use_tips:
+        if const.USE_TIPS:
             return ToolTips.TipFromFunction(
                 self.db,
                 lambda: self.db.get_person_from_handle(data[0])
@@ -627,7 +698,6 @@ class PeopleModel(gtk.GenericTreeModel):
         else:
             return u''
         
-
     def column_int_id(self, data, node):
         return node
 
