@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _BackRefList.py 9505 2007-12-14 14:06:18Z bmcage $
+# $Id: _BackRefList.py 10103 2008-02-24 13:55:55Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -54,14 +54,14 @@ class BackRefList(EmbeddedList):
 
     _column_names = [
         (_('Type'), 0, 100),
-        (_('ID'),  1,  75), 
-        (_('Name'), 2, 250), 
+        (_('ID'),  1,  75),
+        (_('Name'), 2, 250),
         ]
     
     def __init__(self, dbstate, uistate, track, obj, refmodel, callback=None):
         self.obj = obj
         EmbeddedList.__init__(self, dbstate, uistate, track, 
-                              _('References'), refmodel)
+                              _('_References'), refmodel)
         self._callback = callback
         self.model.connect('row-inserted', self.update_label)
 
@@ -80,7 +80,12 @@ class BackRefList(EmbeddedList):
     def is_empty(self):
         return self.model.count == 0
 
-    def create_buttons(self, share=False):
+    def create_buttons(self, share=False, move=False, jump=False):
+        """
+        Create a button box consisting of one button: Edit. 
+        This button box is then appended hbox (self).
+        Method has signature of, and overrides create_buttons from _ButtonTab.py
+        """
         self.edit_btn = SimpleButton(gtk.STOCK_EDIT, self.edit_button_clicked)
         self.tooltips = gtk.Tooltips()
         self.tooltips.set_tip(self.edit_btn, _('Edit reference'))
@@ -90,8 +95,13 @@ class BackRefList(EmbeddedList):
         vbox.pack_start(self.edit_btn, False)
         vbox.show_all()
         self.pack_start(vbox, False)
+        
+        self.add_btn = None
+        self.del_btn = None
 
     def _selection_changed(self, obj=None):
+        if self.dirty_selection:
+            return
         if self.get_selected():
             self.edit_btn.set_sensitive(True)
         else:
