@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _GalleryTab.py 9235 2007-10-22 20:38:29Z bmcage $
+# $Id: _GalleryTab.py 10103 2008-02-24 13:55:55Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -28,7 +28,6 @@
 from gettext import gettext as _
 import cPickle as pickle
 import urlparse
-import os
 
 #-------------------------------------------------------------------------
 #
@@ -37,19 +36,21 @@ import os
 #-------------------------------------------------------------------------
 import gtk
 import pango
+import os
+import gobject
 
 #-------------------------------------------------------------------------
 #
 # GRAMPS classes
 #
 #-------------------------------------------------------------------------
-import RelLib
+import gen.lib
 import Utils
-import ImgManip
+import ThumbNails
 import Errors
 import Mime
 from DdTargets import DdTargets
-from _ButtonTab import ButtonTab
+from DisplayTabs._ButtonTab import ButtonTab
 
 #-------------------------------------------------------------------------
 #
@@ -70,7 +71,9 @@ class GalleryTab(ButtonTab):
     _DND_EXTRA  = DdTargets.URI_LIST
 
     def __init__(self, dbstate, uistate, track,  media_list, update=None):
-        ButtonTab.__init__(self, dbstate, uistate, track, _('Gallery'), True)
+        self.iconlist = gtk.IconView()
+        
+        ButtonTab.__init__(self, dbstate, uistate, track, _('_Gallery'), True)
         self.media_list = media_list
         self.update = update
 
@@ -87,21 +90,24 @@ class GalleryTab(ButtonTab):
 
     def double_click(self, obj, event):
         """
-        Handles the double click on list. If the double click occurs, 
-        the Edit button handler is called
+        Handle the button press event: double click or right click on iconlist. 
+        If the double click occurs, the Edit button handler is called.
         """
         if event.type == gtk.gdk._2BUTTON_PRESS and event.button == 1:
             self.edit_button_clicked(obj)
+            return True
         elif event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
             reflist = self.iconlist.get_selected_items()
             if len(reflist) == 1:
                 ref = self.media_list[reflist[0][0]]
                 self.right_click(ref, event)
+                return True
+        return
 
     def right_click(self, obj, event):
         itemlist = [
             (True, True, gtk.STOCK_ADD, self.add_button_clicked), 
-            (True, False, _('Share'), self.edit_button_clicked), 
+            (True, False, _('Share'), self.share_button_clicked), 
             (False,True, gtk.STOCK_EDIT, self.edit_button_clicked), 
             (True, True, gtk.STOCK_REMOVE, self.del_button_clicked), 
             ]
@@ -114,8 +120,9 @@ class GalleryTab(ButtonTab):
             app = Mime.get_application(mime_type)
             if app:
                 item = gtk.MenuItem(_('Open with %s') % app[1])
-                item.connect('activate', make_launcher(app[0], 
-                                                      ref_obj.get_path()))
+                item.connect('activate', make_launcher(app[0],
+                                    Utils.media_path_full(self.dbstate.db, 
+                                                          ref_obj.get_path())))
                 item.show()
                 menu.append(item)
                 item = gtk.SeparatorMenuItem()
@@ -141,7 +148,8 @@ class GalleryTab(ButtonTab):
         return len(self.media_list)==0
 
     def _build_icon_model(self):
-        self.iconmodel= gtk.ListStore(gtk.gdk.Pixbuf, str, object)
+        self.iconmodel = gtk.ListStore(gtk.gdk.Pixbuf, gobject.TYPE_STRING, 
+                                      object)
 
     def _connect_icon_model(self):
         self.iconlist.set_model(self.iconmodel)
@@ -160,7 +168,6 @@ class GalleryTab(ButtonTab):
         self._build_icon_model()
         
         # build the icon view
-        self.iconlist = gtk.IconView()
         self.iconlist.set_pixbuf_column(0)
         # set custom text cell renderer for better control
         text_renderer = gtk.CellRendererText()
@@ -168,20 +175,21 @@ class GalleryTab(ButtonTab):
         text_renderer.set_property('yalign', 0.0)
         text_renderer.set_property('wrap-mode', pango.WRAP_WORD_CHAR)
         text_renderer.set_property('wrap-width', item_width)
+        text_renderer.set_property('alignment', pango.ALIGN_CENTER)
         self.iconlist.pack_end(text_renderer)
         self.iconlist.set_attributes(text_renderer, text=1)
         
         # set basic properties of the icon view
         self.iconlist.set_margin(12)
-        self.iconlist.set_spacing(24)        
+        self.iconlist.set_spacing(24)
+        self.iconlist.set_reorderable(True)
         self.iconlist.set_item_width(item_width)
         self.iconlist.set_selection_mode(gtk.SELECTION_SINGLE)
-        if gtk.pygtk_version >= (2, 8, 0):
-            self.iconlist.set_reorderable(True)
         
         # connect the signals
         self.iconlist.connect('selection-changed', self._selection_changed)
         self.iconlist.connect('button_press_event', self.double_click)
+        self.iconlist.connect('key_press_event', self.key_pressed)
         self._connect_icon_model()
         
         # create the scrolled window
@@ -220,10 +228,13 @@ class GalleryTab(ButtonTab):
                 #notify user of error
                 from QuestionDialog import RunDatabaseRepair
                 RunDatabaseRepair(
-                            _('Unexisting media found in the Gallery'))
+                            _('Non existing media found in the Gallery'))
             else :
-                pixbuf = ImgManip.get_thumbnail_image(obj.get_path(), 
-                                                  obj.get_mime_type())
+                pixbuf = ThumbNails.get_thumbnail_image(
+                                Utils.media_path_full(self.dbstate.db, 
+                                                      obj.get_path()), 
+                                obj.get_mime_type(),
+                                ref.get_rectangle())
                 self.iconmodel.append(row=[pixbuf, obj.get_description(), ref])
         self._connect_icon_model()
         self._set_label()
@@ -238,21 +249,13 @@ class GalleryTab(ButtonTab):
         return None
 
     def add_button_clicked(self, obj):
-        import AddMedia
-
-        am = AddMedia.AddMediaObject(self.dbstate, self.uistate, self.track)
-        am.run()
-        src = am.object
-
-        if src:
-            sref = RelLib.MediaRef()
-            try:
-                from Editors import EditMediaRef
-                
-                EditMediaRef(self.dbstate, self.uistate, self.track, 
-                             src, sref, self.add_callback)
-            except Errors.WindowActiveError:
-                pass
+        try:
+            from Editors import EditMediaRef
+            EditMediaRef(self.dbstate, self.uistate, self.track, 
+                         gen.lib.MediaObject(), gen.lib.MediaRef(),
+                         self.add_callback)
+        except Errors.WindowActiveError:
+            pass
 
     def add_callback(self, media_ref, media):
         media_ref.ref = media.handle
@@ -262,19 +265,20 @@ class GalleryTab(ButtonTab):
 
     def share_button_clicked(self, obj):
         """
-        Function called with the Add button is clicked. This function
-        should be overridden by the derived class.
+        Function called when the Add button is clicked. 
+        
+        This function should be overridden by the derived class.
+        
         """
         from Selectors import selector_factory
         SelectObject = selector_factory('MediaObject')
 
-        sel = SelectObject(self.dbstate,self.uistate,self.track)
+        sel = SelectObject(self.dbstate, self.uistate, self.track)
         src = sel.run()
         if src:
-            sref = RelLib.MediaRef()
+            sref = gen.lib.MediaRef()
             try:
                 from Editors import EditMediaRef
-                
                 EditMediaRef(self.dbstate, self.uistate, self.track, 
                              src, sref, self.add_callback)
             except Errors.WindowActiveError:
@@ -289,10 +293,10 @@ class GalleryTab(ButtonTab):
     def edit_button_clicked(self, obj):
         ref = self.get_selected()
         if ref:
-            obj = self.dbstate.db.get_object_from_handle(ref.get_reference_handle())
+            obj = self.dbstate.db.get_object_from_handle(
+                                                ref.get_reference_handle())
             try:
                 from Editors import EditMediaRef
-                
                 EditMediaRef(self.dbstate, self.uistate, self.track, 
                              obj, ref, None)
             except Errors.WindowActiveError:
@@ -322,7 +326,7 @@ class GalleryTab(ButtonTab):
                     rebuild = True
         if rebuild:
             self.rebuild()
-    
+
     def media_update(self, upd_media_handle_list):
         """
         Outside of this tab media objects have been changed. Check if tab
@@ -336,7 +340,7 @@ class GalleryTab(ButtonTab):
 
     def _set_dnd(self):
         """
-        Sets up drag-n-drop. The source and destionation are set by calling .target()
+        Set up drag-n-drop. The source and destionation are set by calling .target()
         on the _DND_TYPE. Obviously, this means that there must be a _DND_TYPE
         variable defined that points to an entry in DdTargets.
         """
@@ -378,7 +382,8 @@ class GalleryTab(ButtonTab):
                 return
             
             # pickle the data, and build the tuple to be passed
-            value = (self._DND_TYPE.drag_type, id(self), obj, self.find_index(obj))
+            value = (self._DND_TYPE.drag_type, id(self), obj, 
+                     self.find_index(obj))
             data = pickle.dumps(value)
 
             # pass as a string (8 bits)
@@ -401,7 +406,7 @@ class GalleryTab(ButtonTab):
                 if mytype == self._DND_TYPE.drag_type:
                     
                     # determine the destination row
-                    data = self.iconlist.get_dest_item_at_pos(x,y)
+                    data = self.iconlist.get_dest_item_at_pos(x, y)
                     if data:
                         (path, pos) = data
                         row = path[0]
@@ -424,7 +429,7 @@ class GalleryTab(ButtonTab):
                         self._handle_drag(row, obj)
                     self.rebuild()
                 elif mytype == DdTargets.MEDIAOBJ.drag_type:
-                    oref = RelLib.MediaRef()
+                    oref = gen.lib.MediaRef()
                     oref.set_reference_handle(obj)
                     self.get_data().append(oref)
                     self.changed = True
@@ -433,21 +438,21 @@ class GalleryTab(ButtonTab):
                     self.handle_extra_type(mytype, obj)
             except pickle.UnpicklingError:
                 d = Utils.fix_encoding(sel_data.data.replace('\0',' ').strip())
-                protocol,site,mfile,j,k,l = urlparse.urlparse(d)
+                protocol, site, mfile, j, k, l = urlparse.urlparse(d)
                 if protocol == "file":
                     name = Utils.fix_encoding(mfile)
                     mime = Mime.get_type(name)
                     if not Mime.is_valid_type(mime):
                         return
-                    photo = RelLib.MediaObject()
+                    photo = gen.lib.MediaObject()
                     photo.set_path(name)
                     photo.set_mime_type(mime)
                     basename = os.path.basename(name)
-                    (root,ext) = os.path.splitext(basename)
+                    (root, ext) = os.path.splitext(basename)
                     photo.set_description(root)
                     trans = self.dbstate.db.transaction_begin()
                     self.dbstate.db.add_object(photo, trans)
-                    oref = RelLib.MediaRef()
+                    oref = gen.lib.MediaRef()
                     oref.set_reference_handle(photo.get_handle())
                     self.get_data().append(oref)
                     self.changed = True
@@ -459,21 +464,21 @@ class GalleryTab(ButtonTab):
 #                     import urllib
 #                     u = urllib.URLopener()
 #                     try:
-#                         tfile,headers = u.retrieve(d)
+#                         tfile, headers = u.retrieve(d)
 #                     except (IOError,OSError), msg:
 #                         t = _("Could not import %s") % d
 #                         ErrorDialog(t,str(msg))
 #                         return
 #                     tfile = Utils.fix_encoding(tfile)
 #                     mime = GrampsMime.get_type(tfile)
-#                     photo = RelLib.MediaObject()
+#                     photo = gen.lib.MediaObject()
 #                     photo.set_mime_type(mime)
 #                     photo.set_description(d)
 #                     photo.set_path(tfile)
 #                     trans = self.db.transaction_begin()
 #                     self.db.add_object(photo,trans)
 #                     self.db.transaction_commit(trans,_("Drag Media Object"))
-#                     oref = RelLib.MediaRef()
+#                     oref = gen.lib.MediaRef()
 #                     oref.set_reference_handle(photo.get_handle())
 #                     self.dataobj.add_media_reference(oref)
 #                     self.add_thumbnail(oref)
