@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _SourceEmbedList.py 7951 2007-01-22 03:56:23Z dallingham $
+# $Id: _SourceEmbedList.py 10108 2008-02-24 18:58:45Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -32,7 +32,7 @@ from gettext import gettext as _
 # GRAMPS classes
 #
 #-------------------------------------------------------------------------
-import RelLib
+import gen.lib
 import Errors
 from DdTargets import DdTargets
 from _SourceRefModel import SourceRefModel
@@ -54,6 +54,8 @@ class SourceEmbedList(EmbeddedList):
         'del'   : _('Remove the existing source'),
         'edit'  : _('Edit the selected source'),
         'share' : _('Add an existing source'),
+        'up'    : _('Move the selected source upwards'),
+        'down'  : _('Move the selected source downwards'),
         }
 
     _column_names = [
@@ -65,8 +67,9 @@ class SourceEmbedList(EmbeddedList):
     
     def __init__(self, dbstate, uistate, track, obj):
         self.obj = obj
-        EmbeddedList.__init__(self, dbstate, uistate, track, 
-                              _('Sources'), SourceRefModel, True)
+        EmbeddedList.__init__(self, dbstate, uistate, track, _('_Sources'), 
+                              SourceRefModel, share_button=True, 
+                              move_buttons=True)
 
     def get_icon_name(self):
         return 'gramps-source'
@@ -81,8 +84,8 @@ class SourceEmbedList(EmbeddedList):
         try:
             from Editors import EditSourceRef
             
-            sref = RelLib.SourceRef()
-            src = RelLib.Source()
+            sref = gen.lib.SourceRef()
+            src = gen.lib.Source()
             EditSourceRef(
                 self.dbstate,
                 self.uistate,
@@ -103,7 +106,7 @@ class SourceEmbedList(EmbeddedList):
             try:
                 from Editors import EditSourceRef
                 
-                ref = RelLib.SourceRef()
+                ref = gen.lib.SourceRef()
                 EditSourceRef(self.dbstate,
                               self.uistate,
                               self.track, 
@@ -146,7 +149,7 @@ class SourceEmbedList(EmbeddedList):
         self.rebuild()
 
     def handle_extra_type(self, objtype, obj):
-        sref = RelLib.SourceRef()
+        sref = gen.lib.SourceRef()
         src = self.dbstate.db.get_source_from_handle(obj)
         try:
             from Editors import EditSourceRef
