@@ -18,21 +18,17 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditFamily.py 9511 2007-12-15 21:55:08Z gburto01 $
-
-"""
-Family Editor dialog
-"""
+# $Id: _EditFamily.py 10108 2008-02-24 18:58:45Z acraphae $
 
 #-------------------------------------------------------------------------
 #
 # python modules
 #
 #-------------------------------------------------------------------------
+from bsddb import db as bsddb_db
 from gettext import gettext as _
-import cPickle as pickle
-from bsddb import db
-
+from DdTargets import DdTargets
+import pickle
 #-------------------------------------------------------------------------
 #
 # enable logging for error handling
@@ -47,33 +43,41 @@ log = logging.getLogger(".")
 #
 #-------------------------------------------------------------------------
 import gtk
+from gtk import glade
+from gtk import gdk
 
 #-------------------------------------------------------------------------
 #
 # gramps modules
 #
 #-------------------------------------------------------------------------
-import const
 import Utils
-import NameDisplay
-import RelLib
+import const
 import Config
+from BasicUtils import name_displayer
+import gen.lib
 import Errors
+import DateHandler
 
-from _EditPrimary import EditPrimary
+from Editors import EditPrimary
 from ReportBase import ReportUtils
-from DdTargets import DdTargets
-from DisplayTabs import \
-     EmbeddedList,EventEmbedList,SourceEmbedList,FamilyAttrEmbedList,\
-     NoteTab,GalleryTab,FamilyLdsEmbedList, ChildModel
-from GrampsWidgets import *
-import QuestionDialog
-
-#from ObjectSelector import PersonSelector,PersonFilterSpec
+from DisplayTabs import (EmbeddedList, EventEmbedList, SourceEmbedList, 
+                         FamilyAttrEmbedList, NoteTab, GalleryTab, 
+                         FamilyLdsEmbedList, ChildModel)
+from GrampsWidgets import (PrivacyButton, MonitoredEntry, MonitoredDataType, 
+                           IconButton, LinkBox, BasicLabel)
+from ReportBase import CATEGORY_QR_FAMILY
+from QuestionDialog import (ErrorDialog, RunDatabaseRepair, WarningDialog,
+                            MessageHideDialog)
 
 from Selectors import selector_factory
 SelectPerson = selector_factory('Person')
 
+_RETURN = gdk.keyval_from_name("Return")
+_KP_ENTER = gdk.keyval_from_name("KP_Enter")
+_LEFT_BUTTON = 1
+_RIGHT_BUTTON = 3
+
 class ChildEmbedList(EmbeddedList):
     """
     The child embed list is specific to the Edit Family dialog, so it
@@ -86,8 +90,10 @@ class ChildEmbedList(EmbeddedList):
     _MSG = {
         'add'   : _('Create a new person and add the child to the family'),
         'del'   : _('Remove the child from the family'),
-        'edit'  : _('Edit the child/family relationship'),
+        'edit'  : _('Edit the child reference'),
         'share' : _('Add an existing person as a child of the family'),
+        'up'	: _('Move the child up in the childrens list'),
+        'down'	: _('Move the child down in the childrens list'),
         }
 
     _column_names = [
@@ -108,21 +114,24 @@ class ChildEmbedList(EmbeddedList):
         Create the object, storing the passed family value
         """
         self.family = family
-        EmbeddedList.__init__(self, dbstate, uistate, track,
-                              _('Children'), ChildModel, True)
+        EmbeddedList.__init__(self, dbstate, uistate, track, _('_Children'), 
+                              ChildModel, share_button=True, move_buttons=True)
 
     def get_popup_menu_items(self):
-        """
-        Creates the data for the popup menu
-        """
         return [
+            (False, True,  (gtk.STOCK_EDIT, _('Edit child')), 
+                                            self.edit_child_button_clicked),
             (True, True, gtk.STOCK_ADD, self.add_button_clicked),
-            (True, False, _('Share'), self.edit_button_clicked),
-            (False,True,  _('Edit relationship'), self.edit_button_clicked),
-            (False,True,  _('Edit child'), self.edit_child_button_clicked),
+            (True, False, _('Add an existing child'), 
+                                            self.share_button_clicked),
+            (False, True,  (gtk.STOCK_EDIT, _('Edit relationship')), 
+                                            self.edit_button_clicked),
             (True, True, gtk.STOCK_REMOVE, self.del_button_clicked),
             ]
 
+    def get_middle_click(self):
+        return self.edit_child_button_clicked
+
     def find_index(self, obj):
         """
         returns the index of the object within the associated data
@@ -130,11 +139,8 @@ class ChildEmbedList(EmbeddedList):
         reflist = [ref.ref for ref in self.family.get_child_ref_list()]
         return reflist.index(obj)
 
-    def _find_row(self, x_loc, y_loc):
-        """
-        Find the row from x/y coordinates
-        """
-        row = self.tree.get_path_at_pos(x_loc, y_loc)
+    def _find_row(self, x, y):
+        row = self.tree.get_path_at_pos(x, y)
         if row == None:
             return len(self.family.get_child_ref_list())
         else:
@@ -172,7 +178,7 @@ class ChildEmbedList(EmbeddedList):
                 continue
             name = self._column_names[pair[1]][0]
             render = gtk.CellRendererText()
-            column = gtk.TreeViewColumn(name, render, text=pair[1])
+            column = gtk.TreeViewColumn(name, render, markup=pair[1])
             column.set_min_width(50)
 
             column.set_resizable(True)
@@ -197,14 +203,17 @@ class ChildEmbedList(EmbeddedList):
         return self.family
 
     def column_order(self):
-        return [(1, 0), (1, 1), (1, 2), (1, 3), (1, 4), (1, 5), 
-                (1, 6), (0, 8), (0, 9)]
+        return [(1, 0), (1, 1), (1, 2), (1, 3), (1, 4), (1, 5), (1, 6), 
+                (0, 8), (0, 9)]
 
     def add_button_clicked(self, obj):
         from Editors import EditPerson
-
-        person = RelLib.Person()
+        person = gen.lib.Person()
         autoname = Config.get(Config.SURNAME_GUESSING)
+        #_("Father's surname"), 
+        #_("None"), 
+        #_("Combination of mother's and father's surname"), 
+        #_("Icelandic style"), 
         if autoname == 0:
             name = self.north_american()
         elif autoname == 2:
@@ -218,17 +227,17 @@ class ChildEmbedList(EmbeddedList):
                    self.new_child_added)
 
     def new_child_added(self, person):
-        ref = RelLib.ChildRef()
+        ref = gen.lib.ChildRef()
         ref.ref = person.get_handle()
         self.family.add_child_ref(ref)
         self.rebuild()
+        self.call_edit_childref(ref.ref)
 
     def child_ref_edited(self, person):
         self.rebuild()
 
     def share_button_clicked(self, obj):
         # it only makes sense to skip those who are already in the family
-        
         skip_list = [self.family.get_father_handle(), \
                      self.family.get_mother_handle()] + \
                     [x.ref for x in self.family.get_child_ref_list() ]
@@ -238,10 +247,11 @@ class ChildEmbedList(EmbeddedList):
         person = sel.run()
         
         if person:
-            ref = RelLib.ChildRef()
+            ref = gen.lib.ChildRef()
             ref.ref = person.get_handle()
             self.family.add_child_ref(ref)
             self.rebuild()
+            self.call_edit_childref(ref.ref)
 
     def run(self, skip):
         skip_list = [ x for x in skip if x]
@@ -259,18 +269,21 @@ class ChildEmbedList(EmbeddedList):
     def edit_button_clicked(self, obj):
         handle = self.get_selected()
         if handle:
-            from Editors import EditChildRef
+            self.call_edit_childref(handle)
 
-            for ref in self.family.get_child_ref_list():
-                if ref.ref == handle:
-                    p = self.dbstate.db.get_person_from_handle(handle)
-                    n = NameDisplay.displayer.display(p)
-                    try:
-                        EditChildRef(n, self.dbstate, self.uistate, self.track,
-                                     ref, self.child_ref_edited)
-                    except Errors.WindowActiveError, msg:
-                        pass
-                    break
+    def call_edit_childref(self, handle):
+        from Editors import EditChildRef
+
+        for ref in self.family.get_child_ref_list():
+            if ref.ref == handle:
+                p = self.dbstate.db.get_person_from_handle(handle)
+                n = name_displayer.display(p)
+                try:
+                    EditChildRef(n, self.dbstate, self.uistate, self.track,
+                                 ref, self.child_ref_edited)
+                except Errors.WindowActiveError:
+                    pass
+                break
 
     def edit_child_button_clicked(self, obj):
         handle = self.get_selected()
@@ -279,13 +292,30 @@ class ChildEmbedList(EmbeddedList):
 
             for ref in self.family.get_child_ref_list():
                 if ref.ref == handle:
+                    p = self.dbstate.db.get_person_from_handle(handle)
                     try:
-                        person = self.dbstate.db.get_person_from_handle(handle)
                         EditPerson(self.dbstate, self.uistate, self.track,
-                                   person, self.child_ref_edited)
+                               p, self.child_ref_edited)
                     except Errors.WindowActiveError:
-                        continue
+                        pass
                     break
+    
+    def up_button_clicked(self, obj):
+        handle = self.get_selected()
+        if handle:
+            pos = self.find_index(handle)
+            if pos > 0 :
+                self._move_up(pos,self.family.get_child_ref_list()[pos], 
+                              selmethod=self.family.get_child_ref_list)
+                
+    def down_button_clicked(self, obj):
+        ref = self.get_selected()
+        if ref:
+            pos = self.find_index(ref)
+            if pos >=0 and pos < len(self.family.get_child_ref_list())-1:
+                self._move_down(pos,self.family.get_child_ref_list()[pos], 
+                                selmethod=self.family.get_child_ref_list)
+    
 
     def drag_data_received(self, widget, context, x, y, sel_data, info, time):
         """
@@ -311,7 +341,7 @@ class ChildEmbedList(EmbeddedList):
                     self._move(row_from, row, obj)
                 else:
                     handle = obj
-                    obj = RelLib.ChildRef()
+                    obj = gen.lib.ChildRef()
                     obj.ref = handle
                     self._handle_drag(row, obj)
                 self.rebuild()
@@ -324,23 +354,23 @@ class ChildEmbedList(EmbeddedList):
             father = self.dbstate.db.get_person_from_handle(father_handle)
             pname = father.get_primary_name()
             return (pname.get_surname_prefix(), pname.get_surname())
-        return ("", "")
+        return ("","")
 
     def no_name(self):
-        return ("", "")
+        return ("","")
 
     def latin_american(self):
         if self.family:
             father_handle = self.family.get_father_handle()
             mother_handle = self.family.get_mother_handle()
             if not father_handle or not mother_handle:
-                return ("", "")
+                return ("","")
             father = self.dbstate.db.get_person_from_handle(father_handle)
             mother = self.dbstate.db.get_person_from_handle(mother_handle)
+            if not father or not mother:
+                return ("","")
             fsn = father.get_primary_name().get_surname()
             msn = mother.get_primary_name().get_surname()
-            if not father or not mother:
-                return ("", "")
             try:
                 return ("", "%s %s" % (fsn.split()[0], msn.split()[0]))
             except:
@@ -353,18 +383,18 @@ class FastMaleFilter:
     def __init__(self, db):
         self.db = db
 
-    def match(self, handle):
+    def match(self, handle, db):
         value = self.db.get_raw_person_data(handle)
-        return value[2] == RelLib.Person.MALE
+        return value[2] == gen.lib.Person.MALE
 
 class FastFemaleFilter:
 
     def __init__(self, db):
         self.db = db
 
-    def match(self, handle):
+    def match(self, handle, db):
         value = self.db.get_raw_person_data(handle)
-        return value[2] == RelLib.Person.FEMALE
+        return value[2] == gen.lib.Person.FEMALE
 
 #-------------------------------------------------------------------------
 #
@@ -373,11 +403,14 @@ class FastFemaleFilter:
 #-------------------------------------------------------------------------
 class EditFamily(EditPrimary):
 
+    QR_CATEGORY = CATEGORY_QR_FAMILY
+    
     def __init__(self, dbstate, uistate, track, family):
         
         self.tooltips = gtk.Tooltips()
         EditPrimary.__init__(self, dbstate, uistate, track,
-                             family, dbstate.db.get_family_from_handle)
+                             family, dbstate.db.get_family_from_handle,
+                             dbstate.db.get_family_from_gramps_id)
 
         # look for the scenerio of a child and no parents on a new
         # family
@@ -390,7 +423,7 @@ class EditFamily(EditPrimary):
                 for i in self.hidden:
                     i.set_sensitive(False)
 
-                QuestionDialog.MessageHideDialog(
+                MessageHideDialog(
                     _("Adding parents to a person"),
                     _("It is possible to accidentally create multiple "
                       "families with the same parents. To help avoid "
@@ -403,7 +436,7 @@ class EditFamily(EditPrimary):
             self.add_parent = False
 
     def empty_object(self):
-        return RelLib.Family()
+        return gen.lib.Family()
 
     def _local_init(self):
         self.build_interface()
@@ -413,6 +446,9 @@ class EditFamily(EditPrimary):
 
         self._add_db_signal('family-update', self.check_for_family_change)
         self._add_db_signal('family-delete', self.check_for_close)
+
+        # Add a signal pick up changes to events, bug #1329
+        self._add_db_signal('event-update', self.event_updated)
         
         self.added = self.obj.handle == None
         if self.added:
@@ -427,10 +463,9 @@ class EditFamily(EditPrimary):
     def check_for_family_change(self, handles):
 
         # check to see if the handle matches the current object
-        hndl = self.obj.get_handle()
-        if hndl in handles:
+        if self.obj.get_handle() in handles:
 
-            self.obj = self.dbstate.db.get_family_from_handle(hndl)
+            self.obj = self.dbstate.db.get_family_from_handle(self.obj.get_handle())
             self.reload_people()
             self.event_embed.rebuild()
             self.source_embed.rebuild()
@@ -439,12 +474,15 @@ class EditFamily(EditPrimary):
             self.lds_embed.data = self.obj.get_lds_ord_list()
             self.lds_embed.rebuild()
 
-            QuestionDialog.WarningDialog(
+            WarningDialog(
                 _("Family has changed"),
                 _("The family you are editing has changed. To make sure that the "
                   "database is not corrupted, GRAMPS has updated the family to "
                   "reflect these changes. Any edits you have made may have been lost."))
 
+    def event_updated(self, obj):
+        self.load_data()
+
     def reload_people(self):
         fhandle = self.obj.get_father_handle()
         self.update_father(fhandle)
@@ -466,7 +504,7 @@ class EditFamily(EditPrimary):
 
     def build_interface(self):
 
-        self.top = gtk.glade.XML(const.gladeFile, "family_editor", "gramps")
+        self.top = glade.XML(const.GLADE_FILE, "family_editor", "gramps")
 
         self.set_window(self.top.get_widget("family_editor"), None, self.get_menu_title())
 
@@ -475,15 +513,19 @@ class EditFamily(EditPrimary):
         height = Config.get(Config.FAMILY_HEIGHT)
         self.window.set_default_size(width, height)
 
-        self.fbirth = self.top.get_widget('fbirth')
-        self.fdeath = self.top.get_widget('fdeath')
+        self.fbirth  = self.top.get_widget('fbirth')
+        self.fdeath  = self.top.get_widget('fdeath')
+        self.fbirth_label = self.top.get_widget('label578')
+        self.fdeath_label = self.top.get_widget('label579')
         
-        self.mbirth = self.top.get_widget('mbirth')
-        self.mdeath = self.top.get_widget('mdeath')
+        self.mbirth  = self.top.get_widget('mbirth')
+        self.mdeath  = self.top.get_widget('mdeath')
+        self.mbirth_label = self.top.get_widget('label567')
+        self.mdeath_label = self.top.get_widget('label568')
 
-        self.mbutton  = self.top.get_widget('mbutton')
+        self.mbutton = self.top.get_widget('mbutton')
         self.mbutton2 = self.top.get_widget('mbutton2')
-        self.fbutton  = self.top.get_widget('fbutton')
+        self.fbutton = self.top.get_widget('fbutton')
         self.fbutton2 = self.top.get_widget('fbutton2')
 
         self.tooltips.set_tip(self.mbutton2,
@@ -493,6 +535,9 @@ class EditFamily(EditPrimary):
 
         self.mbox    = self.top.get_widget('mbox')
         self.fbox    = self.top.get_widget('fbox')
+        
+        #allow for a context menu
+        self.set_contexteventbox(self.top.get_widget("eventboxtop"))
 
     def _connect_signals(self):
         self.define_ok_button(self.top.get_widget('ok'), self.save)
@@ -553,32 +598,34 @@ class EditFamily(EditPrimary):
 
         self.child_list = self._add_tab(
             notebook,
-            ChildEmbedList(self.dbstate, self.uistate, self.track, self.obj))
+            ChildEmbedList(self.dbstate,self.uistate, self.track, self.obj))
         
         self.event_embed = EventEmbedList(self.dbstate, self.uistate, 
-                                          self.track, self.obj)
+                                          self.track,self.obj)
         self.event_list = self._add_tab(notebook, self.event_embed)
             
         self.source_embed = SourceEmbedList(self.dbstate, self.uistate, 
                                             self.track, self.obj)
         self.src_list = self._add_tab(notebook, self.source_embed)
             
-        self.attr_embed = FamilyAttrEmbedList(
-            self.dbstate, self.uistate, self.track,
-            self.obj.get_attribute_list())
+        self.attr_embed = FamilyAttrEmbedList(self.dbstate, self.uistate, 
+                                              self.track,
+                                              self.obj.get_attribute_list())
         self.attr_list = self._add_tab(notebook, self.attr_embed)
             
         self.note_tab = self._add_tab(
             notebook,
             NoteTab(self.dbstate, self.uistate, self.track,
-                    self.obj.get_note_object()))
+                    self.obj.get_note_list(), self.get_menu_title(),
+                    notetype=gen.lib.NoteType.FAMILY))
             
         self.gallery_tab = self._add_tab(
             notebook,
             GalleryTab(self.dbstate, self.uistate, self.track,
                        self.obj.get_media_list()))
 
-        self.lds_embed = FamilyLdsEmbedList(self.dbstate, self.uistate, self.track,
+        self.lds_embed = FamilyLdsEmbedList(self.dbstate, self.uistate, 
+                                            self.track,
                                             self.obj.get_lds_ord_list())
         self.lds_list = self._add_tab(notebook, self.lds_embed)
 
@@ -589,28 +636,54 @@ class EditFamily(EditPrimary):
         self.top.get_widget('vbox').pack_start(notebook, True)
 
     def update_father(self, handle):
-        self.load_parent(handle, self.fbox, self.fbirth,
-                         self.fdeath, self.fbutton, self.fbutton2,
+        self.load_parent(handle, self.fbox, self.fbirth, self.fbirth_label,
+                         self.fdeath, self.fdeath_label, self.fbutton,
+                         self.fbutton2,
                          _("Select a person as the father"),
                          _("Remove the person as the father"))
 
     def update_mother(self, handle):
-        self.load_parent(handle, self.mbox, self.mbirth,
-                         self.mdeath, self.mbutton, self.mbutton2,
+        self.load_parent(handle, self.mbox, self.mbirth, self.mbirth_label,
+                         self.mdeath, self.mdeath_label, self.mbutton,
+                         self.mbutton2,
                          _("Select a person as the mother"),
                          _("Remove the person as the mother"))
 
     def add_mother_clicked(self, obj):
         from Editors import EditPerson
-        person = RelLib.Person()
-        person.set_gender(RelLib.Person.FEMALE)
+        person = gen.lib.Person()
+        person.set_gender(gen.lib.Person.FEMALE)
+        autoname = Config.get(Config.SURNAME_GUESSING)
+        #_("Father's surname"), 
+        #_("None"), 
+        #_("Combination of mother's and father's surname"), 
+        #_("Icelandic style"), 
+        if autoname == 2:
+            name = self.latin_american_child("mother")
+        else:
+            name = self.no_name()
+        person.get_primary_name().set_surname(name[1])
+        person.get_primary_name().set_surname_prefix(name[0])
         EditPerson(self.dbstate, self.uistate, self.track, person,
                    self.new_mother_added)
 
     def add_father_clicked(self, obj):
         from Editors import EditPerson
-        person = RelLib.Person()
-        person.set_gender(RelLib.Person.MALE)
+        person = gen.lib.Person()
+        person.set_gender(gen.lib.Person.MALE)
+        autoname = Config.get(Config.SURNAME_GUESSING)
+        #_("Father's surname"), 
+        #_("None"), 
+        #_("Combination of mother's and father's surname"), 
+        #_("Icelandic style"), 
+        if autoname == 0:
+            name = self.north_american_child()
+        elif autoname == 2:
+            name = self.latin_american_child("father")
+        else:
+            name = self.no_name()
+        person.get_primary_name().set_surname(name[1])
+        person.get_primary_name().set_surname_prefix(name[0])
         EditPerson(self.dbstate, self.uistate, self.track,
                    person, self.new_father_added)
 
@@ -645,13 +718,14 @@ class EditFamily(EditPrimary):
 
             if person:
                 self.check_for_existing_family(self.obj.get_father_handle(),
-                                               person.handle)
+                                               person.handle,
+                                               self.obj.handle)
 
                 self.obj.set_mother_handle(person.handle) 
                 self.update_mother(person.handle)
 
     def on_change_father(self, selector_window, obj):
-        if  obj.__class__ == RelLib.Person:
+        if  obj.__class__ == gen.lib.Person:
             try:
                 person = obj
                 self.obj.set_father_handle(person.get_handle()) 
@@ -666,7 +740,7 @@ class EditFamily(EditPrimary):
             log.warn(
                 "Object selector returned obj.__class__ = %s, it should "
                 "have been of type %s." % (obj.__class__.__name__,
-                                           RelLib.Person.__name__))
+                                           gen.lib.Person.__name__))
             
         selector_window.close()
 
@@ -687,13 +761,16 @@ class EditFamily(EditPrimary):
             person = sel.run()
 
             if person:
+
                 self.check_for_existing_family(person.handle,
-                                               self.obj.get_mother_handle())
+                                               self.obj.get_mother_handle(),
+                                               self.obj.handle)
             
                 self.obj.set_father_handle(person.handle) 
                 self.update_father(person.handle)
 
-    def check_for_existing_family(self, father_handle, mother_handle):
+    def check_for_existing_family(self, father_handle, mother_handle,
+                                  family_handle):
 
         if father_handle:
             father = self.dbstate.db.get_person_from_handle(father_handle)
@@ -704,7 +781,7 @@ class EditFamily(EditPrimary):
                 common = list(mfam.intersection(ffam))
                 if len(common) > 0:
                     if self.add_parent or self.obj.handle not in common:
-                        QuestionDialog.WarningDialog(
+                        WarningDialog(
                             _('Duplicate Family'),
                             _('A family with these parents already exists '
                               'in the database. If you save, you will create '
@@ -713,7 +790,7 @@ class EditFamily(EditPrimary):
                               'select the existing family'))
 
     def edit_person(self, obj, event, handle):
-        if event.type == gtk.gdk.BUTTON_PRESS and event.button == 1:
+        if button_activated(event, _LEFT_BUTTON):
             from _EditPerson import EditPerson
             try:
                 person = self.db.get_person_from_handle(handle)
@@ -722,8 +799,8 @@ class EditFamily(EditPrimary):
             except Errors.WindowActiveError:
                 pass
 
-    def load_parent(self, handle, box, birth_obj, death_obj,
-                    btn_obj, btn2_obj, add_msg, del_msg):
+    def load_parent(self, handle, box, birth_obj, birth_label, death_obj,
+                    death_label, btn_obj, btn2_obj, add_msg, del_msg):
 
         is_used = handle != None
 
@@ -739,11 +816,15 @@ class EditFamily(EditPrimary):
             btn2_obj.hide()
             db = self.db
             person = db.get_person_from_handle(handle)
-            name = "%s [%s]" % (NameDisplay.displayer.display(person),
+            name = "%s [%s]" % (name_displayer.display(person),
                                 person.gramps_id)
-            data = ReportUtils.get_birth_death_strings(db, person)
-            birth = data[0]
-            death = data[4]
+            birth = ReportUtils.get_birth_or_fallback(db, person)
+            if birth and birth.get_type() == gen.lib.EventType.BAPTISM:
+                birth_label.set_label(_("Baptism:"))
+
+            death = ReportUtils.get_death_or_fallback(db, person)
+            if death and death.get_type() == gen.lib.EventType.BURIAL:
+                death_label.set_label(_("Burial:"))
 
             del_image = gtk.Image()
             del_image.show()
@@ -751,15 +832,18 @@ class EditFamily(EditPrimary):
             self.tooltips.set_tip(btn_obj, del_msg)
             btn_obj.add(del_image)
 
+            edit_btn = IconButton(self.edit_person, person.handle)
+            self.tooltips.set_tip(edit_btn, _('Edit %s') % name)
+
             box.pack_start(LinkBox(
                 BasicLabel(name),
-                IconButton(self.edit_person, person.handle)
-                ))
+                edit_btn)
+                )
         else:
             btn2_obj.show()
             name = ""
-            birth = ""
-            death = ""
+            birth = None
+            death = None
 
             add_image = gtk.Image()
             add_image.show()
@@ -767,8 +851,13 @@ class EditFamily(EditPrimary):
             self.tooltips.set_tip(btn_obj, add_msg)
             btn_obj.add(add_image)
 
-        birth_obj.set_text(birth)
-        death_obj.set_text(death)
+        if birth:
+            birth_str = DateHandler.displayer.display(birth.get_date_object())
+            birth_obj.set_text(birth_str)
+
+        if death:
+            death_str = DateHandler.displayer.display(death.get_date_object())
+            death_obj.set_text(death_str)
 
     def fix_parent_handles(self, orig_handle, new_handle, trans):
         if orig_handle != new_handle:
@@ -786,15 +875,16 @@ class EditFamily(EditPrimary):
         return self.obj.get_father_handle() == None and \
                self.obj.get_mother_handle() == None and \
                len(self.obj.get_child_ref_list()) == 0
-
+            
     def save(self, *obj):
         try:
             self.__do_save()
-        except db.DBRunRecoveryError, msg:
-            QuestionDialog.RunDatabaseRepair(msg[1])
+        except bsddb_db.DBRunRecoveryError, msg:
+            RunDatabaseRepair(msg[1])
 
     def __do_save(self):
         self.ok_button.set_sensitive(False)
+
         if not self.added:
             original = self.db.get_family_from_handle(self.obj.handle)
         else:
@@ -807,9 +897,9 @@ class EditFamily(EditPrimary):
         if self.obj.get_father_handle() in child_list:
 
             father = self.db.get_person_from_handle(self.obj.get_father_handle())
-            name = "%s [%s]" % (NameDisplay.displayer.display(father),
+            name = "%s [%s]" % (name_displayer.display(father),
                                 father.gramps_id)
-            QuestionDialog.ErrorDialog(_("A father cannot be his own child"),
+            ErrorDialog(_("A father cannot be his own child"),
                                        _("%s is listed as both the father and child "
                                          "of the family.") % name)
             self.ok_button.set_sensitive(True)
@@ -817,19 +907,32 @@ class EditFamily(EditPrimary):
         elif self.obj.get_mother_handle() in child_list:
 
             mother = self.db.get_person_from_handle(self.obj.get_mother_handle())
-            name = "%s [%s]" % (NameDisplay.displayer.display(mother),
+            name = "%s [%s]" % (name_displayer.display(mother),
                                 mother.gramps_id)
-            QuestionDialog.ErrorDialog(_("A mother cannot be her own child"),
+            ErrorDialog(_("A mother cannot be her own child"),
                                        _("%s is listed as both the mother and child "
                                          "of the family.") % name)
             self.ok_button.set_sensitive(True)
             return
 
         if not original and self.object_is_empty():
-            QuestionDialog.ErrorDialog(
+            ErrorDialog(
                 _("Cannot save family"),
                 _("No data exists for this family. "
                   "Please enter data or cancel the edit."))
+            self.ok_button.set_sensitive(True)
+            return
+        
+        (uses_dupe_id, id) = self._uses_duplicate_id()
+        if uses_dupe_id:
+            msg1 = _("Cannot save family. ID already exists.")
+            msg2 = _("You have attempted to use the existing GRAMPS ID with "
+                         "value %(id)s. This value is already used. Please "
+                         "enter a different ID or leave "
+                         "blank to get the next available ID value.") % {
+                         'id' : id}
+            ErrorDialog(msg1, msg2)
+            self.ok_button.set_sensitive(True)
             return
 
         # We disconnect the callbacks to all signals we connected earlier.
@@ -864,11 +967,11 @@ class EditFamily(EditPrimary):
                 self.db.commit_person(child, trans)
 
             self.db.add_family(self.obj, trans)
-            self.db.transaction_commit(trans,_("Add Family"))
+            self.db.transaction_commit(trans, _("Add Family"))
         elif original and self.object_is_empty():
             trans = self.db.transaction_begin()
             self.db.remove_family(self.obj.handle, trans)
-            self.db.transaction_commit(trans,_("Remove Family"))
+            self.db.transaction_commit(trans, _("Remove Family"))
         elif cmp(original.serialize(),self.obj.serialize()):
 
             trans = self.db.transaction_begin()
@@ -887,7 +990,7 @@ class EditFamily(EditPrimary):
                 person.remove_parent_family_handle(self.obj.handle)
                 self.db.commit_person(person, trans)
             
-            # add the family from children which have been addedna
+            # add the family to children which have been added
             for ref in new_set.difference(orig_set):
                 person = self.db.get_person_from_handle(ref.ref)
                 person.add_parent_family_handle(self.obj.handle)
@@ -896,17 +999,10 @@ class EditFamily(EditPrimary):
             if self.object_is_empty():
                 self.db.remove_family(self.obj.handle, trans)
             else:
+                if not self.obj.get_gramps_id():
+                    self.obj.set_gramps_id(self.db.find_next_family_gramps_id())
                 self.db.commit_family(self.obj, trans)
             self.db.transaction_commit(trans, _("Edit Family"))
-        else:
-            # Signal an update to allow other windows that use family data to
-            # refresh. The family-update signal is normally only emitted when
-            # the family record itself changes, however the Relationship view
-            # needs to know to refresh when related data such as the marriage
-            # event may have been altered.
-            # Bug #1416
-            self.db.emit('family-update', ([],))
-
 
         self.close()
 
@@ -915,3 +1011,58 @@ class EditFamily(EditPrimary):
         Config.set(Config.FAMILY_WIDTH, width)
         Config.set(Config.FAMILY_HEIGHT, height)
         Config.sync()
+
+    def no_name(self):
+        """
+        Default surname guess.
+        """
+        return ("","")
+
+    def north_american_child(self):
+        """
+        If SURNAME_GUESSING is north american, then find a child
+        and return their name for the father.
+        """
+        # for each child, find one with a last name
+        for ref in self.obj.get_child_ref_list():
+            child = self.db.get_person_from_handle(ref.ref)
+            if child:
+                pname = child.get_primary_name()
+                return (pname.get_surname_prefix(), pname.get_surname())
+        return ("", "")
+
+    def latin_american_child(self, parent):
+        """
+        If SURNAME_GUESSING is latin american, then find a child
+        and return their name for the father or mother.
+
+        parent = "mother" | "father"
+        """
+        # for each child, find one with a last name
+        for ref in self.obj.get_child_ref_list():
+            child = self.db.get_person_from_handle(ref.ref)
+            if child:
+                pname = child.get_primary_name()
+                prefix, surname = (pname.get_surname_prefix(),
+                                   pname.get_surname())
+                if " " in surname:
+                    fsn, msn = surname.split(" ", 1)
+                else:
+                    fsn, msn = surname, surname
+                if parent == "father":
+                    return prefix, fsn
+                elif parent == "mother":    
+                    return prefix, msn
+                else:    
+                    return ("", "")
+        return ("", "")
+
+def button_activated(event, mouse_button):
+    if (event.type == gtk.gdk.BUTTON_PRESS and \
+        event.button == mouse_button) or \
+       (event.type == gtk.gdk.KEY_PRESS and \
+        event.keyval in (_RETURN, _KP_ENTER)):
+        return True
+    else:
+        return False
+
