@@ -18,7 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditSourceRef.py 6068 2006-03-04 06:34:48Z dallingham $
+# $Id: _EditReference.py 10103 2008-02-24 13:55:55Z acraphae $
+
+#-------------------------------------------------------------------------
+#
+# GTK/Gnome modules
+#
+#-------------------------------------------------------------------------
+import gtk
 
 #-------------------------------------------------------------------------
 #
@@ -26,9 +33,52 @@
 #
 #-------------------------------------------------------------------------
 import ManagedWindow
-from GrampsWidgets import *
+from DisplayTabs import GrampsTab
 import Config
 
+#-------------------------------------------------------------------------
+#
+# Classes
+#
+#-------------------------------------------------------------------------
+
+class RefTab(GrampsTab):
+    """
+    This class provides a simple tabpage for use on EditReference
+    """
+
+    def __init__(self, dbstate, uistate, track, name, widget):
+        """
+        @param dbstate: The database state. Contains a reference to
+        the database, along with other state information. The GrampsTab
+        uses this to access the database and to pass to and created
+        child windows (such as edit dialogs).
+        @type dbstate: DbState
+        @param uistate: The UI state. Used primarily to pass to any created
+        subwindows.
+        @type uistate: DisplayState
+        @param track: The window tracking mechanism used to manage windows.
+        This is only used to pass to generted child windows.
+        @type track: list
+        @param name: Notebook label name
+        @type name: str/unicode
+        @param widget: widget to be shown in the tab
+        @type widge: gtk widget
+        """
+        GrampsTab.__init__(self, dbstate, uistate, track, name)
+        eventbox = gtk.EventBox()
+        eventbox.add(widget)
+        self.pack_start(eventbox)
+        self._set_label(show_image=False)
+        widget.connect('key_press_event', self.key_pressed)
+        self.show_all()
+
+    def is_empty(self):
+        """
+        Override base class
+        """
+        return False
+
 #-------------------------------------------------------------------------
 #
 # EditReference class
@@ -92,15 +142,30 @@ class EditReference(ManagedWindow.ManagedWindow):
             label = notebook.get_tab_label(child)
             page_no = notebook.page_num(child)
             label.drag_dest_set(0, [], 0)
-            label.connect('drag_motion', self._switch_page_on_dnd,notebook,page_no)
-    
+            label.connect('drag_motion',
+                          self._switch_page_on_dnd,
+                          notebook,
+                          page_no)
+            child.set_parent_notebook(notebook)
+        notebook.connect('key-press-event', self.key_pressed, notebook)
+
+    def key_pressed(self, obj, event, notebook):
+        """
+        Handles the key being pressed on the notebook, pass to key press of
+        current page.
+        """
+        pag = notebook.get_current_page()
+        if not pag == -1:
+            notebook.get_nth_page(pag).key_pressed(obj, event)
+
     def _switch_page_on_dnd(self, widget, context, x, y, time, notebook, page_no):
         if notebook.get_current_page() != page_no:
             notebook.set_current_page(page_no)
 
-    def _add_tab(self,notebook,page):
+    def _add_tab(self, notebook,page):
         notebook.insert_page(page, page.get_tab_widget())
         page.add_db_signal_callback(self._add_db_signal)
+        page.label.set_use_underline(True)
         return page
 
     def _add_db_signal(self, name, callback):
@@ -116,7 +181,8 @@ class EditReference(ManagedWindow.ManagedWindow):
         pass
 
     def build_window_key(self,sourceref):
-        if self.source:
+        #the window key for managedwindow identification. No need to return None
+        if self.source and self.source.get_handle():
             return self.source.get_handle()
         else:
             return id(self)
@@ -132,9 +198,11 @@ class EditReference(ManagedWindow.ManagedWindow):
         self._cleanup_on_exit()
         self.close(obj)
 
-    def define_help_button(self,button,tag):
+    def define_help_button(self, button, tag, webpage='', section=''):
         import GrampsDisplay
-        button.connect('clicked', lambda x: GrampsDisplay.help(tag))
+        button.connect('clicked', lambda x: GrampsDisplay.help(tag, webpage,
+                                                               section))
+        button.set_sensitive(True)
 
     def _cleanup_on_exit(self):
         pass
