@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditUrl.py 7804 2006-12-15 12:39:28Z LosHawlos $
+# $Id: _EditUrl.py 10103 2008-02-24 13:55:55Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -32,7 +32,7 @@ from gettext import gettext as _
 # GTK/Gnome modules
 #
 #-------------------------------------------------------------------------
-import gtk.glade
+from gtk import glade
 
 #-------------------------------------------------------------------------
 #
@@ -42,8 +42,7 @@ import gtk.glade
 import const
 import Config
 from _EditSecondary import EditSecondary
-
-from GrampsWidgets import *
+from GrampsWidgets import MonitoredEntry, PrivacyButton, MonitoredDataType
 
 #-------------------------------------------------------------------------
 #
@@ -61,40 +60,41 @@ class EditUrl(EditSecondary):
                                url, callback)
 
     def _local_init(self):
-        self.top = gtk.glade.XML(const.gladeFile, "url_edit","gramps")
+        self.top = glade.XML(const.GLADE_FILE, "url_edit", "gramps")
+        self.jump = self.top.get_widget('jump')
 
         self.set_window(self.top.get_widget("url_edit"),
                         self.top.get_widget("title"),
                         _('Internet Address Editor'))
             
     def _connect_signals(self):
+        self.jump.connect('clicked', self.jump_to)
         self.define_cancel_button(self.top.get_widget('button125'))
-        self.define_ok_button(self.top.get_widget('button124'),self.save)
-        self.define_help_button(self.top.get_widget('button130'),'gramps-edit_complete')
+        self.define_ok_button(self.top.get_widget('button124'), self.save)
+        self.define_help_button(self.top.get_widget('button130'), 'gramps-edit_complete')
         
-    def _setup_fields(self):
-        self.des  = MonitoredEntry(
-            self.top.get_widget("url_des"),
-            self.obj.set_description,
-            self.obj.get_description,
-            self.db.readonly)
+    def jump_to(self, obj):
+        if self.obj.get_path():
+            import GrampsDisplay
+            GrampsDisplay.url(self.obj.get_path())
 
-        self.addr  = MonitoredEntry(
-            self.top.get_widget("url_addr"),
-            self.obj.set_path,
-            self.obj.get_path,
-            self.db.readonly)
+    def _setup_fields(self):
+        self.des  = MonitoredEntry(self.top.get_widget("url_des"),
+                                   self.obj.set_description, 
+                                   self.obj.get_description, self.db.readonly)
+
+        self.addr  = MonitoredEntry(self.top.get_widget("url_addr"), 
+                                    self.obj.set_path, self.obj.get_path, 
+                                    self.db.readonly)
         
         self.priv = PrivacyButton(self.top.get_widget("priv"),
                                   self.obj, self.db.readonly)
 
-        self.type_sel = MonitoredDataType(
-            self.top.get_widget("type"),
-            self.obj.set_type,
-            self.obj.get_type,
-            self.db.readonly)
+        self.type_sel = MonitoredDataType(self.top.get_widget("type"), 
+                                          self.obj.set_type, 
+                                          self.obj.get_type, self.db.readonly)
             
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         etitle =_('Internet Address Editor')
         return (etitle, etitle)
 
