@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +18,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _FilterEditor.py 6840 2006-06-01 22:37:13Z dallingham $
+# $Id: _EditRule.py 10094 2008-02-22 10:50:06Z acraphae $
 
 """
 Custom Filter Editor tool.
 """
 
-__author__ = "Don Allingham"
-
 #-------------------------------------------------------------------------
 #
 # Python modules
@@ -56,11 +54,11 @@ import gobject
 #-------------------------------------------------------------------------
 import GrampsDisplay
 import const
-import RelLib
+import gen.lib
 from Filters import Rules
 import AutoComp
 from Selectors import selector_factory
-from NameDisplay import displayer as _nd
+from BasicUtils import name_displayer as _nd
 import Utils
 import ManagedWindow
 
@@ -69,8 +67,8 @@ import ManagedWindow
 # Sorting function for the filter rules
 #
 #-------------------------------------------------------------------------
-def by_rule_name(f,s):
-    return cmp(f.name,s.name)
+def by_rule_name(f, s):
+    return cmp(f.name, s.name)
 
 #-------------------------------------------------------------------------
 #
@@ -78,13 +76,14 @@ def by_rule_name(f,s):
 #
 #-------------------------------------------------------------------------
 _name2typeclass = {
-    _('Personal event:')     : RelLib.EventType,
-    _('Family event:')       : RelLib.EventType,
-    _('Event type:')         : RelLib.EventType,
-    _('Personal attribute:') : RelLib.AttributeType,
-    _('Family attribute:')   : RelLib.AttributeType,
-    _('Relationship type:')  : RelLib.FamilyRelType,
-    _('Marker type:')        : RelLib.MarkerType,
+    _('Personal event:')     : gen.lib.EventType,
+    _('Family event:')       : gen.lib.EventType,
+    _('Event type:')         : gen.lib.EventType,
+    _('Personal attribute:') : gen.lib.AttributeType,
+    _('Family attribute:')   : gen.lib.AttributeType,
+    _('Relationship type:')  : gen.lib.FamilyRelType,
+    _('Marker type:')        : gen.lib.MarkerType,
+    _('Note type:')          : gen.lib.NoteType,
 }
 
 #-------------------------------------------------------------------------
@@ -94,22 +93,25 @@ _name2typeclass = {
 #-------------------------------------------------------------------------
 class MyBoolean(gtk.CheckButton):
 
-    def __init__(self,label=None):
-        gtk.CheckButton.__init__(self,label)
+    def __init__(self, label=None):
+        gtk.CheckButton.__init__(self, label)
         self.show()
 
     def get_text(self):
         """
-        This method returns the text to save. It should be the same
-        no matter the present locale (English or numeric types).
+        Return the text to save. 
+        
+        It should be the same no matter the present locale (English or numeric 
+        types).
         This class sets this to get_display_text, but when localization
         is an issue (events/attr/etc types) then it has to be overridden.
+        
         """
         return str(int(self.get_active()))
 
-    def set_text(self,val):
+    def set_text(self, val):
         """
-        This method sets the selector state to display the passed value.
+        Set the selector state to display the passed value.
         """
         is_active = bool(int(val))
         self.set_active(is_active)
@@ -121,15 +123,15 @@ class MyBoolean(gtk.CheckButton):
 #-------------------------------------------------------------------------
 class MyInteger(gtk.SpinButton):
 
-    def __init__(self,min,max):
+    def __init__(self, min, max):
         gtk.SpinButton.__init__(self)
-        self.set_adjustment(gtk.Adjustment(min,min,max,1))
+        self.set_adjustment(gtk.Adjustment(min, min, max, 1))
         self.show()
 
     def get_text(self):
         return str(self.get_value_as_int())
 
-    def set_text(self,val):
+    def set_text(self, val):
         self.set_value(int(val))
 
 #-------------------------------------------------------------------------
@@ -138,14 +140,23 @@ class MyInteger(gtk.SpinButton):
 #
 #-------------------------------------------------------------------------
 class MyFilters(gtk.ComboBox):
-    
-    def __init__(self,filters,filter_name=None):
+    """
+    Class to present a combobox of selectable filters.
+    """
+    def __init__(self, filters, filter_name=None):
+        """
+        Construct the combobox from the entries of the filters list.
+        
+        Filter_name is name of calling filter.
+        If filter_name is given, it will be excluded from the dropdown box.
+        
+        """
         gtk.ComboBox.__init__(self)
-        store = gtk.ListStore(str)
+        store = gtk.ListStore(gobject.TYPE_STRING)
         self.set_model(store)
         cell = gtk.CellRendererText()
-        self.pack_start(cell,True)
-        self.add_attribute(cell,'text',0)
+        self.pack_start(cell, True)
+        self.add_attribute(cell, 'text', 0)
         #remove own name from the list if given.
         self.flist = [ f.get_name() for f in filters if \
             (filter_name is None or f.get_name() != filter_name)]
@@ -162,10 +173,42 @@ class MyFilters(gtk.ComboBox):
             return ""
         return self.flist[active]
 
-    def set_text(self,val):
+    def set_text(self, val):
         if val in self.flist:
             self.set_active(self.flist.index(val))
 
+#-------------------------------------------------------------------------
+#
+# MyLesserEqualGreater - Combo box to allow selection of "<", "=", or ">"
+#
+#-------------------------------------------------------------------------
+class MyLesserEqualGreater(gtk.ComboBox):
+
+    def __init__(self):
+        gtk.ComboBox.__init__(self)
+        store = gtk.ListStore(gobject.TYPE_STRING)
+        self.set_model(store)
+        cell = gtk.CellRendererText()
+        self.pack_start(cell, True)
+        self.add_attribute(cell, 'text', 0)
+        self.clist = [_('lesser than'), _('equal to'), _('greater than')]
+        for name in self.clist:
+            store.append(row=[name])
+        self.set_active(0)
+        self.show()
+
+    def get_text(self):
+        active = self.get_active()
+        if active < 0:
+            return _('equal to')
+        return self.clist[active]
+
+    def set_text(self, val):
+        if val in self.clist:
+            self.set_active(self.clist.index(val))
+        else:
+            self.set_active(self.clist.index(_('equal to')))
+
 #-------------------------------------------------------------------------
 #
 # MySource - Combo box with list of sources with a standard interface
@@ -176,11 +219,11 @@ class MySource(gtk.ComboBox):
     def __init__(self, db):
         gtk.ComboBox.__init__(self)
         self.db = db
-        store = gtk.ListStore(str)
+        store = gtk.ListStore(gobject.TYPE_STRING)
         self.set_model(store)
         cell = gtk.CellRendererText()
-        self.pack_start(cell,True)
-        self.add_attribute(cell,'text',0)
+        self.pack_start(cell, True)
+        self.add_attribute(cell, 'text', 0)
 
         self.slist = []
         for src_handle in self.db.get_source_handles(sort_handles=True):
@@ -189,7 +232,7 @@ class MySource(gtk.ComboBox):
             title = src.get_title()
             if len(title) > 44:
                 title = title[:40] + "..."
-            store.append(row=["%s [%s]" % (title,src.get_gramps_id())])
+            store.append(row=["%s [%s]" % (title, src.get_gramps_id())])
 
         self.set_active(0)
         self.show()
@@ -200,7 +243,7 @@ class MySource(gtk.ComboBox):
             return ""
         return self.slist[active]
 
-    def set_text(self,val):
+    def set_text(self, val):
         if val in self.slist:
             self.set_active(self.slist.index(val))
 
@@ -212,10 +255,10 @@ class MySource(gtk.ComboBox):
 #-------------------------------------------------------------------------
 class MyPlaces(gtk.Entry):
     
-    def __init__(self,places):
+    def __init__(self, places):
         gtk.Entry.__init__(self)
         
-        AutoComp.fill_entry(self,places)
+        AutoComp.fill_entry(self, places)
         self.show()
         
 #-------------------------------------------------------------------------
@@ -233,10 +276,11 @@ class MyID(gtk.HBox):
         'Source' : _('Source'),
         'MediaObject'  : _('Media Object'),
         'Repository' : _('Repository'),
+        'Note'   : _('Note'),
         }
     
     def __init__(self, dbstate, uistate, track, namespace='Person'):
-        gtk.HBox.__init__(self,False,6)
+        gtk.HBox.__init__(self, False, 6)
         self.dbstate = dbstate
         self.db = dbstate.db
         self.uistate = uistate
@@ -247,18 +291,18 @@ class MyID(gtk.HBox):
         self.entry.show()
         self.button = gtk.Button()
         self.button.set_label(_('Select...'))
-        self.button.connect('clicked',self.button_press)
+        self.button.connect('clicked', self.button_press)
         self.button.show()
         self.pack_start(self.entry)
         self.add(self.button)
         self.tooltips = gtk.Tooltips()
-        self.tooltips.set_tip(self.button,_('Select %s from a list')
+        self.tooltips.set_tip(self.button, _('Select %s from a list')
                               % self.obj_name[namespace])
         self.tooltips.enable()
         self.show()
         self.set_text('')
 
-    def button_press(self,obj):
+    def button_press(self, obj):
         obj_class = self.namespace
         selector = selector_factory(obj_class)
         inst = selector(self.dbstate, self.uistate, self.track)
@@ -271,7 +315,7 @@ class MyID(gtk.HBox):
     def get_text(self):
         return unicode(self.entry.get_text())
 
-    def name_from_gramps_id(self,gramps_id):
+    def name_from_gramps_id(self, gramps_id):
         if self.namespace == 'Person':
             person = self.db.get_person_from_gramps_id(gramps_id)
             name = _nd.display_name(person.get_primary_name())
@@ -293,14 +337,17 @@ class MyID(gtk.HBox):
         elif self.namespace == 'Repository':
             repo = self.db.get_repository_from_gramps_id(gramps_id)
             name = repo.get_name()
+        elif self.namespace == 'Note':
+            note = self.db.get_note_from_gramps_id(gramps_id)
+            name = note.get()
         return name
 
-    def set_text(self,val):
+    def set_text(self, val):
         try:
             name = self.name_from_gramps_id(val)
-            self.tooltips.set_tip(self.entry,name)
+            self.tooltips.set_tip(self.entry, name)
         except AttributeError:
-            self.tooltips.set_tip(self.entry,_('Not a valid ID'))
+            self.tooltips.set_tip(self.entry, _('Not a valid ID'))
         self.entry.set_text(val)
 
 #-------------------------------------------------------------------------
@@ -321,10 +368,10 @@ class MySelect(gtk.ComboBoxEntry):
     def get_text(self):
         return self.type_class(self.sel.get_values()).xml_str()
 
-    def set_text(self,val):
+    def set_text(self, val):
         tc = self.type_class()
         tc.set_from_xml_str(val)
-        self.sel.set_values((tc.val,tc.string))
+        self.sel.set_values((tc.val, tc.string))
 
 #-------------------------------------------------------------------------
 #
@@ -343,12 +390,12 @@ class MyEntry(gtk.Entry):
 #
 #-------------------------------------------------------------------------
 class EditRule(ManagedWindow.ManagedWindow):
-    def __init__(self, space, dbstate, uistate, track, filterdb, val,
+    def __init__(self, namespace, dbstate, uistate, track, filterdb, val,
                  label, update, filter_name):
 
         ManagedWindow.ManagedWindow.__init__(self, uistate, track, EditRule)
 
-        self.space = space
+        self.namespace = namespace
         self.dbstate = dbstate
         self.db = dbstate.db
         self.filterdb = filterdb
@@ -356,7 +403,7 @@ class EditRule(ManagedWindow.ManagedWindow):
         self.filter_name = filter_name
 
         self.active_rule = val
-        self.define_glade('rule_editor', const.rule_glade)
+        self.define_glade('rule_editor', const.RULE_GLADE)
         
         self.set_window(self.get_widget('rule_editor'),
                         self.get_widget('title'),label)
@@ -375,58 +422,72 @@ class EditRule(ManagedWindow.ManagedWindow):
         self.class2page = {}
         the_map = {}
 
-        if self.space == "Person":
+        if self.namespace == 'Person':
             class_list = Rules.Person.editor_rule_list
-        elif self.space == "Family":
+        elif self.namespace == 'Family':
             class_list = Rules.Family.editor_rule_list
-        elif self.space == "Event":
+        elif self.namespace == 'Event':
             class_list = Rules.Event.editor_rule_list
-        elif self.space == 'Source':
+        elif self.namespace == 'Source':
             class_list = Rules.Source.editor_rule_list
-        elif self.space == 'Place':
+        elif self.namespace == 'Place':
             class_list = Rules.Place.editor_rule_list
-        elif self.space == 'MediaObject':
+        elif self.namespace == 'MediaObject':
             class_list = Rules.MediaObject.editor_rule_list
-        elif self.space == 'Repository':
+        elif self.namespace == 'Repository':
             class_list = Rules.Repository.editor_rule_list
+        elif self.namespace == 'Note':
+            class_list = Rules.Note.editor_rule_list
         
         for class_obj in class_list:
             arglist = class_obj.labels
             vallist = []
             tlist = []
-            self.page.append((class_obj,vallist,tlist))
+            self.page.append((class_obj, vallist, tlist))
             pos = 0
             l2 = gtk.Label(class_obj.name)
-            l2.set_alignment(0,0.5)
+            l2.set_alignment(0, 0.5)
             l2.show()
             c = gtk.TreeView()
-            c.set_data('d',pos)
+            c.set_data('d', pos)
             c.show()
             the_map[class_obj] = c
             # Only add a table with parameters if there are any parameters
             if arglist:
-                table = gtk.Table(3,len(arglist))
+                table = gtk.Table(3, len(arglist))
             else:
-                table = gtk.Table(1,1)
+                table = gtk.Table(1, 1)
             table.set_border_width(6)
             table.set_col_spacings(6)
             table.set_row_spacings(6)
             table.show()
             for v in arglist:
                 l = gtk.Label(v)
-                l.set_alignment(1,0.5)
+                l.set_alignment(1, 0.5)
                 l.show()
                 if v == _('Place:'):
                     t = MyPlaces([])
+                elif v == _('Reference count:'):
+                    t = MyInteger(0, 999)
+                elif v == _('Reference count must be:'):
+                    t = MyLesserEqualGreater()
                 elif v == _('Number of generations:'):
-                    t = MyInteger(1,32)
+                    t = MyInteger(1, 32)
                 elif v == _('ID:'):
-                    t = MyID(self.dbstate,self.uistate,self.track,self.space)
+                    t = MyID(self.dbstate, self.uistate, self.track, 
+                             self.namespace)
                 elif v == _('Source ID:'):
                     t = MySource(self.db)
                 elif v == _('Filter name:'):
-                    t = MyFilters(self.filterdb.get_filters(self.space),
+                    t = MyFilters(self.filterdb.get_filters(self.namespace),
                                   self.filter_name)
+                # filters of another namespace, name may be same as caller!
+                elif v == _('Person filter name:'):
+                    t = MyFilters(self.filterdb.get_filters('Person'))
+                elif v == _('Event filter name:'):
+                    t = MyFilters(self.filterdb.get_filters('Event'))
+                elif v == _('Source filter name:'):
+                    t = MyFilters(self.filterdb.get_filters('Source'))
                 elif _name2typeclass.has_key(v):
                     t = MySelect(_name2typeclass[v])
                 elif v == _('Inclusive:'):
@@ -435,19 +496,23 @@ class EditRule(ManagedWindow.ManagedWindow):
                     t = MyBoolean(_('Use exact case of letters'))
                 elif v == _('Regular-Expression matching:'):
                     t = MyBoolean(_('Use regular expression'))
+                elif v == _('Include Family events:'):
+                    t = MyBoolean(_('Also family events where person is '
+                                    'wife/husband'))
                 else:                    
                     t = MyEntry()
                 tlist.append(t)
-                table.attach(l,1,2,pos,pos+1,gtk.FILL,0,5,5)
-                table.attach(t,2,3,pos,pos+1,gtk.EXPAND|gtk.FILL,0,5,5)
+                table.attach(l, 1, 2, pos, pos+1, gtk.FILL, 0, 5, 5)
+                table.attach(t, 2, 3, pos, pos+1, gtk.EXPAND|gtk.FILL, 0, 5, 5)
                 pos = pos + 1
-            self.notebook.append_page(table,gtk.Label(class_obj.name))
+            self.notebook.append_page(table, gtk.Label(class_obj.name))
             self.class2page[class_obj] = self.page_num
             self.page_num = self.page_num + 1
         self.page_num = 0
-        self.store = gtk.TreeStore(gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)
+        self.store = gtk.TreeStore(gobject.TYPE_STRING, gobject.TYPE_PYOBJECT)
         self.selection = self.rname.get_selection()
-        col = gtk.TreeViewColumn(_('Rule Name'),gtk.CellRendererText(),text=0)
+        col = gtk.TreeViewColumn(_('Rule Name'), gtk.CellRendererText(), 
+                                 text=0)
         self.rname.append_column(col)
         self.rname.set_model(self.store)
 
@@ -477,16 +542,16 @@ class EditRule(ManagedWindow.ManagedWindow):
         catlist.sort()
 
         for category in catlist:
-            top_node[category] = self.store.insert_after(None,last_top)
+            top_node[category] = self.store.insert_after(None, last_top)
             top_level[category] = []
             last_top = top_node[category]
-            self.store.set(last_top,0,category,1,None)
+            self.store.set(last_top, 0, category, 1, None)
 
         for class_obj in keys:
             category = class_obj.category
             top_level[category].append(class_obj.name)
-            node = self.store.insert_after(top_node[category],prev)
-            self.store.set(node,0,class_obj.name,1,class_obj)
+            node = self.store.insert_after(top_node[category], prev)
+            self.store.set(node, 0, class_obj.name, 1, class_obj)
 
             #
             # if this is an edit rule, save the node
@@ -498,53 +563,57 @@ class EditRule(ManagedWindow.ManagedWindow):
             page = self.class2page[self.active_rule.__class__]
             self.notebook.set_current_page(page)
             self.display_values(self.active_rule.__class__)
-            (class_obj,vallist,tlist) = self.page[page]
+            (class_obj, vallist, tlist) = self.page[page]
             r = self.active_rule.values()
-            for i in range(0,len(tlist)):
+            for i in range(0, len(tlist)):
                 tlist[i].set_text(r[i])
             
         self.selection.connect('changed', self.on_node_selected)
-        self.get_widget('ok').connect('clicked',self.rule_ok)
+        self.get_widget('ok').connect('clicked', self.rule_ok)
         self.get_widget('cancel').connect('clicked', self.close_window)
-        self.get_widget('help').connect('clicked',self.on_help_clicked)
+        self.get_widget('help').connect('clicked', self.on_help_clicked)
 
         self.show()
 
-    def on_help_clicked(self,obj):
-        """Display the relevant portion of GRAMPS manual"""
+    def on_help_clicked(self, obj):
+        """
+        Display the relevant portion of GRAMPS manual.
+        """
         GrampsDisplay.help('append-filtref')
 
-    def close_window(self,obj):
+    def close_window(self, obj):
         self.close()
 
-    def on_node_selected(self,obj):
-        """Updates the informational display on the right hand side of
-        the dialog box with the description of the selected report"""
+    def on_node_selected(self, obj):
+        """
+        Update the informational display on the right hand side of the dialog 
+        box with the description of the selected report.
+        """
 
-        store,node = self.selection.get_selected()
+        store, node = self.selection.get_selected()
         if node:
             try:
-                class_obj = store.get_value(node,1)
+                class_obj = store.get_value(node, 1)
                 self.display_values(class_obj)
             except:
                 self.valuebox.set_sensitive(0)
                 self.rule_name.set_text(_('No rule selected'))
                 self.get_widget('description').set_text('')
 
-    def display_values(self,class_obj):
+    def display_values(self, class_obj):
         page = self.class2page[class_obj]
         self.notebook.set_current_page(page)
         self.valuebox.set_sensitive(1)
         self.rule_name.set_text(class_obj.name)
         self.get_widget('description').set_text(class_obj.description)
 
-    def rule_ok(self,obj):
+    def rule_ok(self, obj):
         if self.rule_name.get_text() == _('No rule selected'):
             return
 
         try:
             page = self.notebook.get_current_page()
-            (class_obj,vallist,tlist) = self.page[page]
+            (class_obj, vallist, tlist) = self.page[page]
             value_list = []
             for selector_class in tlist:
                 value_list.append(unicode(selector_class.get_text()))
