@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasMedia.py 7147 2006-08-10 00:42:44Z rshura $
+# $Id:_HasMedia.py 9912 2008-01-22 09:17:46Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -34,7 +34,6 @@ from gettext import gettext as _
 #-------------------------------------------------------------------------
 import DateHandler
 from Filters.Rules._Rule import Rule
-from Filters.Rules._RuleUtils import loose_date_cmp
 
 #-------------------------------------------------------------------------
 #
@@ -62,18 +61,18 @@ class HasMedia(Rule):
         except:
             pass
 
-    def apply(self,db,obj):
-        if not self.match_substring(0,obj.get_description()):
+    def apply(self,db, obj):
+        if not self.match_substring(0, obj.get_description()):
             return False
 
-        if not self.match_substring(1,obj.get_mime_type()):
+        if not self.match_substring(1, obj.get_mime_type()):
             return False
 
-        if not self.match_substring(2,obj.get_path()):
+        if not self.match_substring(2, obj.get_path()):
             return False
 
         if self.date:
-            if not loose_date_cmp(self.date,obj.get_date_object()):
+            if not obj.get_date_object().match(self.date):
                 return False
 
         return True
