@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasDeath.py 7607 2006-11-10 21:27:08Z loshawlos $
+# $Id: _HasDeath.py 9912 2008-01-22 09:17:46Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -33,9 +33,8 @@ from gettext import gettext as _
 #
 #-------------------------------------------------------------------------
 import DateHandler
-from RelLib import EventType,EventRoleType
+from gen.lib import EventType,EventRoleType
 from Filters.Rules._Rule import Rule
-from Filters.Rules._RuleUtils import loose_date_cmp
 
 #-------------------------------------------------------------------------
 #
@@ -72,7 +71,7 @@ class HasDeath(Rule):
                 # No match: wrong description
                 continue
             if self.date:
-                if loose_date_cmp(self.date,event.get_date_object()) == 0:
+                if not event.get_date_object().match(self.date):
                     # No match: wrong date
                     continue
             if self.list[1]:
