@@ -18,14 +18,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 9153 2007-10-11 23:04:36Z bmcage $
+# $Id:__init__.py 9912 2008-01-22 09:17:46Z acraphae $
 
 """
 Package providing filter rules for GRAMPS.
 """
 
-__author__ = "Don Allingham"
-
 from _Disconnected import Disconnected
 from _Everyone import Everyone
 from _FamilyWithIncompleteEvent import FamilyWithIncompleteEvent
@@ -80,6 +78,7 @@ from _IsSiblingOfFilterMatch import IsSiblingOfFilterMatch
 from _IsSpouseOfFilterMatch import IsSpouseOfFilterMatch
 from _IsWitness import IsWitness
 from _MatchesFilter import MatchesFilter
+from _MatchesEventFilter import MatchesEventFilter
 from _MissingParent import MissingParent
 from _MultipleMarriages import MultipleMarriages
 from _NeverMarried import NeverMarried
@@ -146,6 +145,7 @@ editor_rule_list = [
     HasCommonAncestorWith,
     HasCommonAncestorWithFilterMatch,
     MatchesFilter,
+    MatchesEventFilter,
     MissingParent,
     IsChildOfFilterMatch,
     IsParentOfFilterMatch,
