@@ -18,22 +18,24 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 6521 2006-05-03 01:02:54Z rshura $
+# $Id: __init__.py 9928 2008-01-24 20:38:10Z acraphae $
 
 """
 Package providing filter rules for GRAMPS.
 """
 
-__author__ = "Don Allingham"
-
 from _AllPlaces import AllPlaces
 from _HasIdOf import HasIdOf
 from _RegExpIdOf import RegExpIdOf
 from _HasNoteRegexp import HasNoteRegexp
 from _HasNoteMatchingSubstringOf import HasNoteMatchingSubstringOf
+from _HasReferenceCountOf import HasReferenceCountOf
 from _PlacePrivate import PlacePrivate
 from _MatchesFilter import MatchesFilter
 from _HasPlace import HasPlace
+from _HasNoLatOrLon import HasNoLatOrLon
+from _InLatLonNeighborhood import InLatLonNeighborhood
+from _MatchesEventFilter import MatchesEventFilter
 
 editor_rule_list = [
     AllPlaces,
@@ -41,6 +43,11 @@ editor_rule_list = [
     RegExpIdOf,
     HasNoteRegexp,
     HasNoteMatchingSubstringOf,
+    HasReferenceCountOf,
     PlacePrivate,
     MatchesFilter,
+    HasPlace,
+    HasNoLatOrLon,
+    InLatLonNeighborhood,
+    MatchesEventFilter,
 ]
