@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasEvent.py 6635 2006-05-13 03:53:06Z dallingham $
+# $Id: _HasMarkerBase.py 10094 2008-02-22 10:50:06Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -32,8 +32,8 @@ from gettext import gettext as _
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from RelLib import MarkerType
-from Filters.Rules._Rule import Rule
+from gen.lib import MarkerType
+from Filters.Rules import Rule
 
 #-------------------------------------------------------------------------
 #
@@ -41,15 +41,15 @@ from Filters.Rules._Rule import Rule
 #
 #-------------------------------------------------------------------------
 class HasMarkerBase(Rule):
-    """Rule that checks for a person with a particular value"""
+    """Rule that checks for a person with a particular value."""
 
 
     labels      = [ _('Marker type:')]
     name        =  _('Has marker of')
-    description =  _("Matches markers of a particular type")
+    description =  _("Matches markers of a partikular type")
     category    = _('General filters')
     
-    def apply(self,db,obj):
+    def apply(self, db, obj):
         specified_type = MarkerType()
         specified_type.set_from_xml_str(self.list[0])
         return obj.get_marker() == specified_type
