@@ -18,28 +18,22 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 7233 2006-08-22 16:49:21Z rshura $
+# $Id:__init__.py 9912 2008-01-22 09:17:46Z acraphae $
 
 """
 Package providing filter rules for GRAMPS.
 """
 
-__author__ = "Don Allingham"
-
 # Need to expose this to be available for filter plugins:
 # the plugins should say: from Filters.Rules import Rule
-from _Rule import Rule
+from Filters.Rules._Rule import Rule
 
-from _Everything import Everything
-from _HasGrampsId import HasGrampsId
-from _IsPrivate import IsPrivate
-from _HasTextMatchingSubstringOf import HasTextMatchingSubstringOf
-from _HasTextMatchingRegexpOf import HasTextMatchingRegexpOf
+from Filters.Rules._Everything import Everything
+from Filters.Rules._HasGrampsId import HasGrampsId
+from Filters.Rules._IsPrivate import IsPrivate
+from Filters.Rules._HasTextMatchingSubstringOf import HasTextMatchingSubstringOf
+from Filters.Rules._HasTextMatchingRegexpOf import HasTextMatchingRegexpOf
+from Filters.Rules._MatchesFilterBase import MatchesFilterBase
 
-import Person
-import Family
-import Event
-import Source
-import Place
-import MediaObject
-import Repository
+from Filters.Rules import (Person, Family, Event, Source, Place, MediaObject, 
+                           Repository, Note)
