@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _RepoSidebarFilter.py 7866 2007-01-04 05:09:41Z dallingham $
+# $Id: _RepoSidebarFilter.py 10338 2008-03-19 11:26:08Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -40,11 +40,13 @@ import gtk
 #
 #-------------------------------------------------------------------------
 import GrampsWidgets
-from RelLib import Repository, RepositoryType
+from gen.lib import Repository, RepositoryType
 
-from _SidebarFilter import SidebarFilter
+from Filters.SideBar import SidebarFilter
 from Filters import GenericFilterFactory, build_filter_model, Rules
-from Filters.Rules.Repository import *
+from Filters.Rules.Repository import (RegExpIdOf, HasIdOf, HasRepo, 
+                                      HasNoteRegexp, MatchesFilter, 
+                                      HasNoteMatchingSubstringOf)
 
 GenericRepoFilter = GenericFilterFactory('Repository')
 #-------------------------------------------------------------------------
@@ -54,11 +56,8 @@ GenericRepoFilter = GenericFilterFactory('Repository')
 #-------------------------------------------------------------------------
 class RepoSidebarFilter(SidebarFilter):
 
-    def __init__(self,uistate, clicked):
-        SidebarFilter.__init__(self,uistate)
+    def __init__(self, dbstate, uistate, clicked):
         self.clicked_func = clicked
-
-    def create_widget(self):
         self.filter_id = gtk.Entry()
         self.filter_title = gtk.Entry()       
         self.filter_address = gtk.Entry()
@@ -76,10 +75,16 @@ class RepoSidebarFilter(SidebarFilter):
 
         self.filter_regex = gtk.CheckButton(_('Use regular expressions'))
 
-	self.generic = gtk.ComboBox()
-	cell = gtk.CellRendererText()
-	self.generic.pack_start(cell, True)
-	self.generic.add_attribute(cell, 'text', 0)
+        self.generic = gtk.ComboBox()
+
+        SidebarFilter.__init__(self, dbstate, uistate)
+
+    def create_widget(self):
+        cell = gtk.CellRendererText()
+        cell.set_property('width', self._FILTER_WIDTH)
+        cell.set_property('ellipsize', self._FILTER_ELLIPSIZE)
+        self.generic.pack_start(cell, True)
+        self.generic.add_attribute(cell, 'text', 0)
         self.on_filters_changed('Repository')
 
         self.add_text_entry(_('ID'), self.filter_id)
@@ -108,7 +113,7 @@ class RepoSidebarFilter(SidebarFilter):
         rtype = self.repo.get_type().xml_str()
         note = unicode(self.filter_note.get_text()).strip()
         regex = self.filter_regex.get_active()
-	gen = self.generic.get_active() > 0
+        gen = self.generic.get_active() > 0
 
         empty = not (gid or title or address or url or rtype
                      or note or regex or gen)
@@ -123,7 +128,7 @@ class RepoSidebarFilter(SidebarFilter):
                     rule = HasIdOf([gid])
                 generic_filter.add_rule(rule)
 
-            rule = HasRepo([title,rtype,address,url])
+            rule = HasRepo([title, rtype, address, url])
             generic_filter.add_rule(rule)
                 
             if note:
@@ -133,19 +138,20 @@ class RepoSidebarFilter(SidebarFilter):
                     rule = HasNoteMatchingSubstringOf([note])
                 generic_filter.add_rule(rule)
 
-	    if self.generic.get_active() != 0:
-		model = self.generic.get_model()
-		node = self.generic.get_active_iter()
-		obj = model.get_value(node, 0)
-		rule = MatchesFilter([obj])
-		generic_filter.add_rule(rule)
+        if self.generic.get_active() != 0:
+            model = self.generic.get_model()
+            node = self.generic.get_active_iter()
+            obj = model.get_value(node, 0)
+            rule = MatchesFilter([obj])
+            generic_filter.add_rule(rule)
 
         return generic_filter
         
-    def on_filters_changed(self,name_space):
+    def on_filters_changed(self, name_space):
         if name_space == 'Repository':
-            all = GenericRepoFilter()
-            all.set_name(_("None"))
-            all.add_rule(Rules.Repository.AllRepos([]))
-            self.generic.set_model(build_filter_model('Repository', [all]))
+            all_filter = GenericRepoFilter()
+            all_filter.set_name(_("None"))
+            all_filter.add_rule(Rules.Repository.AllRepos([]))
+            self.generic.set_model(build_filter_model('Repository', 
+                                                      [all_filter]))
             self.generic.set_active(0)
