@@ -18,35 +18,55 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _SidebarFilter.py 7948 2007-01-21 21:32:53Z dallingham $
+# $Id: _SidebarFilter.py 10338 2008-03-19 11:26:08Z bmcage $
 
 from gettext import gettext as _
 import gtk
+import pango
+
 import GrampsWidgets
+import Config
 
 _RETURN = gtk.gdk.keyval_from_name("Return")
+_KP_ENTER = gtk.gdk.keyval_from_name("KP_Enter")
 
 class SidebarFilter:
+    _FILTER_WIDTH = 200
+    _FILTER_ELLIPSIZE = pango.ELLIPSIZE_END
 
-    def __init__(self,uistate):
+    def __init__(self, dbstate, uistate):
         self.position = 1
-        self.table = gtk.Table(3,11)
+        self.table = gtk.Table(4, 11)
         self.table.set_border_width(6)
         self.table.set_row_spacings(6)
-        self.table.set_col_spacing(0,6)
-        self.table.set_col_spacing(1,6)
+        self.table.set_col_spacing(0, 6)
+        self.table.set_col_spacing(1, 6)
         self.tooltips = gtk.Tooltips()
+        self.apply_btn = gtk.Button(stock=gtk.STOCK_FIND)
+        self.clear_btn = gtk.Button()
+        
         self._init_interface()
-        uistate.connect('filters-changed',self.on_filters_changed)
+        uistate.connect('filters-changed', self.on_filters_changed)
         self.uistate = uistate
+        self.dbstate = dbstate
 
     def _init_interface(self):
         self.table.attach(GrampsWidgets.MarkupLabel(_('<b>Filter</b>')),
-                          0, 3, 0, 1, xoptions=gtk.FILL, yoptions=0)
+                          0, 2, 0, 1, xoptions=gtk.FILL|gtk.EXPAND, yoptions=0)
+        btn = gtk.Button()
+        img = gtk.image_new_from_stock(gtk.STOCK_CLOSE, gtk.ICON_SIZE_MENU)
+        box = gtk.HBox()
+        btn.set_image(img)
+        btn.set_relief(gtk.RELIEF_NONE)
+        btn.set_alignment(1.0, 0.5)
+        box.pack_start(gtk.Label(''), expand=True, fill=True)
+        box.pack_end(btn, fill=False, expand=False)
+        box.show_all()
+        self.table.attach(box, 2, 4, 0, 1, yoptions=0)
+        btn.connect('clicked', self.btn_clicked)
 
         self.create_widget()
 
-        self.apply_btn = gtk.Button(stock=gtk.STOCK_FIND)
         self.apply_btn.connect('clicked', self.clicked)
 
         hbox = gtk.HBox()
@@ -56,11 +76,10 @@ class SidebarFilter:
         image.show()
         label = gtk.Label(_('Reset'))
         label.show()
-        hbox.pack_start(image,False,False)
-        hbox.pack_start(label,False,True)
+        hbox.pack_start(image, False, False)
+        hbox.pack_start(label, False, True)
         hbox.set_spacing(4)
         
-        self.clear_btn = gtk.Button()
         self.clear_btn.add(hbox)
         self.clear_btn.connect('clicked', self.clear)
 
@@ -69,9 +88,13 @@ class SidebarFilter:
         hbox.add(self.apply_btn)
         hbox.add(self.clear_btn)
         hbox.show()
-        self.table.attach(hbox, 2, 3, self.position, self.position+1,
+        self.table.attach(hbox, 2, 4, self.position, self.position+1,
                           xoptions=gtk.FILL, yoptions=0)
 
+    def btn_clicked(self, obj):
+        Config.set(Config.FILTER, False)
+        Config.sync()
+
     def get_widget(self):
         return self.table
 
@@ -94,13 +117,14 @@ class SidebarFilter:
 
     def add_text_entry(self, name, widget, tooltip=None):
         self.add_entry(name, widget)
-        widget.connect('key-press-event',self.key_press)
+        widget.connect('key-press-event', self.key_press)
         if tooltip:
             self.tooltips.set_tip(widget, tooltip)
 
     def key_press(self, obj, event):
-        if event.keyval == _RETURN and not event.state:
-            self.clicked(obj)
+        if not event.state or event.state in (gtk.gdk.MOD2_MASK,):
+            if event.keyval in (_RETURN, _KP_ENTER):
+                self.clicked(obj)
         return False
 
     def add_entry(self, name, widget):
@@ -108,10 +132,10 @@ class SidebarFilter:
             self.table.attach(GrampsWidgets.BasicLabel(name),
                               1, 2, self.position, self.position+1,
                               xoptions=gtk.FILL, yoptions=0)
-        self.table.attach(widget, 2, 3, self.position, self.position+1,
+        self.table.attach(widget, 2, 4, self.position, self.position+1,
                           xoptions=gtk.FILL, yoptions=0)
         self.position += 1
 
-    def on_filters_changed(self,namespace):
+    def on_filters_changed(self, namespace):
         pass
 
