@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _PluginMgr.py 7976 2007-01-25 03:22:46Z pez4brian $
+# $Id: _PluginMgr.py 10103 2008-02-24 13:55:55Z acraphae $
 
 """
 The core of the GRAMPS plugin system. This module provides tasks to load
@@ -50,10 +50,11 @@ from ReportBase import MODE_GUI, MODE_CLI, MODE_BKI, book_categories
 # Global lists
 #
 #-------------------------------------------------------------------------
-report_list = []
-tool_list   = []
-import_list = []
-export_list = []
+report_list       = []
+quick_report_list = []
+tool_list    = []
+import_list  = []
+export_list  = []
 attempt_list = []
 loaddir_list = []
 textdoc_list = []
@@ -61,7 +62,7 @@ bookdoc_list = []
 drawdoc_list = []
 failmsg_list = []
 bkitems_list = []
-cl_list = []
+cl_list      = []
 cli_tool_list = []
 success_list = []
 
@@ -92,13 +93,13 @@ def load_plugins(direct):
     modules that it finds, adding name to the attempt_lists list. If the module
     successfully loads, it is added to the success_list list. Each plugin is
     responsible for registering itself in the correct manner. No attempt
-    is done in this routine to register the tasks."""
+    is done in this routine to register the tasks. Returns True on error. """
     
     global success_list,attempt_list,loaddir_list,failmsg_list
 
     # if the directory does not exist, do nothing
     if not os.path.isdir(direct):
-        return True
+        return False # return value is True for error
 
     # if the path has not already been loaded, save it in the loaddir_list
     # list for use on reloading
@@ -129,37 +130,34 @@ def load_plugins(direct):
         except:
             failmsg_list.append((filename,sys.exc_info()))
 
-    if len(failmsg_list):
-        return False
-    else:
-        return True
+    return len(failmsg_list) != 0 # return True if there are errors
 
 #-------------------------------------------------------------------------
 #
 # Plugin registering
 #
 #-------------------------------------------------------------------------
-def register_export(exportData,title,description='',config=None,filename=''):
+def register_export(exportData, title, description='', config=None, filename=''):
     """
     Register an export filter, taking the task, file filter, 
     and the list of patterns for the filename matching.
     """
     if description and filename:
         del_index = -1
-        for i in range(0,len(export_list)):
+        for i in range(0, len(export_list)):
             if export_list[i][1] == title:
                 del_index = i
         if del_index != -1:
             del export_list[del_index]
 
-        export_list.append((exportData,title,description,config,filename))
+        export_list.append((exportData, title, description, config, filename))
         mod2text[exportData.__module__] = description
 
 def register_import(task, ffilter, mime=None, native_format=0, format_name=""):
     """Register an import filter, taking the task and file filter"""
     if mime:
         del_index = -1
-        for i in range(0,len(import_list)):
+        for i in range(0, len(import_list)):
             if import_list[i][2] == mime:
                 del_index = i
         if del_index != -1:
@@ -200,17 +198,17 @@ def register_tool(
 
     (junk,gui_task) = divmod(modes,2**_Tool.MODE_GUI)
     if gui_task:
-        _register_gui_tool(tool_class,options_class,translated_name,
+        _register_gui_tool(tool_class, options_class,translated_name,
                            name,category,description,
                            status,author_name,author_email,unsupported,
                            require_active)
 
     (junk,cli_task) = divmod(modes-gui_task,2**_Tool.MODE_CLI)
     if cli_task:
-        _register_cli_tool(name,category,tool_class,options_class,
+        _register_cli_tool(name,category,tool_class, options_class,
                            translated_name,unsupported)
 
-def _register_gui_tool(tool_class,options_class,translated_name,
+def _register_gui_tool(tool_class, options_class,translated_name,
                        name,category,
                        description=_unavailable,
                        status=_("Unknown"),
@@ -226,11 +224,11 @@ def _register_gui_tool(tool_class,options_class,translated_name,
     if del_index != -1:
         del tool_list[del_index]
     mod2text[tool_class.__module__] = description
-    tool_list.append((tool_class,options_class,translated_name,
-                      category,name,description,status,
+    tool_list.append((tool_class, options_class,translated_name,
+                      category, name,description,status,
                       author_name,author_email,unsupported, require_active))
 
-def _register_cli_tool(name,category,tool_class,options_class,
+def _register_cli_tool(name,category,tool_class, options_class,
                        translated_name,unsupported=False):
     del_index = -1
     for i in range(0,len(cli_tool_list)):
@@ -239,7 +237,7 @@ def _register_cli_tool(name,category,tool_class,options_class,
             del_index = i
     if del_index != -1:
         del cli_tool_list[del_index]
-    cli_tool_list.append((name,category,tool_class,options_class,
+    cli_tool_list.append((name,category,tool_class, options_class,
                           translated_name,unsupported, None))
 
 #-------------------------------------------------------------------------
@@ -271,7 +269,7 @@ def register_report(
     """
     (junk,standalone_task) = divmod(modes,2**MODE_GUI)
     if standalone_task:
-        _register_standalone(report_class,options_class,translated_name,
+        _register_standalone(report_class, options_class,translated_name,
                              name,category,description,
                              status,author_name,author_email,unsupported,
                              require_active)
@@ -280,28 +278,21 @@ def register_report(
     if book_item_task:
         book_item_category = book_categories[category]
         register_book_item(translated_name,book_item_category,
-                           report_class,options_class,name,unsupported,
+                           report_class, options_class, name,unsupported,
                            require_active)
 
     (junk,command_line_task) = divmod(modes-standalone_task-book_item_task,
                                         2**MODE_CLI)
     if command_line_task:
-        _register_cl_report(name,category,report_class,options_class,
+        _register_cl_report(name,category,report_class, options_class,
                             translated_name,unsupported, require_active)
 
-def _register_standalone(report_class,
-                         options_class,
-                         translated_name, 
-                         name,
-                         category,
-                         description=_unavailable,
-                         status=_("Unknown"),
-                         author_name=_("Unknown"),
-                         author_email=_("Unknown"),
-                         unsupported=False,
-                         require_active=True,
-                         ):
-    """Register a report with the plugin system"""
+def _register_standalone(report_class, options_class, translated_name, name,
+                         category, description=_unavailable, 
+                         status=_("Unknown"), author_name=_("Unknown"),
+                         author_email=_("Unknown"), unsupported=False,
+                         require_active=True):
+    """Register a report with the plugin system."""
     
     del_index = -1
     for i in range(0,len(report_list)):
@@ -312,14 +303,13 @@ def _register_standalone(report_class,
         del report_list[del_index]
 
     report_list.append((report_class, options_class, translated_name, 
-                        category, name, description, status,
-                        author_name, author_email, unsupported,
-                        require_active))
+                        category, name, description, status, author_name, 
+                        author_email, unsupported, require_active))
     mod2text[report_class.__module__] = description
 
 def register_book_item(translated_name, category, report_class,
                         option_class, name, unsupported, require_active):
-    """Register a book item"""
+    """Register a book item."""
     
     del_index = -1
     for i in range(0,len(bkitems_list)):
@@ -332,8 +322,8 @@ def register_book_item(translated_name, category, report_class,
     bkitems_list.append((translated_name, category, report_class,
                          option_class, name, unsupported, require_active))
 
-def _register_cl_report(name,category,report_class,options_class,
-                        translated_name,unsupported, require_active):
+def _register_cl_report(name, category, report_class, options_class,
+                        translated_name, unsupported, require_active):
     del_index = -1
     for i in range(0,len(cl_list)):
         val = cl_list[i]
@@ -341,8 +331,8 @@ def _register_cl_report(name,category,report_class,options_class,
             del_index = i
     if del_index != -1:
         del cl_list[del_index]
-    cl_list.append((name,category,report_class,options_class,
-                    translated_name,unsupported, require_active))
+    cl_list.append((name, category, report_class, options_class,
+                    translated_name, unsupported, require_active))
 
 #-------------------------------------------------------------------------
 #
@@ -350,8 +340,8 @@ def _register_cl_report(name,category,report_class,options_class,
 #
 #-------------------------------------------------------------------------
 def register_text_doc(name,classref, table, paper, style, ext,
-                      print_report_label=None,clname=''):
-    """Register a text document generator"""
+                      print_report_label=None, clname=''):
+    """Register a text document generator."""
     del_index = -1
     for i in range(0,len(textdoc_list)):
         val = textdoc_list[i]
@@ -410,47 +400,89 @@ def register_draw_doc(name,classref,paper,style, ext,
                          print_report_label, clname))
     mod2text[classref.__module__] = name
 
+#-------------------------------------------------------------------------
+#
+# Quick Report registration
+#
+#-------------------------------------------------------------------------
+def register_quick_report(
+    name,
+    category,
+    run_func,
+    translated_name,
+    status=_("Unknown"),
+    description=_unavailable,
+    author_name=_("Unknown"),
+    author_email=_("Unknown"),
+    unsupported=False,
+    ):
+    """
+    Registers quick report for all possible objects.
+
+    This function should be used to register a quick report 
+    so it appears in the quick report context menu of the object it is
+    attached to.
+    The low-level functions (starting with '_') should not be used
+    on their own. Instead, this function will call them as needed.
+    """
+    """Register a report with the plugin system"""
+    global quick_report_list
+    
+    del_index = -1
+    for i in range(0,len(quick_report_list)):
+        val = quick_report_list[i]
+        if val[3] == name:
+            del_index = i
+    if del_index != -1:
+        del quick_report_list[del_index]
+
+    quick_report_list.append((run_func, translated_name, 
+                        category, name, description, status,
+                        author_name, author_email, unsupported))
+                        
+    mod2text[run_func.__module__] = description
+
 #-------------------------------------------------------------------------
 #
 # Remove plugins whose reloading failed from the already-registered lists
 #
 #-------------------------------------------------------------------------
-def purge_failed(failed_list,export_list,import_list,tool_list,cli_tool_list,
-                 report_list,bkitems_list,cl_list,textdoc_list,bookdoc_list,
-                 drawdoc_list):
+def purge_failed():
+                
+    global report_list, quick_report_list, tool_list, import_list, export_list,\
+            textdoc_list, bookdoc_list, drawdoc_list, bkitems_list, cl_list, \
+            cli_tool_list, failmsg_list
+
     failed_module_names = [
         os.path.splitext(os.path.basename(filename))[0]
-        for filename,junk in failed_list
+        for filename,junk in failmsg_list
         ]
 
-    export_list = [ item for item in export_list
-                    if item[0].__module__ not in failed_module_names ]
-    import_list = [ item for item in import_list
-                    if item[0].__module__ not in failed_module_names ]
-    tool_list = [ item for item in tool_list
-                  if item[0].__module__ not in failed_module_names ]
-    cli_tool_list = [ item for item in cli_tool_list
-                      if item[2].__module__ not in failed_module_names ]
-    report_list = [ item for item in report_list
-                    if item[0].__module__ not in failed_module_names ]
-    bkitems_list = [ item for item in bkitems_list
-                     if item[2].__module__ not in failed_module_names ]
-    cl_list = [ item for item in cl_list
-                if item[2].__module__ not in failed_module_names ]
-    textdoc_list = [ item for item in textdoc_list
-                     if item[1].__module__ not in failed_module_names ]
-    bookdoc_list = [ item for item in bookdoc_list
-                     if item[1].__module__ not in failed_module_names ]
-    drawdoc_list = [ item for item in drawdoc_list
-                     if item[1].__module__ not in failed_module_names ]
+    #although these are global variables, we may not change the pointer of 
+    # the list, as __init__.py already contains these, see comment there
+    export_list[:] = [ item for item in export_list
+                    if item[0].__module__ not in failed_module_names ][:]
+    import_list[:] = [ item for item in import_list
+                    if item[0].__module__ not in failed_module_names ][:]
+    tool_list[:] = [ item for item in tool_list
+                  if item[0].__module__ not in failed_module_names ][:]
+    cli_tool_list[:] = [ item for item in cli_tool_list
+                      if item[2].__module__ not in failed_module_names ][:]
+    report_list[:] = [ item for item in report_list
+                    if item[0].__module__ not in failed_module_names ][:]
+    quick_report_list[:] = [ item for item in quick_report_list
+                    if item[0].__module__ not in failed_module_names ][:]
+    bkitems_list[:] = [ item for item in bkitems_list
+                     if item[2].__module__ not in failed_module_names ][:]
+    cl_list[:] = [ item for item in cl_list
+                if item[2].__module__ not in failed_module_names ][:]
+    textdoc_list[:] = [ item for item in textdoc_list
+                     if item[1].__module__ not in failed_module_names ][:]
+    bookdoc_list[:] = [ item for item in bookdoc_list
+                     if item[1].__module__ not in failed_module_names ][:]
+    drawdoc_list[:] = [ item for item in drawdoc_list
+                     if item[1].__module__ not in failed_module_names ][:]
 
-    # For some funky reason this module's global variables
-    # are not seen inside this function. But they are seen
-    # from other modules, so we pass them back and forth.
-    # Sucks, but I don't know why this happens :-(
-    return (export_list,import_list,tool_list,cli_tool_list,
-            report_list,bkitems_list,cl_list,textdoc_list,bookdoc_list,
-            drawdoc_list)
 
 #-------------------------------------------------------------------------
 #
@@ -467,9 +499,9 @@ def register_relcalc(relclass, languages):
     except:
         pass
 
-def relationship_class(db):
+def relationship_class():
     global _relcalc_class
-    return _relcalc_class(db)
+    return _relcalc_class()
 
 #-------------------------------------------------------------------------
 #
