@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2001-2006  Donald N. Allingham
+# Copyright (C) 2001-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _BareReportDialog.py 7862 2006-12-31 23:56:14Z dallingham $
+# $Id: _BareReportDialog.py 10473 2008-04-05 12:41:26Z pez4brian $
 
 #-------------------------------------------------------------------------
 #
@@ -40,12 +40,10 @@ import gtk
 # gramps modules
 #
 #-------------------------------------------------------------------------
-import NameDisplay
+from BasicUtils import name_displayer
 import BaseDoc
-import Utils
 
 import ManagedWindow
-from Filters import FilterComboBox,Rules
 from _StyleComboBox import StyleComboBox
 from _StyleEditor import StyleListDisplay
 
@@ -53,6 +51,13 @@ import logging
 
 log = logging.getLogger(".")
 
+#-------------------------------------------------------------------------
+#
+# Private Constants
+#
+#-------------------------------------------------------------------------
+URL_REPORT_PAGE = "Gramps_3.0_Wiki_Manual_-_Reports"
+
 #-------------------------------------------------------------------------
 #
 # BareReportDialog class
@@ -70,47 +75,37 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
 
     frame_pad = 5
     border_pad = 6
-    HELP_TOPIC = None
 
-    def __init__(self,dbstate,uistate,person,option_class,
-                 name,translated_name,track=[]):
+    def __init__(self, dbstate, uistate, option_class,
+                 name, translated_name, track=[]):
         """Initialize a dialog to request that the user select options
         for a basic *bare* report."""
-
-        self.dbstate = dbstate
-        self.uistate = uistate
-        self.db = dbstate.db
-        self.person = person
-        self.report_name = translated_name
         self.raw_name = name
-
+        self.dbstate = dbstate
+        self.db = dbstate.db
+        self.report_name = translated_name
+        
         ManagedWindow.ManagedWindow.__init__(self, uistate, track, self)
 
+        self.init_options(option_class)
+        self.init_interface()
+        
+    def init_options(self, option_class):
         if type(option_class) == ClassType:
-            self.options = option_class(name)
+            self.options = option_class(self.raw_name, self.db)
         elif type(option_class) == InstanceType:
             self.options = option_class
 
-        self.init_interface()
+        self.options.load_previous_values()
 
-    def build_window_key(self,obj):
+    def build_window_key(self, obj):
         key = self.raw_name
-        if self.person:
-            key += self.person.get_handle()
         return key
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (_("Configuration"),self.report_name)
 
     def init_interface(self):
-        #self.output_notebook = None
-        #self.notebook_page = 1
-        self.pagecount_menu = None
-        self.filter_combo = None
-        self.extra_menu = None
-        self.extra_textbox = None
-        self.pagebreak_checkbox = None
-        self.generations_spinbox = None
         self.widgets = []
         self.frame_names = []
         self.frames = {}
@@ -118,20 +113,14 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         self.style_button = None
 
         self.style_name = self.options.handler.get_default_stylesheet_name()
-        (self.max_gen,self.page_breaks) = \
-                                 self.options.handler.get_report_generations()
-        try:
-            self.local_filters = self.options.get_report_filters(self.person)
-        except AttributeError:
-            self.local_filters = []
 
         window = gtk.Dialog('GRAMPS')
         self.set_window(window,None,self.get_title())
         self.window.set_has_separator(False)
+        self.window.set_modal(True)
 
-        if self.HELP_TOPIC:
-            self.help = self.window.add_button(gtk.STOCK_HELP, gtk.RESPONSE_HELP)
-            self.help.connect('clicked',self.on_help_clicked)
+        self.help = self.window.add_button(gtk.STOCK_HELP, gtk.RESPONSE_HELP)
+        self.help.connect('clicked',self.on_help_clicked)
 
         self.cancel = self.window.add_button(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL)
         self.cancel.connect('clicked',self.on_cancel)
@@ -158,22 +147,20 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         # frame and to create other frames
         self.add_user_options()
 
-        self.setup_center_person()
+        self.setup_main_options()
         self.setup_target_frame()
         self.setup_format_frame()
         self.setup_style_frame()
-        #self.setup_output_notebook()
-        
+
         self.notebook = gtk.Notebook()
+        self.notebook.set_scrollable(True)
         self.notebook.set_border_width(6)
         self.window.vbox.add(self.notebook)
 
-        self.setup_paper_frame()
-        self.setup_html_frame()
         self.setup_report_options_frame()
         self.setup_other_frames()
         self.notebook.set_current_page(0)
-        self.window.show_all()
+        self.show()
 
     def get_title(self):
         """The window title for this dialog"""
@@ -200,39 +187,6 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         created when needed.  All subclasses should probably override
         this function."""
         return "basic_report.xml"
-
-    def get_report_filters(self):
-        """Return the data used to fill out the 'filter' combo box in
-        the report options box.  The return value is the list of
-        strings to be inserted into the pulldown."""
-        return []
-    
-    def get_report_generations(self):
-        """Return the default number of generations to start the
-        spinbox (zero to disable) and whether or not to include the
-        'page break between generations' check box"""
-        return (10, 1)
-    
-    def get_report_extra_menu_info(self):
-        """Return the data used to fill out the 'extra' option menu in
-        the report options box.  The first value is the string to be
-        used as the label to the left of the menu.  The second value
-        is a mapping of string:value pairs.  The strings will be used
-        to label individual menu items, and the values are what will
-        be returned if a given menu item is selected.  The third value
-        is the name of menu item to pre-select, and the final value is
-        a string to use as the tooltip for the textbox."""
-        return (None, None, None, None)
-    
-    def get_report_extra_textbox_info(self):
-        """Return the data used to fill out the 'extra' textbox in the
-        report options dialog.  The first value is the string to be
-        used as the label to the left of the textbox.  The second
-        value is the string to use as the default contents of the
-        textbox.  If None, then the text box will be hidden.  The
-        final value is a string to use as the tooltip for the
-        textbox."""
-        return (None, None, None)
     
     #------------------------------------------------------------------------
     #
@@ -316,10 +270,7 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         """Set up the title bar of the dialog.  This function relies
         on the get_title() customization function for what the title
         should be."""
-        if self.person:
-            self.name = NameDisplay.displayer.display(self.person)
-        else:
-            self.name = ''
+        self.name = ''
         self.window.set_title(self.get_title())
 
     def setup_header(self):
@@ -345,33 +296,19 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         self.tbl.attach(label, 0, 4, self.col, self.col+1, gtk.FILL|gtk.EXPAND)
         self.col += 1
 
-    def setup_center_person(self): 
-        """Set up center person labels and change button. 
-        Should be overwritten by standalone report dialogs. """
-
-        center_label = gtk.Label("<b>%s</b>" % _("Center Person"))
-        center_label.set_use_markup(True)
-        center_label.set_alignment(0.0,0.5)
-        self.tbl.set_border_width(12)
-        self.tbl.attach(center_label,0,4,self.col,self.col+1)
-        self.col += 1
-
-        name = NameDisplay.displayer.display(self.person)
-        self.person_label = gtk.Label( "%s" % name )
-        self.person_label.set_alignment(0.0,0.5)
-        self.tbl.attach(self.person_label,2,3,self.col,self.col+1)
-        
-        change_button = gtk.Button("%s..." % _('C_hange') )
-        change_button.connect('clicked',self.on_center_person_change_clicked)
-        self.tbl.attach(change_button,3,4,self.col,self.col+1,gtk.SHRINK)
-        self.col += 1
-
     def setup_style_frame(self):
         """Set up the style frame of the dialog.  This function relies
         on other routines create the default style for this report,
         and to read in any user defined styles for this report.  It
         the builds a menu of all the available styles for the user to
         choose from."""
+        # Build the default style set for this report.
+        self.default_style = BaseDoc.StyleSheet()
+        self.options.make_default_style(self.default_style)
+
+        if self.default_style.is_empty():
+            # Don't display the option of no styles are used
+            return
 
         # Styles Frame
         label = gtk.Label("%s:" % _("Style"))
@@ -388,10 +325,6 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
                         xoptions=gtk.SHRINK|gtk.FILL,yoptions=gtk.SHRINK)
         self.col += 1
         
-        # Build the default style set for this report.
-        self.default_style = BaseDoc.StyleSheet()
-        self.options.make_default_style(self.default_style)
-
         # Build the initial list of available styles sets.  This
         # includes the default style set and any style sets saved from
         # previous invocations of gramps.
@@ -408,26 +341,11 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         function relies on several report_xxx() customization
         functions to determine which of the items should be present in
         this box.  *All* of these items are optional, although the
-        generations fields and the filter combo box are used in most
+        generations fields is used in most
         (but not all) dialog boxes."""
 
-        (em_label, extra_map, preset, em_tip) = self.get_report_extra_menu_info()
-        (et_label, string, et_tip) = self.get_report_extra_textbox_info()
-
         row = 0
-        max_rows = 0
-        if self.max_gen:
-            max_rows = max_rows + 2
-            #if self.page_breaks:
-            #    max_rows = max_rows + 1
-        if len(self.local_filters):
-            max_rows = max_rows + 1
-        if extra_map:
-            max_rows = max_rows + 1
-        if string:
-            max_rows = max_rows + 1
-
-        max_rows = max_rows + len(self.widgets)
+        max_rows = len(self.widgets)
 
         if max_rows == 0:
             return
@@ -444,76 +362,6 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         self.notebook.append_page(table,label)
         row += 1
 
-        if len(self.local_filters):
-            self.filter_combo = FilterComboBox()
-            label = gtk.Label("%s:" % _("Filter"))
-            label.set_alignment(0.0,0.5)
-            table.attach(label, 1, 2, row, row+1, gtk.SHRINK|gtk.FILL,
-                         gtk.SHRINK|gtk.FILL)
-            table.attach(self.filter_combo, 2, 3, row, row+1,
-                         gtk.SHRINK|gtk.FILL,gtk.SHRINK|gtk.FILL)
-
-            self.filter_combo.set(self.local_filters)
-            self.filter_combo.set_active(self.options.handler.get_filter_number())
-            row += 1
-            
-        # Set up the generations spin and page break checkbox
-        if self.max_gen:
-            self.generations_spinbox = gtk.SpinButton(digits=0)
-            self.generations_spinbox.set_numeric(1)
-            adjustment = gtk.Adjustment(self.max_gen,1,999,1,0)
-            self.generations_spinbox.set_adjustment(adjustment)
-            adjustment.value_changed()
-            label = gtk.Label("%s:" % _("Generations"))
-            label.set_alignment(0.0,0.5)
-            table.attach(label, 1, 2, row, row+1,
-                         gtk.SHRINK|gtk.FILL, gtk.SHRINK|gtk.FILL)
-            table.attach(self.generations_spinbox, 2, 3, row, row+1,
-                         gtk.EXPAND|gtk.FILL,gtk.SHRINK|gtk.FILL)
-            row += 1
-
-            #if self.page_breaks:
-            msg = _("Page break between generations")
-            self.pagebreak_checkbox = gtk.CheckButton(msg)
-            self.pagebreak_checkbox.set_active(self.page_breaks)
-            table.attach(self.pagebreak_checkbox,2,3,row,row+1,
-                         yoptions=gtk.SHRINK)
-            row += 1
-
-        # Now the "extra" option menu
-        if extra_map:
-            self.extra_menu_label = gtk.Label("%s:" % em_label)
-            self.extra_menu_label.set_alignment(0.0,0.5)
-            self.extra_menu = gtk.OptionMenu()
-            myMenu = Utils.build_string_optmenu(extra_map, preset)
-            self.extra_menu.set_menu(myMenu)
-            self.extra_menu.set_sensitive(len(extra_map) > 1)
-            self.add_tooltip(self.extra_menu,em_tip)
-            table.attach(self.extra_menu_label, 1, 2, row, row+1,
-                         gtk.SHRINK|gtk.FILL, gtk.SHRINK)
-            table.attach(self.extra_menu, 2, 3, row, row+1,
-                         yoptions=gtk.SHRINK)
-            row += 1
-            
-        # Now the "extra" text box
-        if string:
-            self.extra_textbox_label = gtk.Label("%s:" % et_label)
-            self.extra_textbox_label.set_alignment(0.0,0)
-            swin = gtk.ScrolledWindow()
-            swin.set_shadow_type(gtk.SHADOW_IN)
-            swin.set_policy(gtk.POLICY_AUTOMATIC,gtk.POLICY_AUTOMATIC)
-            self.extra_textbox = gtk.TextView()
-            swin.add(self.extra_textbox)
-
-            self.extra_textbox.get_buffer().set_text('\n'.join(string))
-            self.extra_textbox.set_editable(1)
-            self.add_tooltip(self.extra_textbox,et_tip)
-            table.attach(self.extra_textbox_label, 1, 2, row, row+1,
-                         gtk.SHRINK|gtk.FILL,gtk.SHRINK)
-            table.attach(swin, 2, 3, row, row+1,
-                         yoptions=gtk.SHRINK)
-            row += 1
-
         # Setup requested widgets
         for (text,widget) in self.widgets:
             if text:
@@ -530,6 +378,8 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
 
     def setup_other_frames(self):
         for key in self.frame_names:
+            if key == "":
+                continue
             flist = self.frames[key]
             table = gtk.Table(3,len(flist))
             table.set_col_spacings(12)
@@ -552,6 +402,22 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
                     table.attach(widget, 2, 3, row, row+1,
                                  yoptions=gtk.SHRINK)
                 row = row + 1
+                
+    def setup_main_options(self):
+        if self.frames.has_key(""):
+            flist = self.frames[""]
+            for (text,widget) in flist:
+                label = gtk.Label("<b>%s</b>" % text)
+                label.set_use_markup(True)
+                label.set_alignment(0.0,0.5)
+                
+                self.tbl.set_border_width(12)
+                self.tbl.attach(label,0,4,self.col,self.col+1)
+                self.col += 1
+    
+                self.tbl.attach(widget,2,4,self.col,self.col+1)
+                self.col += 1
+
 
     #------------------------------------------------------------------------
     #
@@ -561,18 +427,6 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
     def setup_format_frame(self): 
         """Not used in bare report dialogs. Override in the subclass."""
         pass
-
-    def setup_paper_frame(self):
-        """Not used in bare report dialogs. Override in the subclass."""
-        pass
-
-    def setup_html_frame(self):
-        """Not used in bare report dialogs. Override in the subclass."""
-        pass
-
-    def setup_output_notebook(self):
-        """Not used in bare report dialogs. Override in the subclass."""
-        pass
     
     #------------------------------------------------------------------------
     #
@@ -585,59 +439,9 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         retrieves a value whether or not the menu is displayed on the
         screen.  The subclass will know whether this menu was enabled.
         This is for simplicity of programming."""
-        (style_name,self.selected_style) = self.style_menu.get_value()
-        self.options.handler.set_default_stylesheet_name(style_name)
-
-    def parse_report_options_frame(self):
-        """Parse the report options frame of the dialog.  Save the
-        user selected choices for later use.  Note that this routine
-        retrieves a value from all fields in the frame, regardless of
-        whether or not they are displayed on the screen.  The subclass
-        will know which ones it has enabled.  This is for simplicity
-        of programming."""
-
-        if self.generations_spinbox:
-            self.max_gen = self.generations_spinbox.get_value_as_int()
-        else:
-            self.max_gen = 0
-            
-        if self.pagebreak_checkbox and self.pagebreak_checkbox.get_active():
-            self.pg_brk = 1
-        else:
-            self.pg_brk = 0
-
-        if self.max_gen or self.pg_brk:
-            self.options.handler.set_report_generations(self.max_gen,self.pg_brk)
-
-        if self.filter_combo:
-            try:
-                self.filter = self.filter_combo.get_value()
-                active = max(0,self.filter_combo.get_active())
-                self.options.handler.set_filter_number(active)
-            except:
-                print "Error setting filter. Proceeding with 'Everyone'"
-                self.filter = Rules.Person.Everyone([])
-        else:
-            self.filter = None
-
-        if self.extra_menu:
-            self.report_menu = self.extra_menu.get_menu().get_active().get_data("d")
-        else:
-            self.report_menu = None
-
-        if self.extra_textbox:
-            b = self.extra_textbox.get_buffer()
-            text_val = unicode(b.get_text(b.get_start_iter(),b.get_end_iter(),False))
-            self.report_text = text_val.split('\n')
-            self.options.handler.set_display_format(self.report_text)
-        else:
-            self.report_text = []
-        
-    def parse_other_frames(self):
-        """Do nothing.  This sole purpose of this function is to give
-        subclass a place to hang a routine to parser any other frames
-        that are unique to that specific report."""
-        pass
+        if not self.default_style.is_empty():
+            (style_name, self.selected_style) = self.style_menu.get_value()
+            self.options.handler.set_default_stylesheet_name(style_name)
 
     #------------------------------------------------------------------------
     #
@@ -648,10 +452,10 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         pass
 
     def on_help_clicked(self, *obj):
-        if self.HELP_TOPIC:
-            import GrampsDisplay
-            GrampsDisplay.help(self.HELP_TOPIC)
-        print "HELP CLICKED"
+        import GrampsDisplay
+        GrampsDisplay.help(None, 
+                           URL_REPORT_PAGE, 
+                           self.report_name.replace(" ", "_") )
 
     def on_ok_clicked(self, obj):
         """The user is satisfied with the dialog choices. Parse all options
@@ -659,8 +463,6 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
 
         # Preparation
         self.parse_style_frame()
-        self.parse_report_options_frame()
-        self.parse_other_frames()
         self.parse_user_options()
         
         # Save options
@@ -674,18 +476,6 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
         StyleListDisplay(self.style_sheet_list,self.build_style_menu,
                          self.window)
 
-    def on_center_person_change_clicked(self,*obj):
-        from Selectors import selector_factory
-        SelectPerson = selector_factory('Person')
-        sel_person = SelectPerson(self.dbstate,self.uistate,self.track)
-        new_person = sel_person.run()
-        if new_person:
-            self.new_person = new_person
-            new_name = NameDisplay.displayer.display(new_person)
-            if new_name:
-                self.person_label.set_text( "<i>%s</i>" % new_name )
-                self.person_label.set_use_markup(True)
-
     #------------------------------------------------------------------------
     #
     # Functions related to creating the actual report document.
@@ -706,7 +496,7 @@ class BareReportDialog(ManagedWindow.ManagedWindow):
     #
     #------------------------------------------------------------------------
     def add_tooltip(self,widget,string):
-        """Adds a tooltip to the specified widget"""
+        """Add a tooltip to the specified widget"""
         if not widget or not string:
             return
         tip = gtk.Tooltips()
