@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ScratchPad.py 9343 2007-11-12 21:29:28Z gburto01 $
+# $Id: ScratchPad.py 10641 2008-04-26 20:42:31Z gburto01 $
 
 #------------------------------------------------------------------------
 #
@@ -28,16 +28,22 @@
 import cPickle as pickle
 import os
 from xml.sax.saxutils import escape
-from gettext import gettext as _
 from time import strftime as strftime
 
+try:
+    import fcntl
+    use_lock = True
+except:
+    use_lock = False
+
 #-------------------------------------------------------------------------
 #
 # GTK/Gnome modules
 #
 #-------------------------------------------------------------------------
 import gtk
-from gtk.gdk import ACTION_COPY, BUTTON1_MASK
+from gtk.gdk import ACTION_COPY, BUTTON1_MASK, ACTION_MOVE
+from gtk import glade
 
 #-------------------------------------------------------------------------
 #
@@ -45,10 +51,12 @@ from gtk.gdk import ACTION_COPY, BUTTON1_MASK
 #
 #-------------------------------------------------------------------------
 import const
+import gen.lib
 import TreeTips
 import DateHandler
 import GrampsDisplay
 import ManagedWindow
+from TransUtils import sgettext as _
 
 from DdTargets import DdTargets
 
@@ -59,10 +67,17 @@ from DdTargets import DdTargets
 #
 #-------------------------------------------------------------------------
 
-_stock_image = os.path.join(const.image_dir,'stock_link.png')
+_stock_image = os.path.join(const.IMAGE_DIR,'stock_link.png')
 LINK_PIC = gtk.gdk.pixbuf_new_from_file(_stock_image)
 BLANK_PIC = gtk.gdk.Pixbuf(0,0,8,1,1)
 
+#-------------------------------------------------------------------------
+#
+# The file used to store the state of the Clipboard (was scratchpad) between sessions
+#
+#-------------------------------------------------------------------------
+SCRATCHPAD_FILE = os.path.join(const.HOME_DIR,"scratchpad.dat")
+
 #-------------------------------------------------------------------------
 #
 # wrapper classes to provide object specific listing in the ListView
@@ -71,7 +86,7 @@ BLANK_PIC = gtk.gdk.Pixbuf(0,0,8,1,1)
 
 class ScratchPadWrapper(object):
 
-    def __init__(self,dbstate,obj):
+    def __init__(self,dbstate, obj):
         dbstate.connect('database-changed', self.database_changed)
         self.database_changed(dbstate.db)
 
@@ -100,8 +115,8 @@ class ScratchPadWrapper(object):
 
 class ScratchPadGrampsTypeWrapper(ScratchPadWrapper):
         
-    def __init__(self,dbstate,obj):
-        ScratchPadWrapper.__init__(self,dbstate,obj)
+    def __init__(self,dbstate, obj):
+        ScratchPadWrapper.__init__(self,dbstate, obj)
 
         #unpack object
         (drag_type, idval, self._obj, val) = pickle.loads(obj)
@@ -118,7 +133,7 @@ class ScratchPadGrampsTypeWrapper(ScratchPadWrapper):
                           'MediaObject': self._db.get_object_from_handle,
                           'Source': self._db.get_source_from_handle}
 
-        for (classname,handle) in self._obj.get_referenced_handles_recursively():
+        for (classname, handle) in self._obj.get_referenced_handles_recursively():
             if classname in valid_func_map.keys():
                 if not valid_func_map[classname](handle):
                     return False
@@ -132,8 +147,8 @@ class ScratchPadAddress(ScratchPadGrampsTypeWrapper):
     DRAG_TARGET  = DdTargets.ADDRESS
     ICON         = BLANK_PIC
     
-    def __init__(self,dbstate,obj):
-        ScratchPadGrampsTypeWrapper.__init__(self,dbstate,obj)
+    def __init__(self,dbstate, obj):
+        ScratchPadGrampsTypeWrapper.__init__(self,dbstate, obj)
         self._type  = _("Address")
         self._title = DateHandler.get_date(self._obj)
         self._value = "%s %s %s %s" % (self._obj.get_street(),self._obj.get_city(),
@@ -178,8 +193,8 @@ class ScratchPadLocation(ScratchPadGrampsTypeWrapper):
     DRAG_TARGET  = DdTargets.LOCATION
     ICON         = BLANK_PIC
     
-    def __init__(self,dbstate,obj):
-        ScratchPadGrampsTypeWrapper.__init__(self,dbstate,obj)
+    def __init__(self,dbstate, obj):
+        ScratchPadGrampsTypeWrapper.__init__(self,dbstate, obj)
         self._type  = _("Location")
         self._value = "%s %s %s" % (self._obj.get_city(),
                                     self._obj.get_state(),self._obj.get_country())
@@ -207,8 +222,8 @@ class ScratchPadEvent(ScratchPadWrapper):
     DRAG_TARGET  = DdTargets.EVENT
     ICON         = LINK_PIC
 
-    def __init__(self,dbstate,obj):
-        ScratchPadWrapper.__init__(self,dbstate,obj)
+    def __init__(self,dbstate, obj):
+        ScratchPadWrapper.__init__(self,dbstate, obj)
         self._type  = _("Event Link")
 
         (drag_type, idval, handle, val) = pickle.loads(obj)
@@ -221,27 +236,31 @@ class ScratchPadEvent(ScratchPadWrapper):
     def tooltip(self):
         global escape
         
-        s = "<big><b>%s</b></big>\n\n"\
-            "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s\n" % (
-            _("Event"),
-            _("Type"),escape(Utils.format_personal_event(self._obj.get_name())),
-            _("Date"),escape(DateHander.get_date(self._obj)),
-            _("Place"),escape(place_title(self._db,self._obj)),
-            _("Cause"),escape(self._obj.get_cause()),
-            _("Description"), escape(self._obj.get_description()))
-        if len(self._obj.get_source_references()) > 0:
-            psrc_ref = self._obj.get_source_references()[0]
-            psrc_id = psrc_ref.get_reference_handle()
-            psrc = self._db.get_source_from_handle(psrc_id)
-            s += "\n<big><b>%s</b></big>\n\n"\
-                "\t<b>%s:</b>\t%s\n" % (
-                _("Primary source"),
-                _("Name"),
-                escape(short(psrc.get_title())))
+        # there  are several errors in the below which all cause gramps to 
+        # crash
+        
+#        s = "<big><b>%s</b></big>\n\n"\
+#            "\t<b>%s:</b>\t%s\n"\
+#            "\t<b>%s:</b>\t%s\n"\
+#            "\t<b>%s:</b>\t%s\n"\
+#            "\t<b>%s:</b>\t%s\n"\
+#            "\t<b>%s:</b>\t%s\n" % (
+#            _("Event"),
+#            _("Type"),escape(Utils.format_personal_event(self._obj.get_name())),
+#            _("Date"),escape(DateHander.get_date(self._obj)),
+#            _("Place"),escape(place_title(self._db,self._obj)),
+#            _("Cause"),escape(self._obj.get_cause()),
+#            _("Description"), escape(self._obj.get_description()))
+#        if len(self._obj.get_source_references()) > 0:
+#            psrc_ref = self._obj.get_source_references()[0]
+#            psrc_id = psrc_ref.get_reference_handle()
+#            psrc = self._db.get_source_from_handle(psrc_id)
+#            s += "\n<big><b>%s</b></big>\n\n"\
+#                "\t<b>%s:</b>\t%s\n" % (
+#                _("Primary source"),
+#                _("Name"),
+#                escape(short(psrc.get_title())))
+        s = ""
         return s
 
     def is_valid(self):
@@ -258,8 +277,8 @@ class ScratchPadPlace(ScratchPadWrapper):
     DRAG_TARGET  = DdTargets.PLACE_LINK
     ICON         = LINK_PIC
 
-    def __init__(self,dbstate,obj):
-        ScratchPadWrapper.__init__(self,dbstate,obj)
+    def __init__(self,dbstate, obj):
+        ScratchPadWrapper.__init__(self,dbstate, obj)
         self._type  = _("Place")
 
         (drag_type, idval, handle, val) = pickle.loads(obj)
@@ -281,6 +300,39 @@ class ScratchPadPlace(ScratchPadWrapper):
             return True
         return False
 
+class ScratchPadNote(ScratchPadWrapper):
+
+    DROP_TARGETS = [DdTargets.NOTE_LINK]
+    DRAG_TARGET  = DdTargets.NOTE_LINK
+    ICON         = LINK_PIC
+
+    def __init__(self,dbstate, obj):
+        ScratchPadWrapper.__init__(self,dbstate, obj)
+        self._type  = _("Note")
+
+        (drag_type, idval, handle, val) = pickle.loads(obj)
+
+        value = self._db.get_note_from_handle(handle)
+
+        self._title = value.get_gramps_id()
+        note = value.get().replace('\n', ' ')
+        if len(note) > 80:
+            self._value = note[:80]+"..."
+        else:
+            self._value = note
+
+    def tooltip(self):
+        global escape
+        return ""
+
+    def is_valid(self):
+        data = pickle.loads(self._obj)
+        handle = data[2]
+        obj = self._db.get_note_from_handle(handle)
+        if obj:
+            return True
+        return False
+
 class ScratchPadFamilyEvent(ScratchPadGrampsTypeWrapper):
 
     DROP_TARGETS = [DdTargets.FAMILY_EVENT]
@@ -328,8 +380,8 @@ class ScratchPadUrl(ScratchPadGrampsTypeWrapper):
     DRAG_TARGET  = DdTargets.URL
     ICON         = BLANK_PIC
 
-    def __init__(self,dbstate,obj):
-        ScratchPadGrampsTypeWrapper.__init__(self,dbstate,obj)
+    def __init__(self,dbstate, obj):
+        ScratchPadGrampsTypeWrapper.__init__(self,dbstate, obj)
         self._type  = _("Url")
         self._title = self._obj.get_path()
         self._value = self._obj.get_description()
@@ -422,21 +474,34 @@ class ScratchPadSourceRef(ScratchPadGrampsTypeWrapper):
 
         base = self._db.get_source_from_handle(self._obj.get_reference_handle())
         self._title = base.get_title()
-        self._value = self._obj.get_text()
+        
+        notelist = [ self._db.get_note_from_handle(hndl) 
+                     for hndl in self._obj.get_note_list() ]
+        srctxtlist = [ note for note in notelist 
+                       if note.get_type() == gen.lib.NoteType.SOURCE_TEXT]
+
+        page = self._obj.get_page()
+        if not page:
+            page = _('not available|NA')
+        text = ""
+        if len(srctxtlist) > 0:
+            text = " ".join(srctxtlist[0].get().split())
+            if len(text) > 60:
+                text =  text[:60]+"..."
+        self._value = _("Volume/Page: %(pag)s -- %(sourcetext)s") % {
+                            'pag'        : page,
+                            'sourcetext' : text,
+                            }
 
     def tooltip(self):
         global escape
         base = self._db.get_source_from_handle(self._obj.get_reference_handle())
         s = "<big><b>%s</b></big>\n\n"\
             "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s" % (
-            _("Source Reference"),
-            _("Title"),escape(base.get_title()),
-            _("Page"), escape(self._obj.get_page()),
-            _("Text"), escape(self._obj.get_text()),
-            _("Comment"), escape(self._obj.get_note()))
+            "\t<b>%s:</b>\t%s" % \
+            (_("Source Reference"),
+             _("Title"),escape(base.get_title()),
+             _("Page"), escape(self._obj.get_page()))
 
         return s
 
@@ -458,15 +523,13 @@ class ScratchPadRepoRef(ScratchPadGrampsTypeWrapper):
         global escape
         base = self._db.get_repository_from_handle(self._obj.get_reference_handle())
         s = "<big><b>%s</b></big>\n\n"\
-            "\t<b>%s:</b>\t%s\n"\
             "\t<b>%s:</b>\t%s\n"\
             "\t<b>%s:</b>\t%s\n"\
             "\t<b>%s:</b>\t%s" % (
             _("Repository Reference"),
             _("Name"),escape(base.get_name()),
             _("Call Number"), escape(self._obj.get_call_number()),
-            _("Media Type"), escape(self._obj.get_media_type().__str__()),
-            _("Comment"), escape(self._obj.get_note()))
+            _("Media Type"), escape(self._obj.get_media_type().__str__()))
 
         return s
 
@@ -719,14 +782,12 @@ class ScratchSourceLink(ScratchPadWrapper):
             "\t<b>%s:</b>\t%s\n"\
             "\t<b>%s:</b>\t%s\n"\
             "\t<b>%s:</b>\t%s\n"\
-            "\t<b>%s:</b>\t%s\n"\
             "\t<b>%s:</b>\t%s" % (
             _("Source Link"),
             _("Title"),escape(base.get_title()),
             _("Abbreviation"), escape(base.get_abbreviation()),
             _("Author"), escape(base.get_author()),
-            _("Publication Information"), escape(base.get_publication_info()),
-            _("Comment"), escape(base.get_note()))
+            _("Publication Information"), escape(base.get_publication_info()))
         return s
 
     def is_valid(self):
@@ -781,20 +842,20 @@ class ScratchRepositoryLink(ScratchPadWrapper):
 
 class ScratchDropList(object):
 
-    def __init__(self,model,obj_list):
+    def __init__(self,model, obj_list):
         self._model = model
         self._obj_list = pickle.loads(obj_list)
 
     def get_objects(self):
-        return [self._cls(self._model,obj) for obj in self._obj_list]
+        return [self._cls(self._model, obj) for obj in self._obj_list]
 
 class ScratchPersonLinkList(ScratchDropList):
 
     DROP_TARGETS = [DdTargets.PERSON_LINK_LIST]
     DRAG_TARGET  = None
 
-    def __init__(self,model,obj_list):
-        ScratchDropList.__init__(self,model,obj_list)
+    def __init__(self,model, obj_list):
+        ScratchDropList.__init__(self,model, obj_list)
         self._cls = ScratchPersonLink
     
 
@@ -802,7 +863,7 @@ class ScratchPersonLinkList(ScratchDropList):
 #-------------------------------------------------------------------------
 #
 # ScratchPadListModel class
-#
+# Now shown as 'Clipboard'
 #-------------------------------------------------------------------------
 class ScratchPadListModel(gtk.ListStore):
 
@@ -817,7 +878,7 @@ class ScratchPadListModel(gtk.ListStore):
 #-------------------------------------------------------------------------
 #
 # ScratchPadListView class
-#
+# Now shown as 'Clipboard'
 #-------------------------------------------------------------------------
 class ScratchPadListView:
 
@@ -959,6 +1020,7 @@ class ScratchPadListView:
         self.register_wrapper_class(ScratchPersonLinkList)
         self.register_wrapper_class(ScratchPadPersonRef)
         self.register_wrapper_class(ScratchPadText)
+        self.register_wrapper_class(ScratchPadNote)
         
     def register_wrapper_class(self,wrapper_class):
         for drop_target in wrapper_class.DROP_TARGETS:            
@@ -985,9 +1047,9 @@ class ScratchPadListView:
 
     # handlers for the drag and drop events.
     
-    def on_object_select_row(self,obj):        
+    def on_object_select_row(self, obj):        
         tree_selection = self._widget.get_selection()
-        model,node = tree_selection.get_selected()
+        model, node = tree_selection.get_selected()
 
         self._widget.unset_rows_drag_source()
 
@@ -997,24 +1059,19 @@ class ScratchPadListView:
             targets = [ScratchPadListView.LOCAL_DRAG_TARGET] + \
                       [target.target() for target in o.__class__.DROP_TARGETS]
 
-            self._widget.enable_model_drag_source(BUTTON1_MASK, targets, ACTION_COPY)
+            self._widget.enable_model_drag_source(BUTTON1_MASK, targets, ACTION_COPY | ACTION_MOVE)
 
     def object_drag_begin(self, context, a):
         return
 
     def object_drag_data_get(self, widget, context, sel_data, info, time):
         tree_selection = widget.get_selection()
-        model,node = tree_selection.get_selected()
+        model, node = tree_selection.get_selected()
         o = model.get_value(node,1)
         
         sel_data.set(sel_data.target, 8, o.pack())
 
     def object_drag_data_received(self,widget,context,x,y,selection,info,time):
-
-        # Ignore drops from the same widget.
-        if ScratchPadListView.LOCAL_DRAG_TYPE in context.targets:            
-            return
-
         model = widget.get_model()
         sel_data = selection.data
 
@@ -1060,12 +1117,14 @@ class ScratchPadListView:
                 node = model.get_iter(path)
                 if (position == gtk.TREE_VIEW_DROP_BEFORE
                     or position == gtk.TREE_VIEW_DROP_INTO_OR_BEFORE):
-                    model.insert_before(node,[o.__class__.DRAG_TARGET.drag_type,o,o.tooltip])
+                    model.insert_before(node,[o.__class__.DRAG_TARGET.drag_type, o, o.tooltip])
                 else:
-                    model.insert_after(node,[o.__class__.DRAG_TARGET.drag_type,o,o.tooltip])
+                    model.insert_after(node,[o.__class__.DRAG_TARGET.drag_type, o, o.tooltip])
             else:
-                model.append([o.__class__.DRAG_TARGET.drag_type,o,o.tooltip])
-            
+                model.append([o.__class__.DRAG_TARGET.drag_type, o, o.tooltip])
+
+            if context.action == ACTION_MOVE:
+                context.finish(True, True, time)
 
         # remember time for double drop workaround.
         self._previous_drop_time = realTime
@@ -1093,7 +1152,8 @@ class ScratchPadListView:
 #-------------------------------------------------------------------------
 class ScratchPadWindow(ManagedWindow.ManagedWindow):
     """
-        The ScratchPad provides a temporary area to hold objects that can
+        The Clipboard (was ScratchPad) provides a temporary area to hold objects
+        that can
         be reused accross multiple Person records. The pad provides a window
         onto which objects can be dropped and then dragged into new Person
         dialogs. The objects are stored as the pickles that are built by the
@@ -1110,14 +1170,14 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         """
     
     # Class attribute used to hold the content of the
-    # ScratchPad. A class attribute is used so that the content
-    # it preserved even when the ScratchPad window is closed.
-    # As there is only ever one ScratchPad we do not need to
+    # Clipboard (was ScratchPad). A class attribute is used so that the content
+    # it preserved even when the Clipboard window is closed.
+    # As there is only ever one Clipboard we do not need to
     # maintain a list of these.
     otree = None
     
     def __init__(self, dbstate, uistate):
-        """Initializes the ScratchPad class, and displays the window"""
+        """Initialize the ScratchPad class, and displays the window"""
 
         ManagedWindow.ManagedWindow.__init__(self,uistate,[],self.__class__)
         self.dbstate = dbstate
@@ -1125,11 +1185,11 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         self.database_changed(self.dbstate.db)
         self.dbstate.connect('database-changed', self.database_changed)
 
-        self.glade_file = os.path.join(const.glade_dir,"scratchpad.glade")
+        self.glade_file = os.path.join(const.GLADE_DIR, "scratchpad.glade")
 
-        self.top = gtk.glade.XML(self.glade_file,"scratch_pad","gramps")
+        self.top = glade.XML(self.glade_file,"scratch_pad","gramps")
         self.set_window(self.top.get_widget("scratch_pad"),
-                        None, None, msg=_("Scratch Pad"))
+                        None, None, msg=_("Clipboard"))
 
         self.clear_all_btn = self.top.get_widget("btn_clear_all")
         self.clear_btn = self.top.get_widget("btn_clear")
@@ -1164,8 +1224,8 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         
         self.show()
 
-    def build_menu_names(self,obj):
-        return (_('ScratchPad'),None)
+    def build_menu_names(self, obj):
+        return (_('Clipboard'),None)
 
     def database_changed(self,database):
         self.db = database
@@ -1183,18 +1243,17 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         else:
             self.clear_btn.set_sensitive(True)
         
-    def on_help_clicked(self,obj):
+    def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
         GrampsDisplay.help('tools-util-scratch-pad')
 
-    def on_clear_clicked(self,obj):
+    def on_clear_clicked(self, obj):
         """Deletes the selected object from the object list"""
         selection = self.object_list.get_selection()
         model, node = selection.get_selected()
         if node:
             model.remove(node)
         return        
-        
 
 def short(val,size=60):
     if len(val) > size:
