@@ -1,14 +1,14 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2005  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# This program is distributed in the hope that it will be useful, 
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -18,10 +18,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: SubstKeywords.py 7879 2007-01-08 03:12:42Z pez4brian $
+# $Id: SubstKeywords.py 10103 2008-02-24 13:55:55Z acraphae $
 
 """
-Provides the SubstKeywords class that will replace keywords in a passed
+Provide the SubstKeywords class that will replace keywords in a passed
 string with informatin about the person. For sample:
 
 foo = SubstKeywords(person)
@@ -32,18 +32,15 @@ Will return a value such as:
 Mary Smith was born on 3/28/1923.
 """
 
-__author__ = "Donald N. Allingham"
-__version__ = "$Revision: 7879 $"
-
 #------------------------------------------------------------------------
 #
 # Gramps modules
 #
 #------------------------------------------------------------------------
 
-import NameDisplay
+from BasicUtils import name_displayer
 import DateHandler
-import RelLib
+import gen.lib
 
 #------------------------------------------------------------------------
 #
@@ -52,7 +49,7 @@ import RelLib
 #------------------------------------------------------------------------
 class SubstKeywords:
     """
-    Produces an object that will substitute information about a person
+    Produce an object that will substitute information about a person
     into a passed string.
 
     $n -> Name - FirstName LastName
@@ -68,12 +65,12 @@ class SubstKeywords:
     $M -> Place of preferred marriage
     """
     
-    def __init__(self,database,person_handle):
-        """Creates a new object and associates a person with it."""
+    def __init__(self, database, person_handle):
+        """Create a new object and associates a person with it."""
 
         person = database.get_person_from_handle(person_handle)
-        self.n = NameDisplay.displayer.display(person)
-        self.N = NameDisplay.displayer.sorted(person)
+        self.n = name_displayer.display(person)
+        self.N = name_displayer.sorted(person)
         self.b = ""
         self.B = ""
         self.d = ""
@@ -107,52 +104,47 @@ class SubstKeywords:
             if father_handle == person_handle:
                 if mother_handle:
                     mother = database.get_person_from_handle(mother_handle)
-                    self.s = NameDisplay.displayer.display(mother)
-                    self.S = NameDisplay.displayer.sorted(mother)
+                    self.s = name_displayer.display(mother)
+                    self.S = name_displayer.sorted(mother)
             else:
                 if father_handle:
                     father = database.get_person_from_handle(father_handle)
-                    self.s = NameDisplay.displayer.display(father)
-                    self.S = NameDisplay.displayer.sorted(father)
+                    self.s = name_displayer.display(father)
+                    self.S = name_displayer.sorted(father)
             for e_ref in f.get_event_ref_list():
                 if not e_ref:
                     continue
                 e = database.get_event_from_handle(e_ref.ref)
-                if e.get_type() == RelLib.EventType.MARRIAGE:
+                if e.get_type() == gen.lib.EventType.MARRIAGE:
                     self.m = DateHandler.get_date(e)
                     mplace_handle = e.get_place_handle()
                     if mplace_handle:
                         self.M = database.get_place_from_handle(mplace_handle).get_title()
 
-    def replace(self,line):
-        """Returns a new line of text with the substitutions performed."""
-        
-        line = line.replace("$n",self.n)
-        line = line.replace("$N",self.N)
-        line = line.replace("$b",self.b)
-        line = line.replace("$B",self.B)
-        line = line.replace("$d",self.d)
-        line = line.replace("$D",self.D)
-        line = line.replace("$i",self.i)
-        line = line.replace("$S",self.S)
-        line = line.replace("$s",self.s)
-        line = line.replace("$m",self.m)
-        line = line.replace("$M",self.M)
-        return line.replace("$$",'$')
+    def replace(self, line):
+        """Return a new line of text with the substitutions performed."""
+        array = [ ("$n", self.n), ("$N", self.N), ("$b", self.b), 
+                  ("$B", self.B), ("$d", self.d), ("$D", self.D), 
+                  ("$i", self.i), ("$S", self.S), ("$s", self.s), 
+                  ("$m", self.m), ("$M", self.M), ("$$", "$") ]
+
+        for (key, value) in array:
+            line = line.replace(key, value)
+        return line
 
     def replace_and_clean(self, lines):
-        array = [ ("%n",self.n), ("%N",self.N), ("%b",self.b),
-                  ("%B",self.B), ("%d",self.d), ("%D",self.D),
-                  ("%i",self.i), ("%S",self.S), ("%s",self.s),
-                  ("%m",self.m), ("%M",self.M)]
+        array = [ ("%n", self.n), ("%N", self.N), ("%b", self.b), 
+                  ("%B", self.B), ("%d", self.d), ("%D", self.D), 
+                  ("%i", self.i), ("%S", self.S), ("%s", self.s), 
+                  ("%m", self.m), ("%M", self.M) ]
 
         new = []
         for line in lines:
             remove = False
-            for (key,value) in array:
+            for (key, value) in array:
                 if line.find(key) != -1:
                     if value:
-                        line = line.replace(key,value)
+                        line = line.replace(key, value)
                     else:
                         remove = True
             if not remove:
