@@ -18,11 +18,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: TransUtils.py 6155 2006-03-16 20:24:27Z rshura $
+# $Id:TransUtils.py 9912 2008-01-22 09:17:46Z acraphae $
+
+"""
+Provide translation assistance
+"""
 
 from gettext import gettext
 
-def sgettext(msgid,sep='|'):
+def sgettext(msgid, sep='|'):
     """
     Strip the context used for resolving translation ambiguities.
     
