@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2005  Donald N. Allingham
+# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2007       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +19,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: AsciiDoc.py,v 1.10.2.1 2005/11/24 03:25:45 rshura Exp $
+# $Id:AsciiDoc.py 9912 2008-01-22 09:17:46Z acraphae $
 
 #------------------------------------------------------------------------
 #
 # python modules
 #
 #------------------------------------------------------------------------
-import os
 from gettext import gettext as _
 
 #------------------------------------------------------------------------
@@ -34,9 +34,11 @@ from gettext import gettext as _
 #
 #------------------------------------------------------------------------
 import BaseDoc
-import PluginMgr
+from PluginUtils import register_text_doc
 import Errors
-import GrampsMime
+import Mime
+import Utils
+
 
 #------------------------------------------------------------------------
 #
@@ -119,7 +121,7 @@ def reformat_para(para='',left=0,right=72,just=LEFT,right_pad=0,first=0):
 # Ascii
 #
 #------------------------------------------------------------------------
-class AsciiDoc(BaseDoc.BaseDoc):
+class AsciiDoc(BaseDoc.BaseDoc,BaseDoc.TextDoc):
 
     #--------------------------------------------------------------------
     #
@@ -153,9 +155,8 @@ class AsciiDoc(BaseDoc.BaseDoc):
 
         if self.print_req:
             apptype = 'text/plain'
-            prog = GrampsMime.get_application(apptype)
-            os.environ["FILE"] = self.filename
-            os.system ('%s "$FILE" &' % prog[0])
+            prog = Mime.get_application(apptype)
+            Utils.launch(prog[0],self.filename)
 
     def get_usable_width(self):
         return _WIDTH_IN_CHARS
@@ -165,31 +166,20 @@ class AsciiDoc(BaseDoc.BaseDoc):
     # Force a section page break
     #
     #--------------------------------------------------------------------
-    def end_page(self):
+    def page_break(self):
         self.f.write('\012')
 
-    #--------------------------------------------------------------------
-    #
-    # Force a line break
-    #
-    #--------------------------------------------------------------------
-    def line_break(self):
-        if self.in_cell:
-            self.cellpars[self.cellnum] = self.cellpars[self.cellnum] + '\n'
-        else:
-            self.f.write('\n')
+    def start_bold(self):
+        pass
+
+    def end_bold(self):
+        pass
 
     def start_superscript(self):
-        if self.in_cell:
-            self.cellpars[self.cellnum] = self.cellpars[self.cellnum] + '['
-        else:
-            self.f.write('[')
+        self.text = self.text + '['
 
     def end_superscript(self):
-        if self.in_cell:
-            self.cellpars[self.cellnum] = self.cellpars[self.cellnum] + ']'
-        else:
-            self.f.write(']')
+        self.text = self.text + ']'
 
     #--------------------------------------------------------------------
     #
@@ -197,7 +187,8 @@ class AsciiDoc(BaseDoc.BaseDoc):
     #
     #--------------------------------------------------------------------
     def start_paragraph(self,style_name,leader=None):
-        self.p = self.style_list[style_name]
+        styles = self.get_style_sheet()
+        self.p = styles.get_paragraph_style(style_name)
         self.leader = leader
 
     #--------------------------------------------------------------------
@@ -266,8 +257,9 @@ class AsciiDoc(BaseDoc.BaseDoc):
     # Start a table. Grab the table style, and store it. 
     #
     #--------------------------------------------------------------------
-    def start_table(self,name,style_name):
-        self.tbl_style = self.table_styles[style_name]
+    def start_table(self, name,style_name):
+        styles = self.get_style_sheet()
+        self.tbl_style = styles.get_table_style(style_name)
         self.ncols = self.tbl_style.get_columns()
 
     #--------------------------------------------------------------------
@@ -328,6 +320,8 @@ class AsciiDoc(BaseDoc.BaseDoc):
         self.cellnum = self.cellnum + span
         span = span - 1
         while span:
+            self.cell_widths[self.cellnum] += \
+                self.cell_widths[self.cellnum-span]
             self.cell_widths[self.cellnum-span] = 0
             span = span - 1
             
@@ -344,7 +338,7 @@ class AsciiDoc(BaseDoc.BaseDoc):
         if self.cell_lines[self.cellnum] > self.maxlines:
             self.maxlines = self.cell_lines[self.cellnum]
 
-    def add_photo(self,name,pos,x,y):
+    def add_media_object(self, name, align, w_cm, h_cm):
         this_text = '(photo)'
         if self.in_cell:
             self.cellpars[self.cellnum] = self.cellpars[self.cellnum] + this_text
@@ -369,7 +363,7 @@ class AsciiDoc(BaseDoc.BaseDoc):
     #
     # Writes text. 
     #--------------------------------------------------------------------
-    def write_text(self,text):
+    def write_text(self,text,mark=None):
         text = text.replace('<super>','[')
         text = text.replace('</super>',']')
         self.text = self.text + text
@@ -381,17 +375,15 @@ class AsciiDoc(BaseDoc.BaseDoc):
 #------------------------------------------------------------------------
 print_label = None
 try:
-    import Utils
-
-    mprog = GrampsMime.get_application("text/plain")
-    mtype = GrampsMime.get_description('text/plain')
+    mprog = Mime.get_application("text/plain")
+    mtype = Mime.get_description('text/plain')
 
     if Utils.search_for(mprog[0]):
         print_label=_("Open in %s") % mprog[1]
     else:
         print_label=None
 
-    PluginMgr.register_text_doc(mtype,AsciiDoc,1,1,1,".txt", print_label)
+    register_text_doc(mtype,AsciiDoc,1,1,1,".txt", print_label)
 except:
-    PluginMgr.register_text_doc(_("Plain Text"),AsciiDoc,1,1,1,".txt", None)
+    register_text_doc(_("Plain Text"),AsciiDoc,1,1,1,".txt", None)
 
