@@ -3,13 +3,14 @@
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
 # Copyright (C) 2005-2006  Serge Noiraud
+# Copyright (C) 2007       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# This program is distributed in the hope that it will be useful, 
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ODFDoc.py 8651 2007-06-24 20:44:37Z pez4brian $
+# $Id: ODFDoc.py 10496 2008-04-06 03:43:46Z pez4brian $
 
 #-------------------------------------------------------------------------
 #
@@ -27,11 +28,13 @@
 #
 #-------------------------------------------------------------------------
 import os
+import md5
 import zipfile
 import time
 import locale
 from cStringIO import StringIO
 from math import pi, cos, sin
+from xml.sax.saxutils import escape
 
 #-------------------------------------------------------------------------
 #
@@ -54,17 +57,16 @@ import Errors
 #
 #-------------------------------------------------------------------------
 from gettext import gettext as _
-from xml.sax.saxutils import escape
 
 _apptype = 'application/vnd.oasis.opendocument.text'
 
 _esc_map = {
-    '\x1a'           : '',
-    '\x0c'           : '',
-    '\n'             : '<text:line-break/>',
-    '\t'             : '<text:tab-stop/>',
-    '&lt;super&gt;'  : '<text:span text:style-name="GSuper">',
-    '&lt;/super&gt;' : '</text:span>',
+    '\x1a'           : '', 
+    '\x0c'           : '', 
+    '\n'             : '<text:line-break/>', 
+    '\t'             : '<text:tab />', 
+    '&lt;super&gt;'  : '<text:span text:style-name="GSuper">', 
+    '&lt;/super&gt;' : '</text:span>', 
     }
 
 #-------------------------------------------------------------------------
@@ -72,10 +74,11 @@ _esc_map = {
 # ODFDoc
 #
 #-------------------------------------------------------------------------
-class ODFDoc(BaseDoc.BaseDoc):
+class ODFDoc(BaseDoc.BaseDoc, BaseDoc.TextDoc, BaseDoc.DrawDoc):
 
-    def __init__(self,styles,type,template,orientation=BaseDoc.PAPER_PORTRAIT):
-        BaseDoc.BaseDoc.__init__(self,styles,type,template,orientation)
+    def __init__(self, styles, type, template):
+        BaseDoc.BaseDoc.__init__(self, styles, type, template)
+        self.media_list = []
         self.cntnt = None
         self.filename = None
         self.level = 0
@@ -85,10 +88,10 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.page = 0
         self.first_page = 1
 
-    def open(self,filename):
+    def open(self, filename):
         t = time.localtime(time.time())
         self.time = "%04d-%02d-%02dT%02d:%02d:%02d" % \
-                    (t[0],t[1],t[2],t[3],t[4],t[5])
+                    (t[0], t[1], t[2], t[3], t[4], t[5])
 
         if filename[-4:] != ".odt":
             self.filename = filename + ".odt"
@@ -106,7 +109,7 @@ class ODFDoc(BaseDoc.BaseDoc):
         current_locale = locale.getlocale()
         self.lang = current_locale[0]
         if self.lang:
-            self.lang = self.lang.replace('_','-')
+            self.lang = self.lang.replace('_', '-')
         else:
             self.lang = "en-US"
 
@@ -155,9 +158,11 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.cntnt.write('<style:style style:name="GRAMPS-preformat" style:family="text">')
         self.cntnt.write('<style:text-properties style:font-name="Courier"/>')
         self.cntnt.write('</style:style>\n')
+        
+        styles = self.get_style_sheet()
 
-        for style_name in self.draw_styles.keys():
-            style = self.draw_styles[style_name]
+        for style_name in styles.get_draw_style_names():
+            style = styles.get_draw_style(style_name)
             self.cntnt.write('<style:style style:name="%s"' % style_name)
             self.cntnt.write(' style:family="graphic"')
             self.cntnt.write(' >\n')
@@ -223,9 +228,9 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.cntnt.write('draw:wrap-influence-on-position="once-concurrent" ')
         self.cntnt.write('style:flow-with-text="false"/>')
         self.cntnt.write('</style:style>\n')
-        
-        for style_name in self.style_list.keys():
-            style = self.style_list[style_name]
+
+        for style_name in styles.get_paragraph_style_names():
+            style = styles.get_paragraph_style(style_name)
 
             self.cntnt.write('<style:style style:name="NL%s" ' % style_name)
             self.cntnt.write('style:family="paragraph" ')
@@ -239,21 +244,21 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write('<style:paragraph-properties ')
 
             if style.get_padding() != 0.0:
-               self.cntnt.write('fo:padding="%.2fcm" ' % style.get_padding())
+                self.cntnt.write('fo:padding="%.2fcm" ' % style.get_padding())
             if style.get_header_level() > 0:
                 self.cntnt.write('fo:keep-with-next="true" ')
 
             align = style.get_alignment()
             if align == BaseDoc.PARA_ALIGN_LEFT:
-               self.cntnt.write('fo:text-align="start" ')
+                self.cntnt.write('fo:text-align="start" ')
             elif align == BaseDoc.PARA_ALIGN_RIGHT:
-               self.cntnt.write('fo:text-align="end" ')
+                self.cntnt.write('fo:text-align="end" ')
             elif align == BaseDoc.PARA_ALIGN_CENTER:
-               self.cntnt.write('fo:text-align="center" ')
-               self.cntnt.write('style:justify-single-word="false" ')
+                self.cntnt.write('fo:text-align="center" ')
+                self.cntnt.write('style:justify-single-word="false" ')
             else:
-               self.cntnt.write('fo:text-align="justify" ')
-               self.cntnt.write('style:justify-single-word="false" ')
+                self.cntnt.write('fo:text-align="justify" ')
+                self.cntnt.write('style:justify-single-word="false" ')
             font = style.get_font()
             if font.get_type_face() == BaseDoc.FONT_SANS_SERIF:
                 self.cntnt.write('style:font-name="Arial" ')
@@ -283,12 +288,12 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write('<style:text-properties ')
             align = style.get_alignment()
             if align == BaseDoc.PARA_ALIGN_LEFT:
-               self.cntnt.write('fo:text-align="start" ')
+                self.cntnt.write('fo:text-align="start" ')
             elif align == BaseDoc.PARA_ALIGN_RIGHT:
-               self.cntnt.write('fo:text-align="end" ')
+                self.cntnt.write('fo:text-align="end" ')
             elif align == BaseDoc.PARA_ALIGN_CENTER:
-               self.cntnt.write('fo:text-align="center" ')
-               self.cntnt.write('style:justify-single-word="false" ')
+                self.cntnt.write('fo:text-align="center" ')
+                self.cntnt.write('style:justify-single-word="false" ')
             font = style.get_font()
             if font.get_type_face() == BaseDoc.FONT_SANS_SERIF:
                 self.cntnt.write('style:font-name="Arial" ')
@@ -304,8 +309,8 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write('style:font-size-asian="%.2fpt"/> ' % font.get_size())
             self.cntnt.write('</style:style>\n')
 
-        for style_name in self.table_styles.keys():
-            style = self.table_styles[style_name]
+        for style_name in styles.get_table_style_names():
+            style = styles.get_table_style(style_name)
             self.cntnt.write('<style:style style:name="%s" ' % style_name)
             self.cntnt.write('style:family="table-properties">\n')
             table_width = float(self.get_usable_width())
@@ -313,7 +318,7 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write('<style:table-properties-properties style:width="%scm" '%table_width_str)
             self.cntnt.write('/>\n')
             self.cntnt.write('</style:style>\n')
-            for col in range(0,style.get_columns()):
+            for col in range(0, style.get_columns()):
                 self.cntnt.write('<style:style style:name="')
                 self.cntnt.write(style_name + '.' + str(chr(ord('A')+col)) +'" ')
                 self.cntnt.write('style:family="table-column">')
@@ -323,8 +328,8 @@ class ODFDoc(BaseDoc.BaseDoc):
                 self.cntnt.write('style:column-width="%scm"/>' % width_str)
                 self.cntnt.write('</style:style>\n')
                 
-        for cell in self.cell_styles.keys():
-            cell_style = self.cell_styles[cell]
+        for cell in styles.get_cell_style_names():
+            cell_style = styles.get_cell_style(cell)
             self.cntnt.write('<style:style style:name="%s" ' % cell)
             self.cntnt.write('style:family="table-cell">\n')
             self.cntnt.write('<style:table-cell-properties')
@@ -428,32 +433,33 @@ class ODFDoc(BaseDoc.BaseDoc):
         self._write_zip()
         if self.print_req:
             app = Mime.get_application(_apptype)
-            Utils.launch(app[0],self.filename)
+            Utils.launch(app[0], self.filename)
 
-    def add_media_object(self,name,pos,x_cm,y_cm):
+    def add_media_object(self, file_name, pos, x_cm, y_cm):
 
         # try to open the image. If the open fails, it probably wasn't
         # a valid image (could be a PDF, or a non-image)
-        try:
-            image = ImgManip.ImgManip(name)
-            (x,y) = image.size()
-            ratio = float(x_cm)*float(y)/(float(y_cm)*float(x))
-        except:
+        (x, y) = ImgManip.image_size(file_name)
+        if (x, y) == (0, 0):
             return
         
+        ratio = float(x_cm)*float(y)/(float(y_cm)*float(x))
         if ratio < 1:
             act_width = x_cm
             act_height = y_cm*ratio
         else:
             act_height = y_cm
             act_width = x_cm/ratio
+            
+        not_extension, extension = os.path.splitext(file_name)
+        odf_name = md5.new(file_name).hexdigest() + extension
 
-        media_list_item = (name,act_width,act_height)
+        media_list_item = (file_name, odf_name)
         if not media_list_item in self.media_list:
             self.media_list.append(media_list_item)
 
-        base = os.path.basename(name)
-        tag = base.replace('.','_')
+        base = escape(os.path.basename(file_name))
+        tag = base.replace('.', '_')
         
         if self.new_cell:
             self.cntnt.write('<text:p>')
@@ -472,18 +478,19 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.cntnt.write('svg:height="%.2fcm" ' % act_height)
         self.cntnt.write('draw:z-index="1" >')
         self.cntnt.write('<draw:image xlink:href="Pictures/')
-        self.cntnt.write(base)
+        self.cntnt.write(odf_name)
         self.cntnt.write('" xlink:type="simple" xlink:show="embed" ')
         self.cntnt.write('xlink:actuate="onLoad"/>\n')
         self.cntnt.write('</draw:frame>\n')
         if self.new_cell:
             self.cntnt.write('</text:p>\n')
 
-    def start_table(self,name,style_name):
+    def start_table(self, name, style_name):
         self.cntnt.write('<table:table table:name="%s" ' % name)
         self.cntnt.write('table:style-name="%s">\n' % style_name)
-        table = self.table_styles[style_name]
-        for col in range(0,table.get_columns()):
+        styles = self.get_style_sheet()
+        table = styles.get_table_style(style_name)
+        for col in range(0, table.get_columns()):
             self.cntnt.write('<table:table-column table:style-name="')
             self.cntnt.write(style_name + '.' + str(chr(ord('A')+col)) +'"/>\n')
 
@@ -496,7 +503,7 @@ class ODFDoc(BaseDoc.BaseDoc):
     def end_row(self):
         self.cntnt.write('</table:table-row>\n')
 
-    def start_cell(self,style_name,span=1):
+    def start_cell(self, style_name, span=1):
         self.span = span
         self.cntnt.write('<table:table-cell table:style-name="%s" ' % style_name)
         self.cntnt.write('table:value-type="string"')
@@ -508,7 +515,7 @@ class ODFDoc(BaseDoc.BaseDoc):
 
     def end_cell(self):
         self.cntnt.write('</table:table-cell>\n')
-        #for col in range(1,self.span):
+        #for col in range(1, self.span):
         #    self.cntnt.write('<table:covered-table-cell/>\n')
         self.new_cell = 0
 
@@ -524,16 +531,16 @@ class ODFDoc(BaseDoc.BaseDoc):
     def end_superscript(self):
         self.cntnt.write('</text:span>')
 
-    def _add_zip(self,zfile,name,data,t):
+    def _add_zip(self, zfile, name, data, t):
         zipinfo = zipfile.ZipInfo(name.encode('latin-1'))
         zipinfo.date_time = t
         zipinfo.compress_type = zipfile.ZIP_DEFLATED
-        zfile.writestr(zipinfo,data)
+        zfile.writestr(zipinfo, data)
 
     def _write_zip(self):
         try:
-            zfile = zipfile.ZipFile(self.filename,"w",zipfile.ZIP_DEFLATED)    
-        except IOError,msg:
+            zfile = zipfile.ZipFile(self.filename, "w", zipfile.ZIP_DEFLATED)    
+        except IOError, msg:
             errmsg = "%s\n%s" % (_("Could not create %s") % self.filename, msg)
             raise Errors.ReportError(errmsg)
         except:
@@ -541,11 +548,11 @@ class ODFDoc(BaseDoc.BaseDoc):
             
         t = time.localtime(time.time())[:6]
 
-        self._add_zip(zfile,"META-INF/manifest.xml",self.mfile.getvalue(),t)
-        self._add_zip(zfile,"content.xml",self.cntnt.getvalue(),t)
-        self._add_zip(zfile,"meta.xml",self.meta.getvalue(),t)
-        self._add_zip(zfile,"styles.xml",self.sfile.getvalue(),t)
-        self._add_zip(zfile,"mimetype",self.mimetype.getvalue(),t)
+        self._add_zip(zfile, "META-INF/manifest.xml", self.mfile.getvalue(), t)
+        self._add_zip(zfile, "content.xml", self.cntnt.getvalue(), t)
+        self._add_zip(zfile, "meta.xml", self.meta.getvalue(), t)
+        self._add_zip(zfile, "styles.xml", self.sfile.getvalue(), t)
+        self._add_zip(zfile, "mimetype", self.mimetype.getvalue(), t)
 
         self.mfile.close()
         self.cntnt.close()
@@ -555,9 +562,8 @@ class ODFDoc(BaseDoc.BaseDoc):
         
         for image in self.media_list:
             try:
-                ifile = open(image[0],mode='rb')
-                base = os.path.basename(image[0])
-                self._add_zip(zfile,"Pictures/%s" % base, ifile.read(),t)
+                ifile = open(image[0], mode='rb')
+                self._add_zip(zfile, "Pictures/%s" % image[1], ifile.read(), t)
                 ifile.close()
             except:
                 print "Could not open %s" % image[0]
@@ -661,9 +667,11 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.sfile.write('style:horizontal-rel="paragraph-content"/>\n')
         self.sfile.write('</style:style>\n')
         
-        for key in self.style_list.keys():
-            style = self.style_list[key]
-            self.sfile.write('<style:style style:name="%s" ' % key)
+        styles = self.get_style_sheet()
+        
+        for style_name in styles.get_paragraph_style_names():
+            style = styles.get_paragraph_style(style_name)
+            self.sfile.write('<style:style style:name="%s" ' % style_name)
             self.sfile.write('style:family="paragraph" ')
             self.sfile.write('style:parent-style-name="Standard" ')
             self.sfile.write('style:class="text">\n')
@@ -674,22 +682,22 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.sfile.write('fo:margin-bottom="0.212cm"\n')
 
             if style.get_padding() != 0.0:
-               self.sfile.write('fo:padding="%.2fcm" ' % style.get_padding())
+                self.sfile.write('fo:padding="%.2fcm" ' % style.get_padding())
             if style.get_header_level() > 0:
                 self.sfile.write('fo:keep-with-next="always" ')
 
             align = style.get_alignment()
             if align == BaseDoc.PARA_ALIGN_LEFT:
-               self.sfile.write('fo:text-align="start" ')
-               self.sfile.write('style:justify-single-word="false" ')
+                self.sfile.write('fo:text-align="start" ')
+                self.sfile.write('style:justify-single-word="false" ')
             elif align == BaseDoc.PARA_ALIGN_RIGHT:
-               self.sfile.write('fo:text-align="end" ')
+                self.sfile.write('fo:text-align="end" ')
             elif align == BaseDoc.PARA_ALIGN_CENTER:
-               self.sfile.write('fo:text-align="center" ')
-               self.sfile.write('style:justify-single-word="false" ')
+                self.sfile.write('fo:text-align="center" ')
+                self.sfile.write('style:justify-single-word="false" ')
             else:
-               self.sfile.write('fo:text-align="justify" ')
-               self.sfile.write('style:justify-single-word="false" ')
+                self.sfile.write('fo:text-align="justify" ')
+                self.sfile.write('style:justify-single-word="false" ')
             self.sfile.write('fo:text-indent="%.2fcm" ' % style.get_first_indent())
             self.sfile.write('style:auto-text-indent="false"/> ')
             self.sfile.write('<style:text-properties ')
@@ -760,17 +768,17 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.sfile.write('style:justify-single-word="false"/>')
         self.sfile.write('</style:style>\n')
         self.sfile.write('<style:page-layout style:name="pm1">\n')
-        self.sfile.write('<style:page-layout-properties fo:page-width="%.2fcm" ' % self.width)
-        self.sfile.write('fo:page-height="%.2fcm" ' % self.height)
+        self.sfile.write('<style:page-layout-properties fo:page-width="%.2fcm" ' % self.paper.get_size().get_width())
+        self.sfile.write('fo:page-height="%.2fcm" ' % self.paper.get_size().get_height())
         self.sfile.write('style:num-format="1" ')
-        if self.orientation == BaseDoc.PAPER_PORTRAIT:
+        if self.paper.get_orientation() == BaseDoc.PAPER_PORTRAIT:
             self.sfile.write('style:print-orientation="portrait" ')
         else:
             self.sfile.write('style:print-orientation="landscape" ')
-        self.sfile.write('fo:margin-top="%.2fcm" ' % self.tmargin)
-        self.sfile.write('fo:margin-bottom="%.2fcm" ' % self.bmargin)
-        self.sfile.write('fo:margin-left="%.2fcm" ' % self.lmargin)
-        self.sfile.write('fo:margin-right="%.2fcm" ' % self.rmargin)
+        self.sfile.write('fo:margin-top="%.2fcm" ' % self.paper.get_top_margin())
+        self.sfile.write('fo:margin-bottom="%.2fcm" ' % self.paper.get_bottom_margin())
+        self.sfile.write('fo:margin-left="%.2fcm" ' % self.paper.get_left_margin())
+        self.sfile.write('fo:margin-right="%.2fcm" ' % self.paper.get_right_margin())
         self.sfile.write('style:writing-mode="lr-tb" ')
         self.sfile.write('style:footnote-max-height="0cm">\n')
         self.sfile.write('<style:footnote-sep style:width="0.018cm" ')
@@ -824,8 +832,9 @@ class ODFDoc(BaseDoc.BaseDoc):
     def end_page(self):
         self.cntnt.write('</text:p>\n')
         
-    def start_paragraph(self,style_name,leader=None):
-        style = self.style_list[style_name]
+    def start_paragraph(self, style_name, leader=None):
+        style_sheet = self.get_style_sheet()
+        style = style_sheet.get_paragraph_style(style_name)
         self.level = style.get_header_level()
         if self.new_page == 1:
             self.new_page = 0
@@ -839,7 +848,7 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write(name)
             self.cntnt.write('" text:outline-level="' + str(self.level) + '">')
         if leader != None:
-            self.cntnt.write(escape(leader))
+            self.cntnt.write(leader)
             self.cntnt.write('<text:tab/>')
         self.new_cell = 0
 
@@ -850,20 +859,12 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write('</text:h>\n')
         self.new_cell = 1
 
-    def write_note(self,text,format,style_name):
+    def write_note(self, text, format, style_name):
         if format == 1:
-            text = text.replace('&','&amp;')       # Must be first
-            text = text.replace('<','&lt;')
-            text = text.replace('>','&gt;')
+            text = escape(text, _esc_map)
             # Replace multiple spaces: have to go from the largest number down
-            for n in range(text.count(' '),1,-1):
+            for n in range(text.count(' '), 1, -1):
                 text = text.replace(' '*n, ' <text:s text:c="%d"/>' % (n-1) )
-            text = text.replace('\n','<text:line-break/>')
-            text = text.replace('\t','<text:tab-stop/>')
-            text = text.replace('&lt;super&gt;',
-                                '<text:span text:style-name="GSuper">')
-            text = text.replace('&lt;/super&gt;','</text:span>')
-
             self.start_paragraph(style_name)
             self.cntnt.write('<text:span text:style-name="GRAMPS-preformat">')
             self.cntnt.write(text)
@@ -872,20 +873,20 @@ class ODFDoc(BaseDoc.BaseDoc):
         elif format == 0:
             for line in text.split('\n\n'):
                 self.start_paragraph(style_name)
-                line = line.replace('\n',' ')
+                line = line.replace('\n', ' ')
                 line = ' '.join(line.split())
                 self.write_text(line)
                 self.end_paragraph()
 
-    def write_text(self,text,mark=None):
+    def write_text(self, text, mark=None):
         """
         Uses the xml.sax.saxutils.escape function to convert XML
         entities. The _esc_map dictionary allows us to add our own
         mappings.
         """
         if mark:
-            key = escape(mark.key,_esc_map)
-            key = key.replace('"','&quot;')
+            key = escape(mark.key, _esc_map)
+            key = key.replace('"', '&quot;')
             if mark.type == BaseDoc.INDEX_TYPE_ALP:
                 self.cntnt.write('<text:alphabetical-index-mark ')
                 self.cntnt.write('text:string-value="%s" />' % key)
@@ -893,7 +894,7 @@ class ODFDoc(BaseDoc.BaseDoc):
                 self.cntnt.write('<text:toc-mark ')
                 self.cntnt.write('text:string-value="%s" ' % key)
                 self.cntnt.write('text:outline-level="%d" />' % mark.level)
-        self.cntnt.write(escape(text,_esc_map))
+        self.cntnt.write(escape(text, _esc_map))
 
     def _write_manifest(self):
         self.mfile = StringIO()
@@ -905,11 +906,9 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.mfile.write('manifest:media-type="%s" ' % _apptype)
         self.mfile.write('manifest:full-path="/"/>')
         for image in self.media_list:
-            i = image[0]
-            base = os.path.basename(i)
             self.mfile.write('<manifest:file-entry manifest:media-type="" ')
             self.mfile.write('manifest:full-path="Pictures/')
-            self.mfile.write(base)
+            self.mfile.write(image[1])
             self.mfile.write('"/>')
         self.mfile.write('<manifest:file-entry manifest:media-type="" ')
         self.mfile.write('manifest:full-path="Pictures/"/>')
@@ -937,7 +936,7 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.meta.write('office:version="1.0">\n');
         self.meta.write('<office:meta>\n')
         self.meta.write('<meta:generator>')
-        self.meta.write(const.program_name + ' ' + const.version)
+        self.meta.write(const.PROGRAM_NAME + ' ' + const.VERSION)
         self.meta.write('</meta:generator>\n')
         self.meta.write('<dc:title>')
         # It should be reasonable to have a true document title. but how ?
@@ -950,13 +949,13 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.meta.write('<dc:description>')
         self.meta.write('</dc:description>\n')
         self.meta.write('<meta:initial-creator>')
-        self.meta.write(self.name)
+        self.meta.write(self.get_creator())
         self.meta.write('</meta:initial-creator>\n')
         self.meta.write('<meta:creation-date>')
         self.meta.write(self.time)
         self.meta.write('</meta:creation-date>\n')
         self.meta.write('<dc:creator>')
-        self.meta.write(self.name)
+        self.meta.write(self.get_creator())
         self.meta.write('</dc:creator>\n')
         self.meta.write('<dc:date>')
         self.meta.write(self.time)
@@ -975,18 +974,18 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.meta.write('</office:meta>\n')
         self.meta.write('</office:document-meta>\n')
 
-    def rotate_text(self,style,text,x,y,angle):
-
-        stype = self.draw_styles[style]
+    def rotate_text(self, style, text, x, y, angle):
+        style_sheet = self.get_style_sheet()
+        stype = style_sheet.get_draw_style(style)
         pname = stype.get_paragraph_style()
-        p = self.style_list[pname]
+        p = style_sheet.get_paragraph_style(pname)
         font = p.get_font()
         size = font.get_size()
 
         height = size*(len(text))
         width = 0
         for line in text:
-            width = max(width,FontScale.string_width(font,line))
+            width = max(width, FontScale.string_width(font, line))
         wcm = ReportUtils.pt2cm(width)
         hcm = ReportUtils.pt2cm(height)
 
@@ -1001,50 +1000,48 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.cntnt.write('rotate (%.8f) ' % -rangle)
         xloc = x-((wcm/2.0)*cos(rangle))+((hcm/2.0)*sin(rangle))
         yloc = y-((hcm/2.0)*cos(rangle))-((wcm/2.0)*sin(rangle))
-        self.cntnt.write('translate (%.3fcm %.3fcm)"' % (xloc,yloc))
-        self.cntnt.write('>')
-        self.cntnt.write('<draw:text-box>')
-        self.cntnt.write('<text:p text:style-name="X%s"> ' % pname)
-
-        self.cntnt.write('<text:span text:style-name="F%s">\n' % pname)
-        self.write_text('\n'.join(text))    # No escape(): write_text does that.
-        self.cntnt.write('</text:span>\n</text:p>\n</draw:text-box>\n')
+        self.cntnt.write('translate (%.3fcm %.3fcm)">\n' % (xloc, yloc))
+        self.cntnt.write('<draw:text-box>\n')
+        self.cntnt.write('<text:p text:style-name="X%s">' % pname)
+        self.cntnt.write('<text:span text:style-name="F%s">' % pname)
+        self.cntnt.write(escape('\n'.join(text), _esc_map))
+        self.cntnt.write('</text:span></text:p>\n</draw:text-box>\n')
         self.cntnt.write('</draw:frame>\n')
         
-    def draw_path(self,style,path):
+    def draw_path(self, style, path):
         minx = 9e12
         miny = 9e12
         maxx = 0
         maxy = 0
 
         for point in path:
-            minx = min(point[0],minx)
-            miny = min(point[1],miny)
-            maxx = max(point[0],maxx)
-            maxy = max(point[1],maxy)
+            minx = min(point[0], minx)
+            miny = min(point[1], miny)
+            maxx = max(point[0], maxx)
+            maxy = max(point[1], maxy)
 
         self.cntnt.write('<draw:polygon draw:style-name="%s" draw:layer="layout" ' % style)
         self.cntnt.write('draw:z-index="1" ')
         x = int((minx)*1000)
         y = int((miny)*1000)
         
-        self.cntnt.write('svg:x="%d" svg:y="%d" ' % (x,y))
-        self.cntnt.write('svg:viewBox="0 0 %d %d" ' % (int((maxx-minx)*1000),int((maxy-miny)*1000)))
+        self.cntnt.write('svg:x="%d" svg:y="%d" ' % (x, y))
+        self.cntnt.write('svg:viewBox="0 0 %d %d" ' % (int((maxx-minx)*1000), int((maxy-miny)*1000)))
         self.cntnt.write('svg:width="%.4fcm" ' % (maxx-minx))
         self.cntnt.write('svg:height="%.4fcm" ' % (maxy-miny))
         
         point = path[0]
         x1 = int((point[0]-minx)*1000)
         y1 = int((point[1]-miny)*1000)
-        self.cntnt.write('draw:points="%d,%d' % (x1,y1))
+        self.cntnt.write('draw:points="%d, %d' % (x1, y1))
 
         for point in path[1:]:
             x1 = int((point[0]-minx)*1000)
             y1 = int((point[1]-miny)*1000)
-            self.cntnt.write(' %d,%d' % (x1,y1))
+            self.cntnt.write(' %d, %d' % (x1, y1))
         self.cntnt.write('"/>\n')
 
-    def draw_line(self,style,x1,y1,x2,y2):
+    def draw_line(self, style, x1, y1, x2, y2):
         self.cntnt.write('<draw:line text:anchor-type="paragraph" ')
         self.cntnt.write('draw:z-index="3" ')
         self.cntnt.write('draw:text-style-name="%s" ' % style )
@@ -1055,16 +1052,13 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.cntnt.write('<text:p/>\n')
         self.cntnt.write('</draw:line>\n')
 
-    def draw_text(self,style,text,x,y):
-        box_style = self.draw_styles[style]
+    def draw_text(self, style, text, x, y):
+        style_sheet = self.get_style_sheet()
+        box_style = style_sheet.get_draw_style(style)
         para_name = box_style.get_paragraph_style()
-
-        pstyle = self.style_list[para_name]
+        pstyle = style_sheet.get_paragraph_style(para_name)
         font = pstyle.get_font()
-        if box_style.get_width():
-            sw = box_style.get_width()*1.2
-        else:
-            sw = ReportUtils.pt2cm(FontScale.string_width(font,text))*1.3
+        sw = ReportUtils.pt2cm(FontScale.string_width(font, text))*1.3
 
         self.cntnt.write('<draw:frame text:anchor-type="paragraph" ')
         self.cntnt.write('draw:z-index="2" ')
@@ -1079,25 +1073,14 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.cntnt.write('<text:p text:style-name="F%s">' % para_name)
         self.cntnt.write('<text:span text:style-name="F%s"' % para_name)
         self.cntnt.write(' fo:max-height="%.2f">' % font.get_size() )
-        self.cntnt.write(escape(text,_esc_map))
+        self.cntnt.write(escape(text, _esc_map))
         self.cntnt.write('</text:span></text:p>')
         self.cntnt.write('</draw:text-box>\n')
         self.cntnt.write('</draw:frame>\n')
 
-    def draw_bar(self,style,x,y,x2,y2):
-        box_style = self.draw_styles[style]
-
-        self.cntnt.write('<draw:rect text:anchor-type="paragraph" draw:style-name="')
-        self.cntnt.write(style)
-        self.cntnt.write('" draw:z-index="0" ')
-        self.cntnt.write('svg:width="%.2fcm" ' % float(x2-x))
-        self.cntnt.write('svg:height="%.2fcm" ' % float(y2-y))
-        self.cntnt.write('svg:x="%.2fcm" ' % float(x))
-        self.cntnt.write('svg:y="%.2fcm">' % float(y))
-        self.cntnt.write('</draw:rect>\n')
-
-    def draw_box(self,style,text,x,y):
-        box_style = self.draw_styles[style]
+    def draw_box(self, style, text, x, y, w, h):
+        style_sheet = self.get_style_sheet()
+        box_style = style_sheet.get_draw_style(style)
         para_name = box_style.get_paragraph_style()
         shadow_width = box_style.get_shadow_space()
 
@@ -1106,8 +1089,8 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write('draw:style-name="%s_shadow" ' % style)
             self.cntnt.write('draw:z-index="0" ')
             self.cntnt.write('draw:text-style-name="%s" ' % para_name)
-            self.cntnt.write('svg:width="%.2fcm" ' % box_style.get_width())
-            self.cntnt.write('svg:height="%.2fcm" ' % box_style.get_height())
+            self.cntnt.write('svg:width="%.2fcm" ' % w)
+            self.cntnt.write('svg:height="%.2fcm" ' % h)
             self.cntnt.write('svg:x="%.2fcm" ' % (float(x)+shadow_width))
             self.cntnt.write('svg:y="%.2fcm">\n' % (float(y)+shadow_width))
             self.cntnt.write('</draw:rect>\n')
@@ -1116,29 +1099,30 @@ class ODFDoc(BaseDoc.BaseDoc):
         self.cntnt.write('draw:style-name="%s" ' % style)
         self.cntnt.write('draw:text-style-name="%s" ' % para_name)
         self.cntnt.write('draw:z-index="1" ')
-        self.cntnt.write('svg:width="%.2fcm" ' % box_style.get_width())
-        self.cntnt.write('svg:height="%.2fcm" ' % box_style.get_height())
+        self.cntnt.write('svg:width="%.2fcm" ' % w)
+        self.cntnt.write('svg:height="%.2fcm" ' % h)
         self.cntnt.write('svg:x="%.2fcm" ' % float(x))
         self.cntnt.write('svg:y="%.2fcm">\n' % float(y))
         if text != "":
             self.cntnt.write('<text:p text:style-name="%s">' % para_name)
             self.cntnt.write('<text:span text:style-name="F%s">' % para_name)
-            self.cntnt.write(escape(text,_esc_map))
+            self.cntnt.write(escape(text, _esc_map))
             self.cntnt.write('</text:span>')
             self.cntnt.write('</text:p>\n')
         self.cntnt.write('</draw:rect>\n')
 
-    def center_text(self,style,text,x,y):
-        box_style = self.draw_styles[style]
+    def center_text(self, style, text, x, y):
+        style_sheet = self.get_style_sheet()
+        box_style = style_sheet.get_draw_style(style)
         para_name = box_style.get_paragraph_style()
-        pstyle = self.style_list[para_name]
+        pstyle = style_sheet.get_paragraph_style(para_name)
         font = pstyle.get_font()
 
-        size = 1.2*(FontScale.string_width(font,text)/72.0) * 2.54
+        size = (FontScale.string_width(font, text)/72.0) * 2.54
 
         self.cntnt.write('<draw:frame text:anchor-type="paragraph" ')
         self.cntnt.write('draw:style-name="%s" ' % style)
-        self.cntnt.write('draw:z-index="0" ')
+        self.cntnt.write('draw:z-index="2" ')
         self.cntnt.write('svg:width="%.2fcm" ' % size)
         self.cntnt.write('svg:height="%.2fpt" ' % font.get_size())
 
@@ -1149,7 +1133,7 @@ class ODFDoc(BaseDoc.BaseDoc):
             self.cntnt.write('<draw:text-box>')
             self.cntnt.write('<text:p text:style-name="X%s">' % para_name)
             self.cntnt.write('<text:span text:style-name="F%s">' % para_name)
-            self.cntnt.write(escape(text,_esc_map))
+            self.cntnt.write(escape(text, _esc_map))
             self.cntnt.write('</text:span>\n')
             self.cntnt.write('</text:p>\n')
             self.cntnt.write('</draw:text-box>')
