@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2007       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: RTFDoc.py 8019 2007-01-31 03:13:31Z pez4brian $
+# $Id:RTFDoc.py 9912 2008-01-22 09:17:46Z acraphae $
 
 #------------------------------------------------------------------------
 #
@@ -59,7 +60,7 @@ def twips(cm):
 # use style sheets. Instead it writes raw formatting.
 #
 #------------------------------------------------------------------------
-class RTFDoc(BaseDoc.BaseDoc):
+class RTFDoc(BaseDoc.BaseDoc,BaseDoc.TextDoc):
 
     #--------------------------------------------------------------------
     #
@@ -83,6 +84,8 @@ class RTFDoc(BaseDoc.BaseDoc):
             raise Errors.ReportError(errmsg)
         except:
             raise Errors.ReportError(_("Could not create %s") % self.filename)
+        
+        style_sheet = self.get_style_sheet()
 
         self.f.write('{\\rtf1\\ansi\\ansicpg1252\\deff0\n')
         self.f.write('{\\fonttbl\n')
@@ -93,8 +96,8 @@ class RTFDoc(BaseDoc.BaseDoc):
         index = 1
         self.color_map[(0,0,0)] = 0
         self.f.write('\\red0\\green0\\blue0;')
-        for style_name in self.style_list.keys():
-            style = self.style_list[style_name]
+        for style_name in style_sheet.get_paragraph_style_names():
+            style = style_sheet.get_paragraph_style(style_name)
             fgcolor = style.get_font().get_color()
             bgcolor = style.get_background_color()
             if not self.color_map.has_key(fgcolor):
@@ -107,12 +110,12 @@ class RTFDoc(BaseDoc.BaseDoc):
                 index = index + 1
         self.f.write('}\n')
         self.f.write('\\kerning0\\cf0\\viewkind1')
-        self.f.write('\\paperw%d' % twips(self.width))
-        self.f.write('\\paperh%d' % twips(self.height))
-        self.f.write('\\margl%d' % twips(self.lmargin))
-        self.f.write('\\margr%d' % twips(self.rmargin))
-        self.f.write('\\margt%d' % twips(self.tmargin))
-        self.f.write('\\margb%d' % twips(self.bmargin))
+        self.f.write('\\paperw%d' % twips(self.paper.get_size().get_width()))
+        self.f.write('\\paperh%d' % twips(self.paper.get_size().get_height()))
+        self.f.write('\\margl%d' % twips(self.paper.get_left_margin()))
+        self.f.write('\\margr%d' % twips(self.paper.get_right_margin()))
+        self.f.write('\\margt%d' % twips(self.paper.get_top_margin()))
+        self.f.write('\\margb%d' % twips(self.paper.get_bottom_margin()))
         self.f.write('\\widowctl\n')
         self.in_table = 0
         self.text = ""
@@ -150,7 +153,8 @@ class RTFDoc(BaseDoc.BaseDoc):
     #--------------------------------------------------------------------
     def start_paragraph(self,style_name,leader=None):
         self.opened = 0
-        p = self.style_list[style_name]
+        style_sheet = self.get_style_sheet()
+        p = style_sheet.get_paragraph_style(style_name)
 
         # build font information
 
@@ -270,9 +274,10 @@ class RTFDoc(BaseDoc.BaseDoc):
     # table, since a table is treated as a bunch of rows.
     #
     #--------------------------------------------------------------------
-    def start_table(self,name,style_name):
+    def start_table(self, name,style_name):
         self.in_table = 1
-        self.tbl_style = self.table_styles[style_name]
+        styles = self.get_style_sheet()
+        self.tbl_style = styles.get_table_style(style_name)
 
     #--------------------------------------------------------------------
     #
@@ -320,7 +325,8 @@ class RTFDoc(BaseDoc.BaseDoc):
     #
     #--------------------------------------------------------------------
     def start_cell(self,style_name,span=1):
-        s = self.cell_styles[style_name]
+        styles = self.get_style_sheet()
+        s = styles.get_cell_style(style_name)
         self.remain = span -1
         if s.get_top_border():
             self.f.write('\\clbrdrt\\brdrs\\brdrw10\n')
@@ -330,7 +336,7 @@ class RTFDoc(BaseDoc.BaseDoc):
             self.f.write('\\clbrdrl\\brdrs\\brdrw10\n')
         if s.get_right_border():
             self.f.write('\\clbrdrr\\brdrs\\brdrw10\n')
-        table_width = float(self.get_usable_width())
+        table_width = float(self.paper.get_usable_width())
         for cell in range(self.cell,self.cell+span):
             self.cell_percent = self.cell_percent + float(self.tbl_style.get_column_width(cell))
         cell_width = twips((table_width * self.cell_percent)/100.0)
@@ -355,18 +361,14 @@ class RTFDoc(BaseDoc.BaseDoc):
     # dumped as a string of HEX numbers.
     #
     #--------------------------------------------------------------------
-    def add_media_object(self,name,pos,x_cm,y_cm):
-        try:
-            im = ImgManip.ImgManip(name)
-        except:
-            return
-        
-        nx,ny = im.size()
+    def add_media_object(self, name,pos,x_cm,y_cm):
 
-        if (nx,ny) == (0,0):
+        nx, ny = ImgManip.image_size(name)
+
+        if (nx, ny) == (0,0):
             return
 
-        if (nx,ny) == (0,0):
+        if (nx, ny) == (0,0):
             return
 
         ratio = float(x_cm)*float(ny)/(float(y_cm)*float(nx))
@@ -378,7 +380,8 @@ class RTFDoc(BaseDoc.BaseDoc):
             act_height = y_cm
             act_width = x_cm/ratio
 
-        buf = im.jpg_scale_data(int(act_width*40),int(act_height*40))
+        buf = ImgManip.resize_to_jpeg_buffer(name, int(act_width*40), 
+                                             int(act_height*40))
 
         act_width = twips(act_width)
         act_height = twips(act_height)
