@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2007       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: SvgDrawDoc.py 8552 2007-06-15 03:51:14Z pez4brian $
+# $Id: SvgDrawDoc.py 9912 2008-01-22 09:17:46Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -42,10 +43,10 @@ import Errors
 # SvgDrawDoc
 #
 #-------------------------------------------------------------------------
-class SvgDrawDoc(BaseDoc.BaseDoc):
+class SvgDrawDoc(BaseDoc.BaseDoc,BaseDoc.DrawDoc):
 
-    def __init__(self,styles,type,template,orientation):
-        BaseDoc.BaseDoc.__init__(self,styles,type,template,orientation)
+    def __init__(self,styles,type,template):
+        BaseDoc.BaseDoc.__init__(self,styles,type,template)
         self.f = None
         self.filename = None
         self.level = 0
@@ -80,13 +81,14 @@ class SvgDrawDoc(BaseDoc.BaseDoc):
         self.f.write('<?xml version="1.0" encoding="UTF-8" standalone="no"?>\n')
         self.f.write('<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.0//EN" ')
         self.f.write('"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">\n')
-        self.f.write('<svg width="%5.2fcm" height="%5.2fcm" ' % (self.width,self.height))
+        self.f.write('<svg width="%5.2fcm" height="%5.2fcm" ' % (self.paper.get_size().get_width(),self.paper.get_size().get_height()))
         self.f.write('xmlns="http://www.w3.org/2000/svg">\n')
 
     def rotate_text(self,style,text,x,y,angle):
-        stype = self.draw_styles[style]
+        style_sheet = self.get_style_sheet()
+        stype = style_sheet.get_draw_style(style)
         pname = stype.get_paragraph_style()
-        p = self.style_list[pname]
+        p = style_sheet.get_paragraph_style(pname)
         font = p.get_font()
         size = font.get_size()
 
@@ -96,7 +98,8 @@ class SvgDrawDoc(BaseDoc.BaseDoc):
             width = max(width,self.string_width(font,line))
             height += size
 
-        centerx,centery = units((x+self.lmargin,y+self.tmargin))
+        centerx,centery = units(( x+self.paper.get_left_margin(),
+                                  y+self.paper.get_top_margin() ))
         xpos = (centerx - (width/2.0)) 
         ypos = (centery - (height/2.0)) 
 
@@ -132,12 +135,13 @@ class SvgDrawDoc(BaseDoc.BaseDoc):
         self.f.close()
     
     def draw_line(self,style,x1,y1,x2,y2):
-        x1 = x1 + self.lmargin
-        x2 = x2 + self.lmargin
-        y1 = y1 + self.tmargin
-        y2 = y2 + self.tmargin
+        x1 = x1 + self.paper.get_left_margin()
+        x2 = x2 + self.paper.get_left_margin()
+        y1 = y1 + self.paper.get_top_margin()
+        y2 = y2 + self.paper.get_top_margin()
 
-        s = self.draw_styles[style]
+        style_sheet = self.get_style_sheet()
+        s = style_sheet.get_draw_style(style)
 
         self.f.write('<line x1="%4.2fcm" y1="%4.2fcm" ' % (x1,y1))
         self.f.write('x2="%4.2fcm" y2="%4.2fcm" ' % (x2,y2))
@@ -145,66 +149,51 @@ class SvgDrawDoc(BaseDoc.BaseDoc):
         self.f.write('stroke-width:%.2fpt;"/>\n' % s.get_line_width())
 
     def draw_path(self,style,path):
-        stype = self.draw_styles[style]
+        style_sheet = self.get_style_sheet()
+        stype = style_sheet.get_draw_style(style)
 
         point = path[0]
         self.f.write('<polygon fill="#%02x%02x%02x"' % stype.get_fill_color())
         self.f.write(' style="stroke:#%02x%02x%02x; ' % stype.get_color())
         self.f.write(' stroke-width:%.2fpt;"' % stype.get_line_width())
-        self.f.write(' points="%.2f,%.2f' % units((point[0]+self.lmargin,point[1]+self.tmargin)))
+        self.f.write(' points="%.2f,%.2f' % units((point[0]+self.paper.get_left_margin(),point[1]+self.paper.get_top_margin())))
         for point in path[1:]:
-            self.f.write(' %.2f,%.2f' % units((point[0]+self.lmargin,point[1]+self.tmargin)))
+            self.f.write(' %.2f,%.2f' % units((point[0]+self.paper.get_left_margin(),point[1]+self.paper.get_top_margin())))
         self.f.write('"/>\n')
-            
-    def draw_bar(self,style,x1,y1,x2,y2):
-        x1 = x1 + self.lmargin
-        x2 = x2 + self.lmargin
-        y1 = y1 + self.tmargin
-        y2 = y2 + self.tmargin
 
-	s = self.draw_styles[style]
-        self.f.write('<rect ')
-        self.f.write('x="%4.2fcm" ' % x1)
-        self.f.write('y="%4.2fcm" ' % y1)
-        self.f.write('width="%4.2fcm" ' % (x2-x1))
-        self.f.write('height="%4.2fcm" ' % (y2-y1))
-        self.f.write('style="fill:#%02x%02x%02x; ' % s.get_fill_color())
-        self.f.write('stroke:#%02x%02x%02x; ' % s.get_color())
-        self.f.write('stroke-width:%.2f;"/>\n' % s.get_line_width())
-    
-    def draw_box(self,style,text,x,y):
-        x = x + self.lmargin
-        y = y + self.tmargin
+    def draw_box(self,style,text,x,y, w, h):
+        x = x + self.paper.get_left_margin()
+        y = y + self.paper.get_top_margin()
+
+        style_sheet = self.get_style_sheet()
+        box_style = style_sheet.get_draw_style(style)
 
-	box_style = self.draw_styles[style]
-	para_name = box_style.get_paragraph_style()
-	p = self.style_list[para_name]
-        
-        bh = box_style.get_height()
-        bw = box_style.get_width()
         if box_style.get_shadow():
             self.f.write('<rect ')
             self.f.write('x="%4.2fcm" ' % (x+0.15))
             self.f.write('y="%4.2fcm" ' % (y+0.15))
-            self.f.write('width="%4.2fcm" ' % bw)
-            self.f.write('height="%4.2fcm" ' % bh)
+            self.f.write('width="%4.2fcm" ' % w)
+            self.f.write('height="%4.2fcm" ' % h)
             self.f.write('style="fill:#808080; stroke:#808080; stroke-width:1;"/>\n')
         self.f.write('<rect ')
         self.f.write('x="%4.2fcm" ' % x)
         self.f.write('y="%4.2fcm" ' % y)
-        self.f.write('width="%4.2fcm" ' % bw)
-        self.f.write('height="%4.2fcm" ' % bh)
+        self.f.write('width="%4.2fcm" ' % w)
+        self.f.write('height="%4.2fcm" ' % h)
         self.f.write('style="fill:#%02x%02x%02x; ' % box_style.get_fill_color())
         self.f.write('stroke:#%02x%02x%02x; ' % box_style.get_color())
         self.f.write('stroke-width:%f;"/>\n' % box_style.get_line_width())
         if text != "":
+            para_name = box_style.get_paragraph_style()
+            assert( para_name != '' )
+            p = style_sheet.get_paragraph_style(para_name)
             font = p.get_font()
             font_size = font.get_size()
             lines = text.split('\n')
             nlines = len(lines)
             mar = 10/28.35
             fs = (font_size/28.35) * 1.2
-            center = y + (bh + fs)/2.0 + (fs*0.2)
+            center = y + (h + fs)/2.0 + (fs*0.2)
             ystart = center - (fs/2.0) * nlines
             for i in range(nlines):
                 ypos = ystart + (i * fs)
@@ -222,16 +211,17 @@ class SvgDrawDoc(BaseDoc.BaseDoc):
                 else:
                     self.t.write(' font-family:serif;')
                 self.t.write('">')
-                self.f.write(lines[i])
+                self.t.write(lines[i])
                 self.t.write('</text>\n')
 
     def draw_text(self,style,text,x,y):
-        x = x + self.lmargin
-        y = y + self.tmargin
+        x = x + self.paper.get_left_margin()
+        y = y + self.paper.get_top_margin()
         
-	box_style = self.draw_styles[style]
-	para_name = box_style.get_paragraph_style()
-	p = self.style_list[para_name]
+        style_sheet = self.get_style_sheet()
+        box_style = style_sheet.get_draw_style(style)
+        para_name = box_style.get_paragraph_style()
+        p = style_sheet.get_paragraph_style(para_name)
         
         font = p.get_font()
         font_size = font.get_size()
@@ -254,9 +244,10 @@ class SvgDrawDoc(BaseDoc.BaseDoc):
         self.t.write('</text>\n')
 
     def center_text(self, style, text, x, y):
-        box_style = self.draw_styles[style]
+        style_sheet = self.get_style_sheet()
+        box_style = style_sheet.get_draw_style(style)
         para_name = box_style.get_paragraph_style()
-        p = self.style_list[para_name]
+        p = style_sheet.get_paragraph_style(para_name)
         font = p.get_font()
         font_size = font.get_size()
         width = self.string_width(font,text) / 72
