@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2000-2006  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: gramps.py 9280 2007-10-31 08:25:14Z jgsack $
+# $Id: gramps.py 10186 2008-03-04 22:28:59Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -31,7 +31,6 @@ import locale
 import const
 import signal
 import gettext
-import exceptions
 import logging
 
 log = logging.getLogger(".")
@@ -47,17 +46,17 @@ try:
 except ImportError:
     pass
 
-import gtk.gdk
+#-------------------------------------------------------------------------
+#
+# Miscellaneous initialization
+#
+#-------------------------------------------------------------------------
 import gtk
-import gtk.glade
+from gtk import glade
 import gobject
 
-# setup import path
-
 gobject.threads_init()
 
-sys.path.append(os.path.abspath(os.path.basename(__file__)))
-
 #-------------------------------------------------------------------------
 #
 # Load internationalization setup
@@ -65,8 +64,8 @@ sys.path.append(os.path.abspath(os.path.basename(__file__)))
 #-------------------------------------------------------------------------
 if os.environ.has_key("GRAMPSI18N"):
     loc = os.environ["GRAMPSI18N"]
-elif os.path.exists( os.path.join(const.root_dir,"lang") ):
-    loc = os.path.join(const.root_dir,"lang")
+elif os.path.exists( os.path.join(const.ROOT_DIR, "lang") ):
+    loc = os.path.join(const.ROOT_DIR, "lang")
 else:
     loc = "/usr/share/locale"
 
@@ -79,24 +78,38 @@ except ValueError:
     pass
 
 gettext.bindtextdomain("gramps",loc)
-gtk.glade.bindtextdomain("gramps",loc)
+glade.bindtextdomain("gramps",loc)
 
 try:
-    gtk.glade.textdomain("gramps")
+    glade.textdomain("gramps")
 except:
     pass
 
 gettext.textdomain("gramps")
 gettext.install("gramps",loc,unicode=1)
 
+#-------------------------------------------------------------------------
+#
+# Minimum version check
+#
+#-------------------------------------------------------------------------
+
+MIN_PYTHON_VERSION = (2, 5, 0, '', 0)
+if not sys.version_info >= MIN_PYTHON_VERSION :
+    print gettext.gettext("Your Python version does not meet the "
+                  "requirements. At least python %d.%d.%d is needed to"
+                  " start GRAMPS.\n\n"
+                  "GRAMPS will terminate now.") % (
+                                        MIN_PYTHON_VERSION[0], 
+                                        MIN_PYTHON_VERSION[1],
+                                        MIN_PYTHON_VERSION[2])
+    sys.exit(1)
+
 #-------------------------------------------------------------------------
 #
 # gramps libraries
 #
 #-------------------------------------------------------------------------
-import gramps_main 
-import gobject
-
 try:
     signal.signal(signal.SIGCHLD, signal.SIG_DFL)
 except:
@@ -107,7 +120,6 @@ args = sys.argv
 def setup_logging():
     """Setup basic logging support."""
 
-    import logging
     from GrampsLogger import RotateHandler, GtkHandler
 
     # Setup a formatter
@@ -130,12 +142,12 @@ def setup_logging():
     # Setup the base level logger, this one gets
     # everything.
     l = logging.getLogger()
-    l.setLevel(logging.DEBUG)
+    l.setLevel(logging.WARNING)
     l.addHandler(rh)
     l.addHandler(gtkh)
     l.addHandler(stderrh)
 
-    # put a hook on to catch any completly unhandled exceptions.
+    # put a hook on to catch any completely unhandled exceptions.
     def exc_hook(type, value, tb):
         if type == KeyboardInterrupt:
             # Ctrl-C is not a bug.
@@ -154,32 +166,59 @@ def run():
     setup_logging()
 
     try:
+        #This is GNOME initialization code that is necessary for use 
+        # with the other GNOME libraries. 
+        #It only gets called if the user has gnome installed on his/her system.
+        #There is *no* requirement for it.
+        #If you don't call this, you are not guaranteed that the other GNOME
+        #libraries will function properly. I learned this the hard way.
         import gnome
-        program = gnome.program_init('gramps',const.version, 
+        program = gnome.program_init('gramps',const.VERSION, 
                                      gnome.libgnome_module_info_get(),
-                                     args, const.popt_table)
+                                     args, const.POPT_TABLE)
     
         program.set_property('app-libdir',
-                             '%s/lib' % const.prefixdir)
+                             '%s/lib' % const.PREFIXDIR)
         program.set_property('app-datadir',
-                             '%s/share' % const.prefixdir)
-        program.set_property('app-sysconfdir',const.sysconfdir)
-        program.set_property('app-prefix', const.prefixdir)
+                             '%s/share' % const.PREFIXDIR)
+        program.set_property('app-sysconfdir',const.SYSCONFDIR)
+        program.set_property('app-prefix', const.PREFIXDIR)
     except:
         pass
-    
+
     try:        
+        quit_now = False
+        exit_code = 0
+        import gramps_main 
         gramps_main.Gramps(args)
-    except SystemExit, err:
-        # err.message may be numeric=0 or string="" or None or False
-        # or (), or [], .. ,  all of which are non-error conditions
-        # which need no error logging/dialog here (lower-level, maybe)
-        if err and err.message:
-            log.error("Gramps terminated with the following message:\n %r." 
-                      % err.message, exc_info=True)
-        gtk.main_quit()
+        # TODO: check for returns from gramps_main.Gramps.__init__()
+        #  that perhaps should have raised an exception to be caught here
+
+    except SystemExit, e:
+        quit_now = True
+        if e.code:
+            exit_code = e.code
+            log.error("Gramps terminated with exit code: %d." \
+                      % e.code, exc_info=True)
+    except OSError, e:
+        quit_now = True
+        exit_code = e[0] or 1
+        try:
+            fn = e.filename
+        except AttributeError:
+            fn = ""
+        log.error("Gramps terminated because of OS Error\n" +
+            "Error details: %s %s" % (repr(e), fn), exc_info=True)
     except:
+        quit_now = True
+        exit_code = 1
         log.error("Gramps failed to start.", exc_info=True)
 
+    if quit_now:
+        gtk.main_quit()
+        sys.exit(exit_code)
+        
+    return False
+        
 gobject.timeout_add(100, run, priority=100)
 gtk.main()
