@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Check.py 9531 2007-12-19 09:28:43Z bmcage $
+# $Id: Check.py 10152 2008-03-01 22:47:48Z pez4brian $
 
-"Database Processing/Check and repair database"
+"""Tools/Database Repair/Check and Repair Database"""
 
 #-------------------------------------------------------------------------
 #
@@ -47,21 +47,21 @@ log = logging.getLogger(".CheckRepair")
 #
 #-------------------------------------------------------------------------
 import gtk
-import gtk.glade
+from gtk import glade
 
 #-------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import RelLib
+import gen.lib
 import Utils
-import const
+#import const
 import ManagedWindow
 
 from PluginUtils import Tool, register_tool
 from QuestionDialog import OkDialog, MissingMediaDialog
-from NameDisplay import displayer as _nd
+from BasicUtils import name_displayer as _nd
 
 #-------------------------------------------------------------------------
 #
@@ -73,18 +73,19 @@ def low_level(db):
     This is a low-level repair routine.
 
     It is fixing DB inconsistencies such as duplicates.
-    Returns a (status,name) tuple.
+    Returns a (status, name) tuple.
     The boolean status indicates the success of the procedure.
     The name indicates the problematic table (empty if status is True).
     """
 
-    for the_map in [('Person',db.person_map),
-                    ('Family',db.family_map),
-                    ('Event',db.event_map),
-                    ('Place',db.place_map),
-                    ('Source',db.source_map),
-                    ('Media',db.media_map),
-                    ('Repository', db.repository_map)]:
+    for the_map in [('Person', db.person_map),
+                    ('Family', db.family_map),
+                    ('Event', db.event_map),
+                    ('Place', db.place_map),
+                    ('Source', db.source_map),
+                    ('Media', db.media_map),
+                    ('Repository', db.repository_map),
+                    ('Note', db.note_map)]:
 
         print "Low-level repair: table: %s" % the_map[0]
         if _table_low_level(db,the_map[1]):
@@ -108,8 +109,9 @@ def _table_low_level(db,table):
         print "    No dupes found for this table"
         return True
 
-    import GrampsBSDDB
-    table_cursor = GrampsBSDDB.GrampsBSDDBDupCursor(table)
+#    import gen.db
+    from gen.db import GrampsDBDirDupCursor
+    table_cursor = GrampsDBDirDupCursor(table)
     for handle in dup_handles:
         print "    Duplicates found for handle: %s" % handle
         try:
@@ -157,8 +159,8 @@ class Check(Tool.BatchTool):
 
         # The low-level repair is bypassing the transaction mechanism.
         # As such, we run it before starting the transaction.
-        # We only do this for the BSDDB backend.
-        if self.db.__class__.__name__ == 'GrampsBSDDB':
+        # We only do this for the dbdir backend.
+        if self.db.__class__.__name__ == 'GrampsDBDir':
             low_level(self.db)
         
         trans = self.db.transaction_begin("",batch=True)
@@ -189,6 +191,7 @@ class Check(Tool.BatchTool):
         checker.check_source_references()
         checker.check_media_references()
         checker.check_repo_references()
+        checker.check_note_references()
         self.db.transaction_commit(trans, _("Check Integrity"))
         self.db.enable_signals()
         self.db.request_rebuild()
@@ -223,6 +226,7 @@ class CheckIntegrity:
         self.invalid_source_references = []
         self.invalid_repo_references = []
         self.invalid_media_references = []
+        self.invalid_note_references = []
         self.removed_name_format = []
         self.empty_objects = {'persons' : [],
                               'families': [],
@@ -231,8 +235,9 @@ class CheckIntegrity:
                               'media'   : [],
                               'places'  : [],
                               'repos'   : [],
+                              'notes'   : [],
                              }
-        self.progress = Utils.ProgressMeter(_('Checking database'),'')
+        self.progress = Utils.ProgressMeter(_('Checking Database'),'')
 
     def family_errors(self):
         return len(self.broken_parent_links) + \
@@ -252,7 +257,7 @@ class CheckIntegrity:
         self.progress.set_pass(_('Looking for invalid name format references'),
                                self.db.get_number_of_people())
         
-        deleted_name_formats = [number for (number,name,fmt_str,act)
+        deleted_name_formats = [number for (number, name,fmt_str,act)
                                 in self.db.name_formats if not act]
         
         # remove the invalid references from all Name objects
@@ -262,10 +267,10 @@ class CheckIntegrity:
             p_changed = False
             name = person.get_primary_name()
             if name.get_sort_as() in deleted_name_formats:
-                name.set_sort_as(RelLib.Name.DEF)
+                name.set_sort_as(gen.lib.Name.DEF)
                 p_changed = True
             if name.get_display_as() in deleted_name_formats:
-                name.set_display_as(RelLib.Name.DEF)
+                name.set_display_as(gen.lib.Name.DEF)
                 p_changed = True
             if p_changed:
                 person.set_primary_name(name)
@@ -274,10 +279,10 @@ class CheckIntegrity:
             name_list = []
             for name in person.get_alternate_names():
                 if name.get_sort_as() in deleted_name_formats:
-                    name.set_sort_as(RelLib.Name.DEF)
+                    name.set_sort_as(gen.lib.Name.DEF)
                     a_changed = True
                 if name.get_display_as() in deleted_name_formats:
-                    name.set_display_as(RelLib.Name.DEF)
+                    name.set_display_as(gen.lib.Name.DEF)
                     a_changed = True
                 name_list.append(name)
             if a_changed:
@@ -302,7 +307,7 @@ class CheckIntegrity:
 
         for handle in self.db.person_map.keys():
             value = self.db.person_map[handle]
-            p = RelLib.Person(value)
+            p = gen.lib.Person(value)
             splist = p.get_family_handle_list()
             if len(splist) != len(set(splist)):
                 new_list = []
@@ -515,7 +520,8 @@ class CheckIntegrity:
                 self.bad_photo.append(ObjectId)
 
             def fs_ok_clicked(obj):
-                name = Utils.get_unicode_path(fs_top.get_filename())
+                name = unicode(fs_top.get_filename(),
+                               sys.getfilesystemencoding())
                 if os.path.isfile(name):
                     obj = self.db.get_object_from_handle(ObjectId)
                     obj.set_path(name)
@@ -535,7 +541,7 @@ class CheckIntegrity:
         
         for ObjectId in self.db.get_media_object_handles():
             obj = self.db.get_object_from_handle(ObjectId)
-            photo_name = obj.get_path()
+            photo_name = Utils.media_path_full(self.db, obj.get_path())
             if photo_name is not None and photo_name != "" and not Utils.find_file(photo_name):
                 if cl:
                     print "Warning: media file %s was not found." \
@@ -558,7 +564,7 @@ class CheckIntegrity:
                     elif missmedia_action == 3:
                         select_clicked()
             self.progress.step()
-            
+    
     def cleanup_empty_objects(self):
         #the position of the change column in the primary objects
         CHANGE_PERSON = 17
@@ -567,16 +573,17 @@ class CheckIntegrity:
         CHANGE_SOURCE = 8
         CHANGE_PLACE  = 11
         CHANGE_MEDIA  = 8
-        # REPOS CHANGE ONLY ADDED IN VERSION >= 3.0
-        CHANGE_REPOS  = None
+        CHANGE_REPOS  = 7
+        CHANGE_NOTE   = 5
         
-        empty_person_data = RelLib.Person().serialize()
-        empty_family_data = RelLib.Family().serialize()
-        empty_event_data = RelLib.Event().serialize()
-        empty_source_data = RelLib.Source().serialize()
-        empty_place_data = RelLib.Place().serialize()
-        empty_media_data = RelLib.MediaObject().serialize()
-        empty_repos_data = RelLib.Repository().serialize()
+        empty_person_data = gen.lib.Person().serialize()
+        empty_family_data = gen.lib.Family().serialize()
+        empty_event_data = gen.lib.Event().serialize()
+        empty_source_data = gen.lib.Source().serialize()
+        empty_place_data = gen.lib.Place().serialize()
+        empty_media_data = gen.lib.MediaObject().serialize()
+        empty_repos_data = gen.lib.Repository().serialize()
+        empty_note_data = gen.lib.Note().serialize()
 
         tables = {
             'persons' : {'get_func': self.db.get_person_from_handle,
@@ -635,6 +642,14 @@ class CheckIntegrity:
                                                     empty_repos_data, 
                                                     CHANGE_REPOS),
                          'remove'  : self.db.remove_repository},
+            'notes'   : {'get_func': self.db.get_note_from_handle,
+                         'cursor_func': self.db.get_note_cursor,
+                         'total_func' : self.db.get_number_of_notes,
+                         'progress' : _('Looking for empty note records'),
+                         'check_func' : lambda x : self._check_empty(x, 
+                                                    empty_note_data, 
+                                                    CHANGE_NOTE),
+                         'remove'  : self.db.remove_note},
             }
         for the_type in tables.keys():
             cursor = tables[the_type]['cursor_func']()
@@ -672,9 +687,8 @@ class CheckIntegrity:
 
         fhandle_list = self.db.get_family_handles()
 
-        self.progress.set_pass(
-                    _('Looking for families with no parents or children'),
-                    len(fhandle_list))
+        self.progress.set_pass(_('Looking for empty families'),
+                               len(fhandle_list))
         for family_handle in fhandle_list:
             self.progress.step()
             
@@ -721,15 +735,15 @@ class CheckIntegrity:
             else:
                 mgender = None
 
-            if (fgender == RelLib.Person.FEMALE \
-                    or mgender == RelLib.Person.MALE) \
+            if (fgender == gen.lib.Person.FEMALE \
+                    or mgender == gen.lib.Person.MALE) \
                     and fgender != mgender:
                 # swap. note: (at most) one handle may be None
                 family.set_father_handle(mother_handle)
                 family.set_mother_handle(father_handle)
                 self.db.commit_family(family,self.trans)
                 self.fam_rel.append(family_handle)
- 
+
     def check_events(self):
         self.progress.set_pass(_('Looking for event problems'),
                                self.db.get_number_of_people()
@@ -750,9 +764,9 @@ class CheckIntegrity:
                     self.db.commit_person(person,self.trans)
                     self.invalid_events.append(key)
                 else:
-                    if int(birth.get_type()) != RelLib.EventType.BIRTH:
+                    if int(birth.get_type()) != gen.lib.EventType.BIRTH:
                         # Birth event was not of the type "Birth"
-                        birth.set_type(RelLib.EventType(RelLib.EventType.BIRTH))
+                        birth.set_type(gen.lib.EventType(gen.lib.EventType.BIRTH))
                         self.db.commit_event(birth,self.trans)
                         self.invalid_birth_events.append(key)
             death_ref = person.get_death_ref()
@@ -766,9 +780,9 @@ class CheckIntegrity:
                     self.db.commit_person(person,self.trans)
                     self.invalid_events.append(key)
                 else:
-                    if int(death.get_type()) != RelLib.EventType.DEATH:
+                    if int(death.get_type()) != gen.lib.EventType.DEATH:
                         # Death event was not of the type "Death"
-                        death.set_type(RelLib.EventType(RelLib.EventType.DEATH))
+                        death.set_type(gen.lib.EventType(gen.lib.EventType.DEATH))
                         self.db.commit_event(death,self.trans)
                         self.invalid_death_events.append(key)
 
@@ -799,7 +813,10 @@ class CheckIntegrity:
                     if not event:
                         # The event referenced by the family
                         # does not exist in the database
-                        family.get_event_ref_list().remove(event_ref)
+                        print family.gramps_id
+                        nlist = [ x for x in family.get_event_ref_list() \
+                                      if x.ref != event_handle]
+                        family.set_event_ref_list(nlist)
                         self.db.commit_family(family,self.trans)
                         self.invalid_events.append(key)
             elif type(family.get_event_ref_list()) != list:
@@ -897,7 +914,7 @@ class CheckIntegrity:
         for handle in self.db.person_map.keys():
             self.progress.step()
             info = self.db.person_map[handle]
-            person = RelLib.Person()
+            person = gen.lib.Person()
             person.unserialize(info)
             handle_list = person.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -913,7 +930,7 @@ class CheckIntegrity:
         for handle in self.db.family_map.keys():
             self.progress.step()
             info = self.db.family_map[handle]
-            family = RelLib.Family()
+            family = gen.lib.Family()
             family.unserialize(info)
             handle_list = family.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -929,7 +946,7 @@ class CheckIntegrity:
         for handle in self.db.place_map.keys():
             self.progress.step()
             info = self.db.place_map[handle]
-            place = RelLib.Place()
+            place = gen.lib.Place()
             place.unserialize(info)
             handle_list = place.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -941,12 +958,28 @@ class CheckIntegrity:
                 new_bad_handles = [handle for handle in bad_handles if handle
                                    not in self.invalid_source_references]
                 self.invalid_source_references += new_bad_handles
-        
-        #I think this for loop is useless! source does not reference other sources
+
+        for handle in self.db.repository_map.keys():
+            self.progress.step()
+            info = self.db.repository_map[handle]
+            repo = gen.lib.Repository()
+            repo.unserialize(info)
+            handle_list = repo.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Source' and
+                            item[1] not in known_handles ]
+            if bad_handles:
+                repo.remove_source_references(bad_handles)
+                self.db.commit_repository(repo,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_source_references]
+                self.invalid_source_references += new_bad_handles
+
+        #I think this for loop is useless! sources in sources map exist...
         for handle in known_handles:
             self.progress.step()
             info = self.db.source_map[handle]
-            source = RelLib.Source()
+            source = gen.lib.Source()
             source.unserialize(info)
             handle_list = source.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -962,7 +995,7 @@ class CheckIntegrity:
         for handle in self.db.media_map.keys():
             self.progress.step()
             info = self.db.media_map[handle]
-            obj = RelLib.MediaObject()
+            obj = gen.lib.MediaObject()
             obj.unserialize(info)
             handle_list = obj.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -970,7 +1003,7 @@ class CheckIntegrity:
                             item[1] not in known_handles ]
             if bad_handles:
                 obj.remove_source_references(bad_handles)
-                self.db.commit_object(obj,self.trans)
+                self.db.commit_media_object(obj,self.trans)
                 new_bad_handles = [handle for handle in bad_handles if handle
                                    not in self.invalid_source_references]
                 self.invalid_source_references += new_bad_handles
@@ -978,7 +1011,7 @@ class CheckIntegrity:
         for handle in self.db.event_map.keys():
             self.progress.step()
             info = self.db.event_map[handle]
-            event = RelLib.Event()
+            event = gen.lib.Event()
             event.unserialize(info)
             handle_list = event.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -991,22 +1024,6 @@ class CheckIntegrity:
                                    not in self.invalid_source_references]
                 self.invalid_source_references += new_bad_handles
 
-        for handle in self.db.repository_map.keys():
-            self.progress.step()
-            info = self.db.repository_map[handle]
-            repo = RelLib.Repository()
-            repo.unserialize(info)
-            handle_list = repo.get_referenced_handles_recursively()
-            bad_handles = [ item[1] for item in handle_list
-                            if item[0] == 'Source' and
-                            item[1] not in known_handles ]
-            if bad_handles:
-                repo.remove_source_references(bad_handles)
-                self.db.commit_repository(repo,self.trans)
-                new_bad_handles = [handle for handle in bad_handles if handle
-                                   not in self.invalid_source_references]
-                self.invalid_source_references += new_bad_handles
-
     def check_media_references(self):
         known_handles = self.db.get_media_object_handles(False)
 
@@ -1020,7 +1037,7 @@ class CheckIntegrity:
         for handle in self.db.person_map.keys():
             self.progress.step()
             info = self.db.person_map[handle]
-            person = RelLib.Person()
+            person = gen.lib.Person()
             person.unserialize(info)
             handle_list = person.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -1036,7 +1053,7 @@ class CheckIntegrity:
         for handle in self.db.family_map.keys():
             self.progress.step()
             info = self.db.family_map[handle]
-            family = RelLib.Family()
+            family = gen.lib.Family()
             family.unserialize(info)
             handle_list = family.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -1052,7 +1069,7 @@ class CheckIntegrity:
         for handle in self.db.place_map.keys():
             self.progress.step()
             info = self.db.place_map[handle]
-            place = RelLib.Place()
+            place = gen.lib.Place()
             place.unserialize(info)
             handle_list = place.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -1068,7 +1085,7 @@ class CheckIntegrity:
         for handle in self.db.event_map.keys():
             self.progress.step()
             info = self.db.event_map[handle]
-            event = RelLib.Event()
+            event = gen.lib.Event()
             event.unserialize(info)
             handle_list = event.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -1084,7 +1101,7 @@ class CheckIntegrity:
         for handle in self.db.source_map.keys():
             self.progress.step()
             info = self.db.source_map[handle]
-            source = RelLib.Source()
+            source = gen.lib.Source()
             source.unserialize(info)
             handle_list = source.get_referenced_handles_recursively()
             bad_handles = [ item[1] for item in handle_list
@@ -1097,6 +1114,137 @@ class CheckIntegrity:
                                    not in self.invalid_media_references]
                 self.invalid_media_references += new_bad_handles
 
+    def check_note_references(self):
+        known_handles = self.db.get_note_handles()
+
+        total = self.db.get_number_of_people() + self.db.get_number_of_families() + \
+                self.db.get_number_of_events() + self.db.get_number_of_places() + \
+                self.db.get_number_of_media_objects() + \
+                self.db.get_number_of_sources() + \
+                self.db.get_number_of_repositories()
+
+        self.progress.set_pass(_('Looking for note reference problems'),
+                               total)
+        
+        for handle in self.db.person_map.keys():
+            self.progress.step()
+            info = self.db.person_map[handle]
+            person = gen.lib.Person()
+            person.unserialize(info)
+            handle_list = person.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Note' and
+                            item[1] not in known_handles ]
+            for bad_handle in bad_handles:
+                person.remove_note(bad_handle)
+            if bad_handles:
+                self.db.commit_person(person,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_note_references]
+                self.invalid_note_references += new_bad_handles
+
+        for handle in self.db.family_map.keys():
+            self.progress.step()
+            info = self.db.family_map[handle]
+            family = gen.lib.Family()
+            family.unserialize(info)
+            handle_list = family.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Note' and
+                            item[1] not in known_handles ]
+            for bad_handle in bad_handles:
+                family.remove_note(bad_handle)
+            if bad_handles:
+                self.db.commit_family(family,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_note_references]
+                self.invalid_note_references += new_bad_handles
+
+        for handle in self.db.place_map.keys():
+            self.progress.step()
+            info = self.db.place_map[handle]
+            place = gen.lib.Place()
+            place.unserialize(info)
+            handle_list = place.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Note' and
+                            item[1] not in known_handles ]
+            for bad_handle in bad_handles:
+                place.remove_note(bad_handle)
+            if bad_handles:
+                self.db.commit_place(place,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_note_references]
+                self.invalid_note_references += new_bad_handles
+
+        for handle in self.db.source_map.keys():
+            self.progress.step()
+            info = self.db.source_map[handle]
+            source = gen.lib.Source()
+            source.unserialize(info)
+            handle_list = source.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Note' and
+                            item[1] not in known_handles ]
+            for bad_handle in bad_handles:
+                source.remove_note(bad_handle)
+            if bad_handles:
+                self.db.commit_source(source,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_note_references]
+                self.invalid_note_references += new_bad_handles
+
+        for handle in self.db.media_map.keys():
+            self.progress.step()
+            info = self.db.media_map[handle]
+            obj = gen.lib.MediaObject()
+            obj.unserialize(info)
+            handle_list = obj.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Note' and
+                            item[1] not in known_handles ]
+            for bad_handle in bad_handles:
+                obj.remove_note(bad_handle)
+            if bad_handles:
+                self.db.commit_media_object(obj,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_note_references]
+                self.invalid_note_references += new_bad_handles
+
+        for handle in self.db.event_map.keys():
+            self.progress.step()
+            info = self.db.event_map[handle]
+            event = gen.lib.Event()
+            event.unserialize(info)
+            handle_list = event.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Note' and
+                            item[1] not in known_handles ]
+            for bad_handle in bad_handles:
+                event.remove_note(bad_handle)
+            if bad_handles:
+                self.db.commit_event(event,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_note_references]
+                self.invalid_note_references += new_bad_handles
+
+        for handle in self.db.repository_map.keys():
+            self.progress.step()
+            info = self.db.repository_map[handle]
+            repo = gen.lib.Repository()
+            repo.unserialize(info)
+            handle_list = repo.get_referenced_handles_recursively()
+            bad_handles = [ item[1] for item in handle_list
+                            if item[0] == 'Note' and
+                            item[1] not in known_handles ]
+            for bad_handle in bad_handles:
+                repo.remove_note(bad_handle)
+            if bad_handles:
+                self.db.commit_repository(repo,self.trans)
+                new_bad_handles = [handle for handle in bad_handles if handle
+                                   not in self.invalid_note_references]
+                self.invalid_note_references += new_bad_handles
+
     def build_report(self,cl=0):
         self.progress.close()
         bad_photos = len(self.bad_photo)
@@ -1117,6 +1265,7 @@ class CheckIntegrity:
         source_references = len(self.invalid_source_references)
         repo_references = len(self.invalid_repo_references)
         media_references = len(self.invalid_media_references)
+        note_references = len(self.invalid_note_references)
         name_format = len(self.removed_name_format)
         empty_objs = ( len(self.empty_objects['persons']) 
                         + len(self.empty_objects['families'])
@@ -1125,12 +1274,13 @@ class CheckIntegrity:
                         + len(self.empty_objects['media'])
                         + len(self.empty_objects['places'])
                         + len(self.empty_objects['repos'])
+                        + len(self.empty_objects['notes'])
                      )
 
         errors = (photos + efam + blink + plink + slink + rel
                   + event_invalid + person 
                   + person_references + place_references + source_references
-                  + repo_references + media_references
+                  + repo_references + media_references  + note_references
                   + name_format + empty_objs
                  )
         
@@ -1215,7 +1365,7 @@ class CheckIntegrity:
             self.text.write(_("1 person was referenced but not found\n"))
         elif person_references > 1:
             self.text.write(_("%d persons were referenced, but not found\n") % person_references)
-
+        
         if repo_references == 1:
             self.text.write(_("1 repository was referenced but not found\n"))
         elif repo_references > 1:
@@ -1265,19 +1415,25 @@ class CheckIntegrity:
             self.text.write(_("1 source was referenced but not found\n"))
         elif source_references > 1:
             self.text.write(_("%d sources were referenced, but not found\n") % source_references)
-        
+
         if media_references == 1:
             self.text.write(_("1 media object was referenced but not found\n"))
         elif media_references > 1:
             self.text.write(_("%d media objects were referenced, "
                               "but not found\n") % media_references)
 
+        if note_references == 1:
+            self.text.write(_("1 note object was referenced but not found\n"))
+        elif note_references > 1:
+            self.text.write(_("%d note objects were referenced, "
+                              "but not found\n") % note_references)
+
         if name_format == 1:
             self.text.write(_("1 invalid name format reference was removed\n"))
         elif name_format > 1:
             self.text.write(_("%d invalid name format references were removed\n")
                             % name_format)
-                            
+
         if empty_objs > 0 :
             self.text.write(_("%d empty objects removed:\n"
                               "   %d person objects\n"
@@ -1287,6 +1443,7 @@ class CheckIntegrity:
                               "   %d media objects\n"
                               "   %d place objects\n"
                               "   %d repository objects\n"
+                              "   %d note objects\n"
                             ) % (empty_objs, 
                                  len(self.empty_objects['persons']),
                                  len(self.empty_objects['families']),
@@ -1294,8 +1451,10 @@ class CheckIntegrity:
                                  len(self.empty_objects['sources']),
                                  len(self.empty_objects['media']),
                                  len(self.empty_objects['places']),
-                                 len(self.empty_objects['repos']) 
+                                 len(self.empty_objects['repos']),
+                                 len(self.empty_objects['notes']) 
                                 ) )
+
         return errors
 
 #-------------------------------------------------------------------------
@@ -1314,7 +1473,7 @@ class Report(ManagedWindow.ManagedWindow):
         
         base = os.path.dirname(__file__)
         glade_file = base + os.sep + "summary.glade"
-        topDialog = gtk.glade.XML(glade_file,"summary","gramps")
+        topDialog = glade.XML(glade_file,"summary","gramps")
         topDialog.get_widget("close").connect('clicked',self.close)
 
         window = topDialog.get_widget("summary")
@@ -1340,8 +1499,8 @@ class CheckOptions(Tool.ToolOptions):
     Defines options and provides handling interface.
     """
 
-    def __init__(self,name,person_id=None):
-        Tool.ToolOptions.__init__(self,name,person_id)
+    def __init__(self, name,person_id=None):
+        Tool.ToolOptions.__init__(self, name,person_id)
 
 #------------------------------------------------------------------------
 #
@@ -1354,9 +1513,10 @@ register_tool(
     tool_class = Check,
     options_class = CheckOptions,
     modes = Tool.MODE_GUI | Tool.MODE_CLI,
-    translated_name = _("Check and repair database"),
+    translated_name = _("Check and Repair Database"),
     status = _("Stable"),
     author_name = "Donald N. Allingham",
     author_email = "don@gramps-project.org",
-    description=_("Checks the database for integrity problems, fixing the problems that it can")
+    description =_("Checks the database for integrity problems, fixing the "
+                   "problems that it can")
     )
