@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2007       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,31 +19,23 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: FamilyGroup.py 7956 2007-01-23 01:51:33Z pez4brian $
+# $Id: FamilyGroup.py 10152 2008-03-01 22:47:48Z pez4brian $
 
-"""Generate files/Family Group Report"""
-
-#------------------------------------------------------------------------
-#
-# Gnome/GTK modules
-#
-#------------------------------------------------------------------------
-import gtk
+"""Reports/Text Reports/Family Group Report"""
 
 #------------------------------------------------------------------------
 #
 # GRAMPS 
 #
 #------------------------------------------------------------------------
-import RelLib
-from PluginUtils import register_report
-from ReportBase import Report, ReportUtils, ReportOptions, \
+import gen.lib
+from PluginUtils import register_report, BooleanOption, FamilyOption
+from ReportBase import Report, ReportUtils, MenuReportOptions, \
      CATEGORY_TEXT, MODE_GUI, MODE_BKI, MODE_CLI
 import BaseDoc
 import DateHandler
-import Utils
 from TransUtils import sgettext as _
-from NameDisplay import displayer as _nd
+from BasicUtils import name_displayer as _nd
 
 #------------------------------------------------------------------------
 #
@@ -51,9 +44,9 @@ from NameDisplay import displayer as _nd
 #------------------------------------------------------------------------
 class FamilyGroup(Report):
 
-    def __init__(self,database,person,options_class):
+    def __init__(self, database, options_class):
         """
-        Creates the DetAncestorReport object that produces the report.
+        Create the DetAncestorReport object that produces the report.
         
         The arguments are:
 
@@ -65,96 +58,33 @@ class FamilyGroup(Report):
         that come in the options class.
         
         family_handle - Handle of the family to write report on.
+        includeAttrs  - Whether to include attributes
         """
-        Report.__init__(self,database,person,options_class)
+        Report.__init__(self, database, options_class)
+        menu = options_class.menu
 
         self.family_handle = None
 
-        family_id = options_class.handler.options_dict['family_id']
-        if family_id:
-            family_list = person.get_family_handle_list()
-            for family_handle in family_list:
-                family = database.get_family_from_handle(family_handle)
-                this_family_id = family.get_gramps_id()
-                if this_family_id == family_id:
-                    self.family_handle = family_handle
-                    break
+        family_id = menu.get_option_by_name('family_id').get_value()
+        family = database.get_family_from_gramps_id(family_id)
+        if family:
+            self.family_handle = family.get_handle()
+        else:
+            self.family_handle = None
 
-        self.recursive     = options_class.handler.options_dict['recursive']
-        self.missingInfo   = options_class.handler.options_dict['missinginfo']
-        self.generations   = options_class.handler.options_dict['generations']
-        self.incParEvents  = options_class.handler.options_dict['incParEvents']
-        self.incParAddr    = options_class.handler.options_dict['incParAddr']
-        self.incParNotes   = options_class.handler.options_dict['incParNotes']
-        self.incParNames   = options_class.handler.options_dict['incParNames']
-        self.incParMar     = options_class.handler.options_dict['incParMar']
-        self.incRelDates   = options_class.handler.options_dict['incRelDates']
-        self.incChiMar     = options_class.handler.options_dict['incChiMar']
+        self.recursive     = menu.get_option_by_name('recursive').get_value()
+        self.missingInfo   = menu.get_option_by_name('missinginfo').get_value()
+        self.generations   = menu.get_option_by_name('generations').get_value()
+        self.incParEvents  = menu.get_option_by_name('incParEvents').get_value()
+        self.incParAddr    = menu.get_option_by_name('incParAddr').get_value()
+        self.incParNotes   = menu.get_option_by_name('incParNotes').get_value()
+        self.incParNames   = menu.get_option_by_name('incParNames').get_value()
+        self.incParMar     = menu.get_option_by_name('incParMar').get_value()
+        self.incRelDates   = menu.get_option_by_name('incRelDates').get_value()
+        self.incChiMar     = menu.get_option_by_name('incChiMar').get_value()
+        self.includeAttrs  = menu.get_option_by_name('incattrs').get_value()
 
-    def define_table_styles(self):
-        """
-        Define the table  styles used by the report. 
-        """
-        cell = BaseDoc.TableCellStyle()
-        cell.set_padding(0.2)
-        cell.set_top_border(1)
-        cell.set_bottom_border(1)
-        cell.set_right_border(1)
-        cell.set_left_border(1)
-        self.doc.add_cell_style('FGR-ParentHead',cell)
-
-        cell = BaseDoc.TableCellStyle()
-        cell.set_padding(0.1)
-        cell.set_bottom_border(1)
-        cell.set_left_border(1)
-        self.doc.add_cell_style('FGR-TextContents',cell)
-
-        cell = BaseDoc.TableCellStyle()
-        cell.set_padding(0.1)
-        cell.set_bottom_border(0)
-        cell.set_left_border(1)
-        cell.set_padding(0.1)
-        self.doc.add_cell_style('FGR-TextChild1',cell)
-
-        cell = BaseDoc.TableCellStyle()
-        cell.set_padding(0.1)
-        cell.set_bottom_border(1)
-        cell.set_left_border(1)
-        cell.set_padding(0.1)
-        self.doc.add_cell_style('FGR-TextChild2',cell)
-
-        cell = BaseDoc.TableCellStyle()
-        cell.set_padding(0.1)
-        cell.set_bottom_border(1)
-        cell.set_right_border(1)
-        cell.set_left_border(1)
-        self.doc.add_cell_style('FGR-TextContentsEnd',cell)
-
-        cell = BaseDoc.TableCellStyle()
-        cell.set_padding(0.2)
-        cell.set_bottom_border(1)
-        cell.set_right_border(1)
-        cell.set_left_border(1)
-        self.doc.add_cell_style('FGR-ChildName',cell)
-
-        table = BaseDoc.TableStyle()
-        table.set_width(100)
-        table.set_columns(3)
-        table.set_column_width(0,20)
-        table.set_column_width(1,40)
-        table.set_column_width(2,40)
-        self.doc.add_table_style('FGR-ParentTable',table)
-
-        table = BaseDoc.TableStyle()
-        table.set_width(100)
-        table.set_columns(4)
-        table.set_column_width(0,7)
-        table.set_column_width(1,18)
-        table.set_column_width(2,35)
-        table.set_column_width(3,40)
-        self.doc.add_table_style('FGR-ChildTable',table)
-
-    def dump_parent_event(self,name,event):
+    def dump_parent_event(self, name,event):
         place = ""
         date = ""
         descr = ""
@@ -163,6 +93,14 @@ class FamilyGroup(Report):
             place_handle = event.get_place_handle()
             place = ReportUtils.place_name(self.database,place_handle)
             descr = event.get_description()
+            
+            if self.includeAttrs:
+                for attr in event.get_attribute_list():
+                    if descr:
+                        descr += "; "
+                    descr += _("%(type)s: %(value)s") % {
+                        'type'     : attr.get_type(),
+                        'value'    : attr.get_value() }            
 
         self.doc.start_row()
         self.doc.start_cell("FGR-TextContents")
@@ -274,7 +212,7 @@ class FamilyGroup(Report):
         elif self.missingInfo:
             self.dump_parent_line(_("Mother"),"")
 
-    def dump_parent_line(self,name,text):
+    def dump_parent_line(self, name,text):
         self.doc.start_row()
         self.doc.start_cell("FGR-TextContents")
         self.doc.start_paragraph('FGR-Normal')
@@ -293,7 +231,7 @@ class FamilyGroup(Report):
         if not person_handle and not self.missingInfo:
             return
         elif not person_handle:
-            person = RelLib.Person()
+            person = gen.lib.Person()
         else:
             person = self.database.get_person_from_handle(person_handle)
         name = _nd.display(person)
@@ -311,7 +249,7 @@ class FamilyGroup(Report):
 
         birth_ref = person.get_birth_ref()
         birth = None
-        evtName = str(RelLib.EventType())
+        evtName = str(gen.lib.EventType())
         if birth_ref:
             birth = self.database.get_event_from_handle(birth_ref.ref)
         if birth or self.missingInfo:
@@ -319,7 +257,7 @@ class FamilyGroup(Report):
 
         death_ref = person.get_death_ref()
         death = None
-        evtName = str(RelLib.EventType(RelLib.EventType.DEATH))
+        evtName = str(gen.lib.EventType(gen.lib.EventType.DEATH))
         if death_ref:
             death = self.database.get_event_from_handle(death_ref.ref)
         if death or self.missingInfo:
@@ -359,52 +297,23 @@ class FamilyGroup(Report):
                 self.doc.end_cell()
                 self.doc.end_row()
 
-        if self.incParNotes and (person.get_note() != ""):
-            self.dump_parent_line(_("Notes"),person.get_note())
+        if self.incParNotes:
+            for notehandle in person.get_note_list():
+                note = self.database.get_note_from_handle(notehandle)
+                self.dump_parent_line(_("Note"), note.get(False))
+                
+        if self.includeAttrs:
+            for attr in person.get_attribute_list():
+                self.dump_parent_line(str(attr.get_type()),attr.get_value())
 
         if self.incParNames:
             for alt_name in person.get_alternate_names():
                 name_type = str( alt_name.get_type() )
                 name = _nd.display_name(alt_name)
-                self.dump_parent_line(name_type,name)
+                self.dump_parent_line(name_type, name)
 
         self.doc.end_table()
 
-    def dump_marriage(self,family):
-        if not family:
-            return
-        m = None
-        family_ref_list = family.get_event_ref_list()
-        for event_ref in family_ref_list:
-            if event_ref:
-                event = self.database.get_event_from_handle(event_ref.ref)
-                if int(event.get_type()) == RelLib.EventType.MARRIAGE:
-                    m = event
-                    break
-
-        if m or self.missingInfo:
-            self.doc.start_table("MarriageInfo",'FGR-ParentTable')
-            self.doc.start_row()
-            self.doc.start_cell('FGR-ParentHead',3)
-            self.doc.start_paragraph('FGR-ParentName')
-            self.doc.write_text(_("Marriage:"))
-            self.doc.end_paragraph()
-            self.doc.end_cell()
-            self.doc.end_row()
-        
-            evtName = str(RelLib.EventType(RelLib.EventType.MARRIAGE))
-            self.dump_parent_event(evtName,m)
-            
-            for event_ref in family_ref_list:
-                if event_ref:
-                    event = self.database.get_event_from_handle(event_ref.ref)
-                    evtType = event.get_type()
-                    if int(evtType) != RelLib.EventType.MARRIAGE:
-                        name = Utils.format_event( evtType )
-                        self.dump_parent_event(name,event)
-            
-            self.doc.end_table()
-
     def dump_marriage(self,family):
 
         if not family:
@@ -415,7 +324,7 @@ class FamilyGroup(Report):
         for event_ref in family_list:
             if event_ref:
                 event = self.database.get_event_from_handle(event_ref.ref)
-                if event.get_type() == RelLib.EventType.MARRIAGE:
+                if event.get_type() == gen.lib.EventType.MARRIAGE:
                     m = event
                     break
 
@@ -434,12 +343,12 @@ class FamilyGroup(Report):
             for event_ref in family_list:
                 if event_ref:
                     event = self.database.get_event_from_handle(event_ref.ref)
-                    if event.get_type() != RelLib.EventType.MARRIAGE:
+                    if event.get_type() != gen.lib.EventType.MARRIAGE:
                         self.dump_parent_event(str(event.get_type()),event)
             
             self.doc.end_table()
 
-    def dump_child_event(self,text,name,event):
+    def dump_child_event(self,text, name,event):
         date = ""
         place = ""
         if event:
@@ -504,9 +413,9 @@ class FamilyGroup(Report):
             self.doc.start_cell('FGR-TextChild2')
         self.doc.start_paragraph('FGR-ChildText')
         index_str = ("%d" % index)
-        if person.get_gender() == RelLib.Person.MALE:
+        if person.get_gender() == gen.lib.Person.MALE:
             self.doc.write_text(index_str + _("acronym for male|M"))
-        elif person.get_gender() == RelLib.Person.FEMALE:
+        elif person.get_gender() == gen.lib.Person.FEMALE:
             self.doc.write_text(index_str + _("acronym for female|F"))
         else:
             self.doc.write_text(_("%dU") % index)
@@ -544,7 +453,7 @@ class FamilyGroup(Report):
                 for event_ref in family.get_event_ref_list():
                     if event_ref:
                         event = self.database.get_event_from_handle(event_ref.ref)
-                        if int(event.get_type()) == RelLib.EventType.MARRIAGE:
+                        if int(event.get_type()) == gen.lib.EventType.MARRIAGE:
                             m = event
                             break  
                 
@@ -554,7 +463,7 @@ class FamilyGroup(Report):
                     spouse_id = family.get_mother_handle()
                 else:
                     spouse_id = family.get_father_handle()
-    	    
+    
                 if spouse_id:
                     self.doc.start_row()
                     if m or index != families:
@@ -594,7 +503,7 @@ class FamilyGroup(Report):
                     self.doc.end_row()
                   
                 if m:
-                    evtName = str(RelLib.EventType(RelLib.EventType.MARRIAGE))
+                    evtName = str(gen.lib.EventType(gen.lib.EventType.MARRIAGE))
                     if index == families:
                         self.dump_child_event('FGR-TextChild2',evtName,m)
                     else:
@@ -609,7 +518,7 @@ class FamilyGroup(Report):
         mark = BaseDoc.IndexMark(title,BaseDoc.INDEX_TYPE_TOC,1)
         self.doc.write_text( title, mark )
         self.doc.end_paragraph()
-	
+
         family = self.database.get_family_from_handle(family_handle)
 
         self.dump_parent(_("Husband"),family.get_father_handle())
@@ -659,203 +568,97 @@ class FamilyGroup(Report):
 
 #------------------------------------------------------------------------
 #
-# 
+# MenuReportOptions
 #
 #------------------------------------------------------------------------
-class FamilyGroupOptions(ReportOptions):
+class FamilyGroupOptions(MenuReportOptions):
 
     """
     Defines options and provides handling interface.
     """
 
-    def __init__(self,name,person_id=None):
-        ReportOptions.__init__(self,name,person_id)
-
-    def set_new_options(self):
-        # Options specific for this report
-        self.options_dict = {
-            'family_id'    : '',
-            'recursive'    : 0,
-            'missinginfo'  : 1,
-            'generations'  : 1,
-            'incParEvents' : 0,
-            'incParAddr'   : 0,
-            'incParNotes'  : 0,
-            'incParNames'  : 0,
-            'incParMar'    : 0,
-            'incChiMar'    : 1,            
-            'incRelDates'  : 0,
-        }
-
-        self.options_help = {
-            'family_id'    : ("=ID","Gramps ID of the person's family.",
-                            "Use show=id to get ID list.",
-                            ),
-            'recursive'    : ("=0/1","Create reports for all decendants of this family.",
-                            ["Do not create reports for decendants","Create reports for decendants"],
-                            False),
-
-            'missinginfo'  : ("=0/1","Whether to include fields for missing information.",
-                            ["Do not include missing info","Include missing info"],
-                            True),
-
-            'generations'  : ("=0/1","Whether to include the generation on each report (recursive only).",
-                            ["Do not include the generation","Include the generation"],
-                            True),
-
-            'incParEvents' : ("=0/1","Whether to include events for parents.",
-                            ["Do not include parental events","Include parental events"],
-                            True),
-
-            'incParAddr'   : ("=0/1","Whether to include addresses for parents.",
-                            ["Do not include parental addresses","Include parental addresses"],
-                            True),
-                                     
-            'incParNotes'  : ("=0/1","Whether to include notes for parents.",
-                            ["Do not include parental notes","Include parental notes"],
-                            True),
-                                     
-            'incParNames'  : ("=0/1","Whether to include alternate names for parents.",
-                            ["Do not include parental names","Include parental names"],
-                            True),
-                            
-            'incParMar'    : ("=0/1","Whether to include marriage information for parents.",
-                            ["Do not include parental marriage info","Include parental marriage info"],
-                            False),
-                            
-            'incChiMar'    : ("=0/1","Whether to include marriage information for children.",
-                            ["Do not include children marriage info","Include children marriage info"],
-                            True),
-
-            'incRelDates'  : ("=0/1","Whether to include dates for relatives.",
-                            ["Do not include dates of relatives","Include dates of relatives"],
-                            True),
-        }
-
-    def get_families(self,database,person):
-        """
-        Create a mapping of all spouse names:families to be put
-        into the 'extra' option menu in the report options box.  If
-        the selected person has never been married then this routine
-        will return a placebo label and disable the OK button.
-        """
-        families = []
-        family_id = None
-        family_list = person.get_family_handle_list()
-        for family_handle in family_list:
-            family = database.get_family_from_handle(family_handle)
-            family_id = family.get_gramps_id()
-            if person.get_handle() == family.get_father_handle():
-                spouse_handle = family.get_mother_handle()
-            else:
-                spouse_handle = family.get_father_handle()
-            if spouse_handle:
-                spouse = database.get_person_from_handle(spouse_handle)
-                name = spouse.get_primary_name().get_name()
-            else:
-                name = _("unknown")
-            name = "%s (%s)" % (name,family_id)
-            families.append((family_id,name))
-        return families
-
-    def add_user_options(self,dialog):
-        """
-        Override the base class add_user_options task to add a menu that allows
-        the user to select the sort method.
-        """
+    def __init__(self, name, dbase):
+        MenuReportOptions.__init__(self, name, dbase)
         
-        families = self.get_families(dialog.db,dialog.person)
-        family_id = self.options_dict['family_id']
-
-        self.spouse_menu = gtk.combo_box_new_text()
-        index = 0
-        family_index = 0
-        for item in families:
-            self.spouse_menu.append_text(item[1])
-            if item[0] == family_id:
-                family_index = index
-            index = index + 1
-        self.spouse_menu.set_active(family_index)
-	
-        # Recursive
-        self.recursive_option = gtk.CheckButton()
-        self.recursive_option.set_active(self.options_dict['recursive'])
-	
-        # Missing Info
-        self.missing_info_option = gtk.CheckButton(_("Print fields for missing information"))
-        self.missing_info_option.set_active(self.options_dict['missinginfo'])
-	
-        # Generations
-        self.include_generations_option = gtk.CheckButton(_("Generation numbers (recursive only)"))
-        self.include_generations_option.set_active(self.options_dict['generations'])
-	
-        # Parental Events
-        self.include_par_events_option = gtk.CheckButton(_("Parent Events"))
-        self.include_par_events_option.set_active(self.options_dict['incParEvents'])
+    def add_menu_options(self, menu):
         
-        # Parental Addresses
-        self.include_par_addr_option = gtk.CheckButton(_("Parent Addresses"))
-        self.include_par_addr_option.set_active(self.options_dict['incParAddr'])
-	
-        # Parental Notes
-        self.include_par_notes_option = gtk.CheckButton(_("Parent Notes"))
-        self.include_par_notes_option.set_active(self.options_dict['incParNotes'])
+        ##########################
+        category_name = _("Report Options")
+        ##########################
         
-        # Parental Names
-        self.include_par_names_option = gtk.CheckButton(_("Alternate Parent Names"))
-        self.include_par_names_option.set_active(self.options_dict['incParNames'])
+        family_id = FamilyOption(_("Center Family"))
+        family_id.set_help(_("The center family for the report"))
+        menu.add_option(category_name, "family_id", family_id)
         
-        # Parental Marriage
-        self.include_par_marriage_option = gtk.CheckButton(_("Parent Marriage"))
-        self.include_par_marriage_option.set_active(self.options_dict['incParMar'])
+        recursive = BooleanOption(_('Recursive'),False)
+        recursive.set_help(_("Create reports for all descendants "
+                             "of this family."))
+        menu.add_option(category_name,"recursive",recursive)
         
-        # Relatives Dates
-        self.include_rel_dates_option = gtk.CheckButton(_("Dates of Relatives (father, mother, spouse)"))
-        self.include_rel_dates_option.set_active(self.options_dict['incRelDates'])
-
-        # Children Marriages
-        self.include_chi_marriage_option = gtk.CheckButton(_("Children Marriages"))
-        self.include_chi_marriage_option.set_active(self.options_dict['incChiMar'])
-
-        dialog.add_option(_("Spouse"),self.spouse_menu)
-        dialog.add_option(_("Recursive"),self.recursive_option)
-        dialog.add_frame_option(_('Include'),'',self.include_generations_option)
-        dialog.add_frame_option(_('Include'),'',self.include_par_events_option)
-        dialog.add_frame_option(_('Include'),'',self.include_par_addr_option)
-        dialog.add_frame_option(_('Include'),'',self.include_par_notes_option)
-        dialog.add_frame_option(_('Include'),'',self.include_par_names_option)
-        dialog.add_frame_option(_('Include'),'',self.include_par_marriage_option)
-        dialog.add_frame_option(_('Include'),'',self.include_chi_marriage_option)
-        dialog.add_frame_option(_('Include'),'',self.include_rel_dates_option)
-        dialog.add_frame_option(_('Missing Information'),'',self.missing_info_option)
-
-    def parse_user_options(self,dialog):
-        """
-        Parses the custom options that we have added.
-        """
-        families = self.get_families(dialog.db,dialog.person)
-        family_index = self.spouse_menu.get_active()
-        if families:
-            self.options_dict['family_id'] = families[family_index][0]
-	    
-        self.options_dict['recursive']    = int(self.recursive_option.get_active())
-        self.options_dict['missinginfo']  = int(self.missing_info_option.get_active())
-        self.options_dict['generations']  = int(self.include_generations_option.get_active())
-        self.options_dict['incParEvents'] = int(self.include_par_events_option.get_active())
-        self.options_dict['incParAddr']   = int(self.include_par_addr_option.get_active())
-        self.options_dict['incParNotes']  = int(self.include_par_notes_option.get_active())
-        self.options_dict['incParNames']  = int(self.include_par_names_option.get_active())
-        self.options_dict['incParMar']    = int(self.include_par_marriage_option.get_active())
-        self.options_dict['incChiMar']    = int(self.include_chi_marriage_option.get_active())
-        self.options_dict['incRelDates']  = int(self.include_rel_dates_option.get_active())
+        ##########################
+        category_name = _("Include")
+        ##########################
+        
+        generations = BooleanOption(_("Generation numbers "
+                                      "(recursive only)"),True)
+        generations.set_help(_("Whether to include the generation on each "
+                               "report (recursive only)."))
+        menu.add_option(category_name,"generations",generations)
+        
+        incParEvents = BooleanOption(_("Parent Events"),False)
+        incParEvents.set_help(_("Whether to include events for parents."))
+        menu.add_option(category_name,"incParEvents",incParEvents)
+        
+        incParAddr = BooleanOption(_("Parent Addresses"),False)
+        incParAddr.set_help(_("Whether to include addresses for parents."))
+        menu.add_option(category_name,"incParAddr",incParAddr)
+        
+        incParNotes = BooleanOption(_("Parent Notes"),False)
+        incParNotes.set_help(_("Whether to include notes for parents."))
+        menu.add_option(category_name,"incParNotes",incParNotes)
+        
+        incattrs = BooleanOption(_("Parent Attributes"),False)
+        incattrs.set_help(_("Whether to include attributes."))
+        menu.add_option(category_name,"incattrs",incattrs)
+        
+        incParNames = BooleanOption(_("Alternate Parent Names"),False)
+        incParNames.set_help(_("Whether to include alternate "
+                               "names for parents."))
+        menu.add_option(category_name,"incParNames",incParNames)
+        
+        incParMar = BooleanOption(_("Parent Marriage"),False)
+        incParMar.set_help(_("Whether to include marriage information "
+                             "for parents."))
+        menu.add_option(category_name,"incParMar",incParMar)
+        
+        incRelDates = BooleanOption(_("Dates of Relatives"),False)
+        incRelDates.set_help(_("Whether to include dates for relatives "
+                               "(father, mother, spouse)."))
+        menu.add_option(category_name,"incRelDates",incRelDates)
+        
+        incChiMar = BooleanOption(_("Children Marriages"),True)
+        incChiMar.set_help(_("Whether to include marriage information "
+                             "for children."))
+        menu.add_option(category_name,"incChiMar",incChiMar)
+        
+        ##########################
+        category_name = _("Missing Information")
+        ##########################
+                
+        missinginfo = BooleanOption(_("Print fields for missing "
+                                      "information"),True)
+        missinginfo.set_help(_("Whether to include fields for missing "
+                               "information."))
+        menu.add_option(category_name,"missinginfo",missinginfo)
 
     def make_default_style(self,default_style):
         """Make default output style for the Family Group Report."""
         para = BaseDoc.ParagraphStyle()
+        #Paragraph Styles
         font = BaseDoc.FontStyle()
         font.set_size(4)
         para.set_font(font)
-        default_style.add_style('FGR-blank',para)
+        default_style.add_paragraph_style('FGR-blank',para)
 
         font = BaseDoc.FontStyle()
         font.set_type_face(BaseDoc.FONT_SANS_SERIF)
@@ -865,7 +668,7 @@ class FamilyGroupOptions(ReportOptions):
         para.set_font(font)
         para.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
         para.set_description(_("The style used for the title of the page."))
-        default_style.add_style('FGR-Title',para)
+        default_style.add_paragraph_style('FGR-Title',para)
 
         font = BaseDoc.FontStyle()
         font.set_type_face(BaseDoc.FONT_SERIF)
@@ -874,7 +677,7 @@ class FamilyGroupOptions(ReportOptions):
         para = BaseDoc.ParagraphStyle()
         para.set_font(font)
         para.set_description(_('The basic style used for the text display.'))
-        default_style.add_style('FGR-Normal',para)
+        default_style.add_paragraph_style('FGR-Normal',para)
 
         font = BaseDoc.FontStyle()
         font.set_type_face(BaseDoc.FONT_SANS_SERIF)
@@ -883,7 +686,7 @@ class FamilyGroupOptions(ReportOptions):
         para = BaseDoc.ParagraphStyle()
         para.set_font(font)
         para.set_description(_('The style used for the text related to the children.'))
-        default_style.add_style('FGR-ChildText',para)
+        default_style.add_paragraph_style('FGR-ChildText',para)
 
         font = BaseDoc.FontStyle()
         font.set_type_face(BaseDoc.FONT_SANS_SERIF)
@@ -892,7 +695,67 @@ class FamilyGroupOptions(ReportOptions):
         para = BaseDoc.ParagraphStyle()
         para.set_font(font)
         para.set_description(_("The style used for the parent's name"))
-        default_style.add_style('FGR-ParentName',para)
+        default_style.add_paragraph_style('FGR-ParentName',para)
+        
+        #Table Styles
+        cell = BaseDoc.TableCellStyle()
+        cell.set_padding(0.2)
+        cell.set_top_border(1)
+        cell.set_bottom_border(1)
+        cell.set_right_border(1)
+        cell.set_left_border(1)
+        default_style.add_cell_style('FGR-ParentHead',cell)
+
+        cell = BaseDoc.TableCellStyle()
+        cell.set_padding(0.1)
+        cell.set_bottom_border(1)
+        cell.set_left_border(1)
+        default_style.add_cell_style('FGR-TextContents',cell)
+
+        cell = BaseDoc.TableCellStyle()
+        cell.set_padding(0.1)
+        cell.set_bottom_border(0)
+        cell.set_left_border(1)
+        cell.set_padding(0.1)
+        default_style.add_cell_style('FGR-TextChild1',cell)
+
+        cell = BaseDoc.TableCellStyle()
+        cell.set_padding(0.1)
+        cell.set_bottom_border(1)
+        cell.set_left_border(1)
+        cell.set_padding(0.1)
+        default_style.add_cell_style('FGR-TextChild2',cell)
+
+        cell = BaseDoc.TableCellStyle()
+        cell.set_padding(0.1)
+        cell.set_bottom_border(1)
+        cell.set_right_border(1)
+        cell.set_left_border(1)
+        default_style.add_cell_style('FGR-TextContentsEnd',cell)
+
+        cell = BaseDoc.TableCellStyle()
+        cell.set_padding(0.2)
+        cell.set_bottom_border(1)
+        cell.set_right_border(1)
+        cell.set_left_border(1)
+        default_style.add_cell_style('FGR-ChildName',cell)
+
+        table = BaseDoc.TableStyle()
+        table.set_width(100)
+        table.set_columns(3)
+        table.set_column_width(0,20)
+        table.set_column_width(1,40)
+        table.set_column_width(2,40)
+        default_style.add_table_style('FGR-ParentTable',table)
+
+        table = BaseDoc.TableStyle()
+        table.set_width(100)
+        table.set_columns(4)
+        table.set_column_width(0,7)
+        table.set_column_width(1,18)
+        table.set_column_width(2,35)
+        table.set_column_width(3,40)
+        default_style.add_table_style('FGR-ChildTable',table)
 
 #------------------------------------------------------------------------
 #
@@ -909,6 +772,6 @@ register_report(
     status = _("Stable"),
     author_name = "Donald N. Allingham",
     author_email = "don@gramps-project.org",
-    description=_("Creates a family group report, showing information "
-                  "on a set of parents and their children."),
+    description = _("Produces a family group report showing information "
+                    "on a set of parents and their children."),
     )
