@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2003-2006  Donald N. Allingham
+# Copyright (C) 2003-2006 Donald N. Allingham
+# Copyright (C) 2007-2008 Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: FanChart.py 7408 2006-10-16 03:15:58Z pez4brian $
+# $Id: FanChart.py 10152 2008-03-01 22:47:48Z pez4brian $
 
 #------------------------------------------------------------------------
 #
@@ -27,13 +28,6 @@
 #------------------------------------------------------------------------
 from gettext import gettext as _
 
-#------------------------------------------------------------------------
-#
-# gnome/gtk
-#
-#------------------------------------------------------------------------
-import gtk
-
 #------------------------------------------------------------------------
 #
 # gramps modules
@@ -41,9 +35,26 @@ import gtk
 #------------------------------------------------------------------------
 import BaseDoc
 from PluginUtils import register_report
-from ReportBase import Report, ReportUtils, ReportOptions, \
-     CATEGORY_DRAW, MODE_GUI, MODE_BKI, MODE_CLI
+from PluginUtils import NumberOption, EnumeratedListOption, PersonOption
+from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_DRAW, \
+    MODE_GUI, MODE_BKI, MODE_CLI
 from SubstKeywords import SubstKeywords
+
+#------------------------------------------------------------------------
+#
+# private constants
+#
+#------------------------------------------------------------------------
+FULL_CIRCLE = 0
+HALF_CIRCLE = 1
+QUAR_CIRCLE = 2
+
+BACKGROUND_WHITE = 0
+BACKGROUND_GEN   = 1
+
+RADIAL_UPRIGHT    = 0
+RADIAL_ROUNDABOUT = 1
+
 pt2cm = ReportUtils.pt2cm
 
 #------------------------------------------------------------------------
@@ -53,9 +64,9 @@ pt2cm = ReportUtils.pt2cm
 #------------------------------------------------------------------------
 class FanChart(Report):
 
-    def __init__(self,database,person,options_class):
+    def __init__(self, database, options_class):
         """
-        Creates the FanChart object that produces the report.
+        Create the FanChart object that produces the report.
         
         The arguments are:
 
@@ -67,75 +78,39 @@ class FanChart(Report):
         that come in the options class.
         
         maxgen          - Maximum number of generations to include.
-        full_circle     - != 0: draw a full circle; half_circle and quar_circle should be 0.
-        half_circle     - != 0: draw a half circle; full_circle and quar_circle should be 0.
-        quar_circle     - != 0: draw a quarter circle; full_circle and half_circle should be 0.
-        backgr_white    - 0: Background color is generation dependent; 1: Background color is white.
-        radial_upright  - 0: Print radial texts roundabout; 1: Print radial texts as upright as possible.
+        circle          - Draw a full circle, half circle, or quarter circle.
+        background      - Background color is generation dependent or white.
+        radial          - Print radial texts roundabout or as upright as possible.
         """
 
-        self.background_color_generation =\
-        [(255,63,0), (255,175,15), (255,223,87), (255,255,111),
-         (159,255,159), (111,215,255), (79,151,255), (231,23,255)]
-
-        self.max_generations = options_class.handler.options_dict['maxgen']
-        self.full_circle = options_class.handler.options_dict['full_circle']
-        self.half_circle = options_class.handler.options_dict['half_circle']
-        self.quar_circle = options_class.handler.options_dict['quar_circle']
-        self.backgr_white = options_class.handler.options_dict['backgr_white']
-        self.radial_upright = options_class.handler.options_dict['radial_upright']
+        menu = options_class.menu
+        self.max_generations = menu.get_option_by_name('maxgen').get_value()
+        self.circle          = menu.get_option_by_name('circle').get_value()
+        self.background      = menu.get_option_by_name('background').get_value()
+        self.radial          = menu.get_option_by_name('radial').get_value()
+        pid                  = menu.get_option_by_name('pid').get_value()
+        self.center_person = database.get_person_from_gramps_id(pid)
 
         self.background_style = []
         self.text_style = []
         for i in range (0, self.max_generations):
-            background_style_name = 'background_style' + '%d' % i
+            if self.background == BACKGROUND_WHITE:
+                background_style_name = 'background_style_white'
+            else:
+                background_style_name = 'background_style' + '%d' % i
             self.background_style.append(background_style_name)
             text_style_name = 'text_style' + '%d' % i
             self.text_style.append(text_style_name)
 
-        if self.backgr_white:
-            self.background_color = []
-            for i in range (0, len (self.background_color_generation)):
-                self.background_color.append ((255,255,255))
-        else:
-            self.background_color = self.background_color_generation
-        self.MAX_GENERATION = len (self.background_color)
-
-        Report.__init__(self,database,person,options_class)
+        Report.__init__(self, database, options_class)
 
         self.height = 0
         self.lines = 0
         self.display = "%n"
         self.map = [None] * 2**self.max_generations
-        self.text= {}
+        self.text = {}
         self.box_width = 0
 
-
-    def define_graphics_styles(self):
-        g = BaseDoc.GraphicsStyle()
-        g.set_paragraph_style('FC-Title')
-        g.set_line_width(0)
-        self.doc.add_draw_style("t",g)
-
-        for i in range (0, self.max_generations):
-            # Continuous colors:
-            color_index = i % self.MAX_GENERATION
-            
-            g = BaseDoc.GraphicsStyle()
-            g.set_fill_color(self.background_color[color_index])
-            g.set_paragraph_style('FC-Normal')
-            background_style_name = 'background_style' + '%d' % i
-            self.doc.add_draw_style(background_style_name,g)
-
-            g = BaseDoc.GraphicsStyle()
-            g.set_fill_color(self.background_color[color_index])
-            text_style_name = 'text_style' + '%d' % (self.max_generations - 1)
-            g.set_paragraph_style(text_style_name)
-            g.set_line_width(0)
-            text_style_name = 'text_style' + '%d' % i
-            self.doc.add_draw_style(text_style_name,g)
-
-
     def apply_filter(self,person_handle,index):
         """traverse the ancestors recursively until either the end
         of a line is found, or until we reach the maximum number of 
@@ -152,8 +127,8 @@ class FanChart(Report):
         for line in self.display:
             self.text[index-1].append(subst.replace(line))
 
-        text_style_name = 'text_style' + '%d' % (self.max_generations - 1)
-        self.font = self.doc.style_list[text_style_name].get_font()
+        style_sheet = self.doc.get_style_sheet()
+        self.font = style_sheet.get_paragraph_style('text_style').get_font()
         for line in self.text[index-1]:
             self.box_width = max(self.box_width,self.doc.string_width(self.font,line))
 
@@ -171,10 +146,10 @@ class FanChart(Report):
 
         self.doc.start_page()
         
-        self.apply_filter(self.start_person.get_handle(),1)
-        n = self.start_person.get_primary_name().get_regular_name()
+        self.apply_filter(self.center_person.get_handle(),1)
+        n = self.center_person.get_primary_name().get_regular_name()
 
-        if self.full_circle:
+        if self.circle == FULL_CIRCLE:
             max_angle = 360.0
             start_angle = 90
             max_circular = 5
@@ -182,7 +157,7 @@ class FanChart(Report):
             y = self.doc.get_usable_height() / 2.0
             min_xy = min (x, y)
 
-        elif self.half_circle:
+        elif self.circle == HALF_CIRCLE:
             max_angle = 180.0
             start_angle = 180
             max_circular = 3
@@ -198,12 +173,24 @@ class FanChart(Report):
             y = self.doc.get_usable_height()
             min_xy = min (self.doc.get_usable_width(), y)
 
+        if self.circle == FULL_CIRCLE or self.circle == QUAR_CIRCLE:
+            # adjust only if full circle or 1/4 circle in landscape mode
+            if self.doc.get_usable_height() <= self.doc.get_usable_width():
+                # Should be in Landscape now
+                style_sheet = self.doc.get_style_sheet()
+                fontsize = pt2cm(style_sheet.get_paragraph_style('FC-Title').get_font().get_size())
+                # y is vertical distance to center of circle, move center down 1 fontsize
+                y = y + fontsize
+                # min_XY is the diamter of the circle, subtract two fontsize
+                # so we dont draw outside bottom of the paper
+                min_xy = min(min_xy,y-2*fontsize)
         if self.max_generations > max_circular:
             block_size = min_xy / (self.max_generations * 2 - max_circular)
         else:
             block_size = min_xy / self.max_generations
-        self.doc.center_text ('t', _('%d Generation Fan Chart for %s') % (self.max_generations, n),
-                             self.doc.get_usable_width() / 2, 0)
+        text = _("%(generations)d Generation Fan Chart for %(person)s" ) % \
+                 { 'generations' : self.max_generations, 'person' : n }
+        self.doc.center_text ('t', text, self.doc.get_usable_width() / 2, 0)
 
         for generation in range (0, min (max_circular, self.max_generations)):
             self.draw_circular (x, y, start_angle, max_angle, block_size, generation)
@@ -250,9 +237,9 @@ class FanChart(Report):
             else:
                 name = pn.get_first_name() + pn.get_surname()
 
-            if self.full_circle:
+            if self.circle == FULL_CIRCLE:
                 return [ name, val ]
-            elif self.half_circle:
+            elif self.circle == HALF_CIRCLE:
                 return [ name, val ]
             else:
                 if (name != "") and (val != ""):
@@ -261,9 +248,9 @@ class FanChart(Report):
                     string = name + val
                 return [string]
         elif generation == 6:
-            if self.full_circle:
+            if self.circle == FULL_CIRCLE:
                 return [ pn.get_first_name(), pn.get_surname(), val ]
-            elif self.half_circle:
+            elif self.circle == HALF_CIRCLE:
                 return [ pn.get_first_name(), pn.get_surname(), val ]
             else:
                 if (pn.get_first_name() != "") and (pn.get_surname() != ""):
@@ -288,10 +275,10 @@ class FanChart(Report):
         for index in range(segments - 1, 2*segments - 1):
             start_angle = end_angle
             end_angle = start_angle + delta
-            (xc,yc) = self.doc.draw_wedge(background_style, x, y, rad2,
+            (xc,yc) = ReportUtils.draw_wedge(self.doc,background_style, x, y, rad2,
                                           start_angle, end_angle, rad1)
             if self.map[index]:
-                if (generation == 0) and self.full_circle:
+                if (generation == 0) and self.circle == FULL_CIRCLE:
                     yc = y
                 self.doc.rotate_text(text_style,
                                      self.get_info(self.map[index],
@@ -307,10 +294,10 @@ class FanChart(Report):
         text_angle = start_angle - delta / 2.0
         background_style = self.background_style[generation]
         text_style = self.text_style[generation]
-        if self.full_circle:
+        if self.circle == FULL_CIRCLE:
             rad1 = size * ((generation * 2) - 5)
             rad2 = size * ((generation * 2) - 3)
-        elif self.half_circle:
+        elif self.circle == HALF_CIRCLE:
             rad1 = size * ((generation * 2) - 3)
             rad2 = size * ((generation * 2) - 1)
         else:  # quarter circle
@@ -320,11 +307,11 @@ class FanChart(Report):
         for index in range(segments - 1, 2*segments - 1):
             start_angle = end_angle
             end_angle = start_angle + delta
-            (xc,yc) = self.doc.draw_wedge(background_style, x, y, rad2,
+            (xc,yc) = ReportUtils.draw_wedge(self.doc,background_style, x, y, rad2,
                                           start_angle, end_angle, rad1)
             text_angle += delta
             if self.map[index]:
-                if self.radial_upright and (start_angle >= 90) and (start_angle < 270):
+                if self.radial == RADIAL_UPRIGHT and (start_angle >= 90) and (start_angle < 270):
                     self.doc.rotate_text(text_style,
                                          self.get_info(self.map[index],
                                                        generation),
@@ -340,97 +327,63 @@ class FanChart(Report):
 # 
 #
 #------------------------------------------------------------------------
-class FanChartOptions(ReportOptions):
+class FanChartOptions(MenuReportOptions):
 
-    """
-    Defines options and provides handling interface for Fan Chart.
-    """
-
-    def __init__(self,name,person_id=None):
-        ReportOptions.__init__(self,name,person_id)
-
-
-    def set_new_options(self):
-        # Options specific for this report
-        self.options_dict = {
-            'maxgen'    : 5,
-            'full_circle' : 0,
-            'half_circle' : 1,
-            'quar_circle' : 0,
-            'backgr_white' : 0,
-            'backgr_generation' : 1,
-            'radial_upright' : 1,
-            'radial_roundabout' : 0,
-        }
-        self.options_help = {
-            'maxgen'    : ("=num","Number of generations to print.",
-                            [],
-                            True),
-            'full_circle': ("=0/1","The form of the diagram shall be a full circle.",
-                            ["half or quarter circle","full circle"],
-                            True),
-            'half_circle': ("=0/1","The form of the diagram shall be a half circle.",
-                            ["full or quarter circle","half circle"],
-                            True),
-            'quar_circle': ("=0/1","The form of the diagram shall be a quarter circle.",
-                            ["full or half circle","quarter circle"],
-                            True),
-            'backgr_white': ("=0/1","Background color is white.",
-                             ["generation dependent","white"],
-                             True),
-            'backgr_generation': ("=0/1","Background color is generation dependent.",
-                                  ["white","generation dependent"],
-                                  True),
-            'radial_upright': ("=0/1","Print radial texts as upright as possible.",
-                                ["roundabout","upright"],
-                                True),
-            'radial_roundabout': ("=0/1","Print radial texts roundabout.",
-                                  ["upright","roundabout"],
-                                  True),
-        }
-
-    def add_user_options(self,dialog):
+    def __init__(self, name, dbase):
+        self.MAX_GENERATIONS = 8
+        
+        MenuReportOptions.__init__(self, name, dbase)
+        
+    def add_menu_options(self, menu):
         """
-        Override the base class add_user_options task to add a menu that allows
-        the user to select the number of generations to print, ....
+        Add options to the menu for the fan chart.
         """
-        self.max_gen = gtk.SpinButton(gtk.Adjustment(5,2,8,1))
-        self.max_gen.set_value(self.options_dict['maxgen'])
-        self.max_gen.set_wrap(True)
-        dialog.add_option(_('Generations'),self.max_gen)
-        self.type_box = gtk.combo_box_new_text ()
-        self.type_box.append_text (_('full circle'))
-        self.type_box.append_text (_('half circle'))
-        self.type_box.append_text (_('quarter circle'))
-        self.type_box.set_active(self.options_dict['half_circle'] + 2 * self.options_dict['quar_circle'])
-        dialog.add_option(_('Type of graph'),self.type_box)
-        self.backgr_box = gtk.combo_box_new_text ()
-        self.backgr_box.append_text (_('white'))
-        self.backgr_box.append_text (_('generation dependent'))
-        self.backgr_box.set_active(self.options_dict['backgr_generation'])
-        dialog.add_option(_('Background color'),self.backgr_box)
-        self.radial_box = gtk.combo_box_new_text ()
-        self.radial_box.append_text (_('upright'))
-        self.radial_box.append_text (_('roundabout'))
-        self.radial_box.set_active(self.options_dict['radial_roundabout'])
-        dialog.add_option(_('Orientation of radial texts'),self.radial_box)
-
-    def parse_user_options(self,dialog):
-        """
-        Parses the custom options that we have added.
-        """
-        self.options_dict['maxgen'] = int(self.max_gen.get_value_as_int())
-        self.options_dict['full_circle'] = int(self.type_box.get_active() == 0)
-        self.options_dict['half_circle'] = int(self.type_box.get_active() == 1)
-        self.options_dict['quar_circle'] = int(self.type_box.get_active() == 2)
-        self.options_dict['backgr_white'] = int(self.backgr_box.get_active() == 0)
-        self.options_dict['backgr_generation'] = int(self.backgr_box.get_active() == 1)
-        self.options_dict['radial_upright'] = int(self.radial_box.get_active() == 0)
-        self.options_dict['radial_roundabout'] = int(self.radial_box.get_active() == 1)
-
+        category_name = _("Report Options")
+    
+        pid = PersonOption(_("Center Person"))
+        pid.set_help(_("The center person for the report"))
+        menu.add_option(category_name, "pid", pid)
+            
+        max_gen = NumberOption(_("Generations"),5,1,self.MAX_GENERATIONS)
+        max_gen.set_help(_("The number of generations to include in the report"))
+        menu.add_option(category_name,"maxgen",max_gen)
+        
+        circle = EnumeratedListOption(_('Type of graph'),HALF_CIRCLE)
+        circle.add_item(FULL_CIRCLE,_('full circle'))
+        circle.add_item(HALF_CIRCLE,_('half circle'))
+        circle.add_item(QUAR_CIRCLE,_('quarter circle'))
+        circle.set_help( _("The form of the graph: full circle, half circle,"
+                           " or quarter circle."))
+        menu.add_option(category_name,"circle",circle)
+        
+        background = EnumeratedListOption(_('Background color'),BACKGROUND_GEN)
+        background.add_item(BACKGROUND_WHITE,_('white'))
+        background.add_item(BACKGROUND_GEN,_('generation dependent'))
+        background.set_help(_("Background color is either white or generation"
+                              " dependent"))
+        menu.add_option(category_name,"background",background)
+        
+        radial = EnumeratedListOption( _('Orientation of radial texts'),
+                                       RADIAL_UPRIGHT )
+        radial.add_item(RADIAL_UPRIGHT,_('upright'))
+        radial.add_item(RADIAL_ROUNDABOUT,_('roundabout'))
+        radial.set_help(_("Print raidal texts upright or roundabout"))
+        menu.add_option(category_name,"radial",radial)
 
     def make_default_style(self,default_style):
         """Make the default output style for the Fan Chart report."""
+        BACKGROUND_COLORS = [
+                             (255, 63,  0), 
+                             (255,175, 15), 
+                             (255,223, 87), 
+                             (255,255,111),
+                             (159,255,159), 
+                             (111,215,255), 
+                             ( 79,151,255), 
+                             (231, 23,255)   
+                            ]
+
+        #Paragraph Styles
         f = BaseDoc.FontStyle()
         f.set_size(20)
         f.set_bold(1)
@@ -439,19 +392,41 @@ class FanChartOptions(ReportOptions):
         p.set_font(f)
         p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
         p.set_description(_('The style used for the title.'))
-        default_style.add_style("FC-Title",p)
+        default_style.add_paragraph_style("FC-Title",p)
 
-        font_size = [48, 24, 16, 12, 9, 6, 4, 3]
-        for index in range (0, len (font_size)):
-            f = BaseDoc.FontStyle()
-            f.set_size(font_size[index])
-            f.set_type_face(BaseDoc.FONT_SANS_SERIF)
-            p = BaseDoc.ParagraphStyle()
-            p.set_font(f)
-            p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
-            p.set_description(_('The basic style used for the text display.'))
-            default_style.add_style("text_style%d" % index, p)
+        f = BaseDoc.FontStyle()
+        f.set_size(9)
+        f.set_type_face(BaseDoc.FONT_SANS_SERIF)
+        p = BaseDoc.ParagraphStyle()
+        p.set_font(f)
+        p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
+        p.set_description(_('The basic style used for the text display.'))
+        default_style.add_paragraph_style("text_style", p)
+            
+        # GraphicsStyles
+        g = BaseDoc.GraphicsStyle()
+        g.set_paragraph_style('FC-Title')
+        g.set_line_width(0)
+        default_style.add_draw_style("t",g)
 
+        for i in range (0, self.MAX_GENERATIONS):
+            g = BaseDoc.GraphicsStyle()
+            g.set_fill_color(BACKGROUND_COLORS[i])
+            g.set_paragraph_style('FC-Normal')
+            background_style_name = 'background_style' + '%d' % i
+            default_style.add_draw_style(background_style_name,g)
+
+            g = BaseDoc.GraphicsStyle()
+            g.set_fill_color(BACKGROUND_COLORS[i])
+            g.set_paragraph_style('text_style')
+            g.set_line_width(0)
+            text_style_name = 'text_style' + '%d' % i
+            default_style.add_draw_style(text_style_name,g)
+            
+        g = BaseDoc.GraphicsStyle()
+        g.set_fill_color((255,255,255))
+        g.set_paragraph_style('FC-Normal')
+        default_style.add_draw_style('background_style_white',g)
 
 #------------------------------------------------------------------------
 #
