@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: FindDupes.py 7837 2006-12-22 19:24:46Z dallingham $
+# $Id: FindDupes.py 10152 2008-03-01 22:47:48Z pez4brian $
 
-"Database Processing/Merge people"
+"""Tools/Database Processing/Find Possible Duplicate People"""
 
 #-------------------------------------------------------------------------
 #
@@ -35,23 +35,25 @@ from gettext import gettext as _
 # GNOME libraries
 #
 #-------------------------------------------------------------------------
-import gtk 
-import gtk.glade
+import gtk
+from gtk import glade
 
 #-------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import RelLib
+import gen.lib
 import Utils
 import soundex
-import NameDisplay
+from BasicUtils import name_displayer
 import ListModel
+import Errors
 from Merge import PersonCompare
 import GrampsDisplay
 import ManagedWindow
 from PluginUtils import Tool, register_tool
+from QuestionDialog import ErrorDialog, RunDatabaseRepair
 
 #-------------------------------------------------------------------------
 #
@@ -103,7 +105,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
 
         base = os.path.dirname(__file__)
         self.glade_file = "%s/%s" % (base,"merge.glade")
-        top = gtk.glade.XML(self.glade_file,"dialog","gramps")
+        top = glade.XML(self.glade_file,"dialog","gramps")
 
         # retrieve options
         threshold = self.options.handler.options_dict['threshold']
@@ -128,7 +130,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
 
         window = top.get_widget('dialog')
         self.set_window(window, top.get_widget('title'),
-                        _('Find possible duplicate people'))
+                        _('Find Possible Duplicate People'))
 
         top.signal_autoconnect({
             "on_merge_ok_clicked"   : self.on_merge_ok_clicked,
@@ -139,10 +141,10 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
 
         self.show()
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (_("Tool settings"),_("Find Duplicates tool"))
 
-    def on_help_clicked(self,obj):
+    def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
         GrampsDisplay.help('tools-db')
 
@@ -157,10 +159,14 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             self.ancestors_of(f1.get_father_handle(),id_list)
             self.ancestors_of(f1.get_mother_handle(),id_list)
 
-    def on_merge_ok_clicked(self,obj):
+    def on_merge_ok_clicked(self, obj):
         threshold = self.menu.get_menu().get_active().get_data("v")
         self.use_soundex = int(self.soundex_obj.get_active())
-        self.find_potentials(threshold)
+        try:
+            self.find_potentials(threshold)
+        except AttributeError, msg:
+            RunDatabaseRepair(str(msg))
+            return
 
         self.options.handler.options_dict['threshold'] = threshold
         self.options.handler.options_dict['soundex'] = self.use_soundex
@@ -168,16 +174,18 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         self.options.handler.save_options()
 
         if len(self.map) == 0:
-            import QuestionDialog
-            QuestionDialog.ErrorDialog(
+            ErrorDialog(
                 _("No matches found"),
                 _("No potential duplicate people were found"))
         else:
-            ShowMatches(self.dbstate,self.uistate,self.track,
-                        self.list,self.map,self.update)
+            try:
+                ShowMatches(self.dbstate,self.uistate,self.track,
+                            self.list,self.map,self.update)
+            except Errors.WindowActiveError:
+                pass
     
     def find_potentials(self,thresh):
-        self.progress = Utils.ProgressMeter(_('Find duplicates'),
+        self.progress = Utils.ProgressMeter(_('Find Duplicates'),
                                             _('Looking for duplicate people'))
 
         index = 0
@@ -194,7 +202,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             self.progress.step()
             p1 = self.db.get_person_from_handle(p1_id)
             key = self.gen_key(p1.get_primary_name().get_surname())
-            if p1.get_gender() == RelLib.Person.MALE:
+            if p1.get_gender() == gen.lib.Person.MALE:
                 if males.has_key(key):
                     males[key].append(p1_id)
                 else:
@@ -213,7 +221,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             p1 = self.db.get_person_from_handle(p1key)
 
             key = self.gen_key(p1.get_primary_name().get_surname())
-            if p1.get_gender() == RelLib.Person.MALE:
+            if p1.get_gender() == gen.lib.Person.MALE:
                 remaining = males[key]
             else:
                 remaining = females[key]
@@ -257,7 +265,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         name1 = p1.get_primary_name()
         name2 = p2.get_primary_name()
 
-        chance = self.name_match(name1,name2)
+        chance = self.name_match(name1, name2)
         if chance == -1  :
             return -1
 
@@ -265,25 +273,25 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         if birth1_ref:
             birth1 = self.db.get_event_from_handle(birth1_ref.ref)
         else:
-            birth1 = RelLib.Event()
+            birth1 = gen.lib.Event()
 
         death1_ref = p1.get_death_ref()
         if death1_ref:
             death1 = self.db.get_event_from_handle(death1_ref.ref)
         else:
-            death1 = RelLib.Event()
+            death1 = gen.lib.Event()
 
         birth2_ref = p2.get_birth_ref()
         if birth2_ref:
             birth2 = self.db.get_event_from_handle(birth2_ref.ref)
         else:
-            birth2 = RelLib.Event()
+            birth2 = gen.lib.Event()
 
         death2_ref = p2.get_death_ref()
         if death2_ref:
             death2 = self.db.get_event_from_handle(death2_ref.ref)
         else:
-            death2 = RelLib.Event()
+            death2 = gen.lib.Event()
 
         value = self.date_match(birth1.get_date_object(),
                                 birth2.get_date_object())
@@ -327,12 +335,12 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             f2 = self.db.get_family_from_handle(f2_id)
             dad1_id = f1.get_father_handle()
             if dad1_id:
-            	dad1 = get_name_obj(self.db.get_person_from_handle(dad1_id))
+                dad1 = get_name_obj(self.db.get_person_from_handle(dad1_id))
             else:
                 dad1 = None
             dad2_id = f2.get_father_handle()
             if dad2_id:
-            	dad2 = get_name_obj(self.db.get_person_from_handle(dad2_id))
+                dad2 = get_name_obj(self.db.get_person_from_handle(dad2_id))
             else:
                 dad2 = None
             
@@ -345,12 +353,12 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             
             mom1_id = f1.get_mother_handle()
             if mom1_id:
-            	mom1 = get_name_obj(self.db.get_person_from_handle(mom1_id))
+                mom1 = get_name_obj(self.db.get_person_from_handle(mom1_id))
             else:
                 mom1 = None
             mom2_id = f2.get_mother_handle()
             if mom2_id:
-            	mom2 = get_name_obj(self.db.get_person_from_handle(mom2_id))
+                mom2 = get_name_obj(self.db.get_person_from_handle(mom2_id))
             else:
                 mom2 = None
 
@@ -364,7 +372,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             f1 = self.db.get_family_from_handle(f1_id)
             for f2_id in p2.get_family_handle_list():
                 f2 = self.db.get_family_from_handle(f2_id)
-                if p1.get_gender() == RelLib.Person.FEMALE:
+                if p1.get_gender() == gen.lib.Person.FEMALE:
                     father1_id = f1.get_father_handle()
                     father2_id = f2.get_father_handle()
                     if father1_id and father2_id:
@@ -446,7 +454,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             else:
                 return -1
 
-    def name_match(self,name,name1):
+    def name_match(self, name, name1):
 
         if not name1 or not name:
             return 0
@@ -503,7 +511,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                 if name == name2:
                     value = value + 0.5
                     break
-                if name[0] == name2[0] and self.name_compare(name,name2):
+                if name[0] == name2[0] and self.name_compare(name, name2):
                     value = value + 0.25
                     break
         if value == 0:
@@ -524,7 +532,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                 if name == name2:
                     value = value + 0.5
                     break
-                if name[0] == name2[0] and self.name_compare(name,name2):
+                if name[0] == name2[0] and self.name_compare(name, name2):
                     value = value + 0.25
                     break
         if value == 0:
@@ -549,7 +557,7 @@ class ShowMatches(ManagedWindow.ManagedWindow):
         
         base = os.path.dirname(__file__)
         self.glade_file = "%s/%s" % (base,"merge.glade")
-        top = gtk.glade.XML(self.glade_file,"mergelist","gramps")
+        top = glade.XML(self.glade_file,"mergelist","gramps")
         window = top.get_widget("mergelist")
         self.set_window(window, top.get_widget('title'),
                         _('Potential Merges'))
@@ -570,10 +578,10 @@ class ShowMatches(ManagedWindow.ManagedWindow):
         self.redraw()
         self.show()
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (_("Merge candidates"),None)
 
-    def on_help_clicked(self,obj):
+    def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
         GrampsDisplay.help('tools-db')
 
@@ -595,11 +603,11 @@ class ShowMatches(ManagedWindow.ManagedWindow):
             p2 = self.db.get_person_from_handle(p2key)
             if not p1 or not p2:
                 continue
-            pn1 = NameDisplay.displayer.display(p1)
-            pn2 = NameDisplay.displayer.display(p2)
-            self.list.add([c, pn1, pn2,c2],(p1key,p2key))
+            pn1 = name_displayer.display(p1)
+            pn2 = name_displayer.display(p2)
+            self.list.add([c1, pn1, pn2,c2],(p1key,p2key))
 
-    def on_do_merge_clicked(self,obj):
+    def on_do_merge_clicked(self, obj):
         store,iter = self.list.selection.get_selected()
         if not iter:
             return
@@ -618,7 +626,7 @@ class ShowMatches(ManagedWindow.ManagedWindow):
         self.update()
         self.redraw()
         
-    def update_and_destroy(self,obj):
+    def update_and_destroy(self, obj):
         self.update(1)
         self.close()
         
@@ -631,7 +639,7 @@ class ShowMatches(ManagedWindow.ManagedWindow):
 def name_of(p):
     if not p:
         return ""
-    return "%s (%s)" % (NameDisplay.displayer.display(p),p.get_handle())
+    return "%s (%s)" % (name_displayer.display(p),p.get_handle())
 
 def get_name_obj(person):
     if person:
@@ -658,10 +666,9 @@ class MergeOptions(Tool.ToolOptions):
     Defines options and provides handling interface.
     """
 
-    def __init__(self,name,person_id=None):
-        Tool.ToolOptions.__init__(self,name,person_id)
+    def __init__(self, name,person_id=None):
+        Tool.ToolOptions.__init__(self, name,person_id)
 
-    def set_new_options(self):
         # Options specific for this report
         self.options_dict = {
             'soundex'   : 1,
@@ -686,10 +693,10 @@ register_tool(
     tool_class = Merge,
     options_class = MergeOptions,
     modes = Tool.MODE_GUI,
-    translated_name = _("Find possible duplicate people"),
+    translated_name = _("Find Possible Duplicate People"),
     status = _("Stable"),
     author_name = "Donald N. Allingham",
     author_email = "don@gramps-project.org",
-    description=_("Searches the entire database, looking for "
-                  "individual entries that may represent the same person.")
+    description = _("Searches the entire database, looking for "
+                    "individual entries that may represent the same person.")
     )
