@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007 Donald N. Allingham
+# Copyright (C) 2007-2008 Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: IndivComplete.py 9488 2007-12-11 08:25:16Z bmcage $
+# $Id: IndivComplete.py 10501 2008-04-06 15:32:11Z gburto01 $
 
 #------------------------------------------------------------------------
 #
@@ -28,40 +29,33 @@
 import os
 from gettext import gettext as _
 
-#------------------------------------------------------------------------
-#
-# Gnome/GTK modules
-#
-#------------------------------------------------------------------------
-import gtk
-
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import RelLib
-import const
-import Utils
+import gen.lib
 import BaseDoc
-from Filters import GenericFilter, Rules
 import DateHandler
-from PluginUtils import register_report
-from ReportBase import Report, ReportUtils, ReportOptions, \
+from PluginUtils import register_report, FilterOption, BooleanOption, \
+    PersonOption
+from ReportBase import Report, ReportUtils, MenuReportOptions, \
      CATEGORY_TEXT, MODE_GUI, MODE_BKI, MODE_CLI
-from NameDisplay import displayer as _nd
+from ReportBase import Bibliography, Endnotes
+from BasicUtils import name_displayer as _nd
+from Utils import media_path_full
 from QuestionDialog import WarningDialog
 
 #------------------------------------------------------------------------
 #
-# IndivComplete
+# IndivCompleteReport
 #
 #------------------------------------------------------------------------
 class IndivCompleteReport(Report):
 
-    def __init__(self,database,person,options_class):
+    def __init__(self, database, options_class):
         """
-        Creates the IndivCompleteReport object that produces the report.
+        Create the IndivCompleteReport object that produces the report.
         
         The arguments are:
 
@@ -78,49 +72,22 @@ class IndivCompleteReport(Report):
         cites     - Whether or not to include source informaiton.
         """
 
-        Report.__init__(self,database,person,options_class)
+        Report.__init__(self, database, options_class)
 
-        self.use_srcs = options_class.handler.options_dict['cites']
+        menu = options_class.menu
+        self.use_srcs = menu.get_option_by_name('cites').get_value()
 
-        filter_num = options_class.get_filter_number()
-        filters = options_class.get_report_filters(person)
-        self.filter = filters[filter_num]
-        self.sref_map = {}
-        
-    def define_table_styles(self):
-        tbl = BaseDoc.TableStyle()
-        tbl.set_width(100)
-        tbl.set_columns(2)
-        tbl.set_column_width(0,20)
-        tbl.set_column_width(1,80)
-        self.doc.add_table_style("IDS-IndTable",tbl)
-
-        tbl = BaseDoc.TableStyle()
-        tbl.set_width(100)
-        tbl.set_columns(2)
-        tbl.set_column_width(0,50)
-        tbl.set_column_width(1,50)
-        self.doc.add_table_style("IDS-ParentsTable",tbl)
-
-        cell = BaseDoc.TableCellStyle()
-        cell.set_top_border(1)
-        cell.set_bottom_border(1)
-        self.doc.add_cell_style("IDS-TableHead",cell)
-
-        cell = BaseDoc.TableCellStyle()
-        self.doc.add_cell_style("IDS-NormalCell",cell)
-
-        cell = BaseDoc.TableCellStyle()
-        cell.set_longlist(1)
-        self.doc.add_cell_style("IDS-ListCell",cell)
+        filter_option = options_class.menu.get_option_by_name('filter')
+        self.filter = filter_option.get_filter()
+        self.bibli = None
 
     def write_fact(self,event_ref):
         event = self.database.get_event_from_handle(event_ref.ref)
         if event == None:
             return
         text = ""
-        if event_ref.get_role() == RelLib.EventRoleType.PRIMARY or \
-           event_ref.get_role() == RelLib.EventRoleType.FAMILY:
+        if event_ref.get_role() == gen.lib.EventRoleType.PRIMARY or \
+           event_ref.get_role() == gen.lib.EventRoleType.FAMILY:
             name = str(event.get_type())
         else:
             name = '%(event)s (%(role)s)' % {'event' : str(event.get_type()),
@@ -143,10 +110,11 @@ class IndivCompleteReport(Report):
             text = '%s. ' % date
 
         description = event.get_description()
-        text = '%s%s. ' % (text,description)
+        if description:
+            text = '%s, %s' % (description, text)
         endnotes = ""
         if self.use_srcs:
-            endnotes = ReportUtils.get_endnotes(self.sref_map,event)
+            endnotes = Endnotes.cite_source(self.bibli, event)
 
         self.doc.start_row()
         self.normal_cell(name)
@@ -159,45 +127,50 @@ class IndivCompleteReport(Report):
             self.doc.end_superscript()
         self.doc.end_paragraph()
         
-        note = event.get_note()
-        if note:
-            format = event.get_note_format()
-            self.doc.write_note(note,format,'IDS-Normal')
+        for notehandle in event.get_note_list():
+            note = self.database.get_note_from_handle(notehandle)
+            text = note.get()
+            format = note.get_format()
+            self.doc.write_note(text,format, 'IDS-Normal')
         
         self.doc.end_cell()
         self.doc.end_row()
 
-    def write_p_entry(self,label,parent,rel,mark=None):
+    def write_p_entry(self, label, parent, rel, pmark=None):
         self.doc.start_row()
         self.normal_cell(label)
 
         if parent:
-            self.normal_cell('%(parent)s, relationship: %(relation)s' %
-                               { 'parent' : parent, 'relation' : rel },
-                             mark=mark)
+            text = '%(parent)s, relationship: %(relation)s' % { 
+                                                            'parent' : parent, 
+                                                            'relation' : rel }
+            self.normal_cell(text, mark=pmark)
         else:
             self.normal_cell('')
         self.doc.end_row()
 
     def write_note(self):
-        note = self.start_person.get_note()
-        if note == '':
+        notelist = self.person.get_note_list()
+        if not notelist:
             return
         self.doc.start_table('note','IDS-IndTable')
         self.doc.start_row()
-        self.doc.start_cell('IDS-TableHead',2)
+        self.doc.start_cell('IDS-TableHead', 2)
         self.doc.start_paragraph('IDS-TableTitle')
         self.doc.write_text(_('Notes'))
         self.doc.end_paragraph()
         self.doc.end_cell()
         self.doc.end_row()
 
-        self.doc.start_row()
-        self.doc.start_cell('IDS-NormalCell',2)
-        format = self.start_person.get_note_format()
-        self.doc.write_note(note,format,'IDS-Normal')
-        self.doc.end_cell()
-        self.doc.end_row()
+        for notehandle in notelist:
+            note = self.database.get_note_from_handle(notehandle)
+            text = note.get()
+            format = note.get_format()
+            self.doc.start_row()
+            self.doc.start_cell('IDS-NormalCell', 2)
+            self.doc.write_note(text,format, 'IDS-Normal')
+            self.doc.end_cell()
+            self.doc.end_row()
 
         self.doc.end_table()
         self.doc.start_paragraph("IDS-Normal")
@@ -205,22 +178,22 @@ class IndivCompleteReport(Report):
 
     def write_alt_parents(self):
 
-        if len(self.start_person.get_parent_family_handle_list()) < 2:
+        if len(self.person.get_parent_family_handle_list()) < 2:
             return
         
         self.doc.start_table("altparents","IDS-IndTable")
         self.doc.start_row()
-        self.doc.start_cell("IDS-TableHead",2)
+        self.doc.start_cell("IDS-TableHead", 2)
         self.doc.start_paragraph("IDS-TableTitle")
         self.doc.write_text(_("Alternate Parents"))
         self.doc.end_paragraph()
         self.doc.end_cell()
         self.doc.end_row()
         
-        family_handle_list = self.start_person.get_parent_family_handle_list()
+        family_handle_list = self.person.get_parent_family_handle_list()
         for family_handle in family_handle_list:
             if family_handle == \
-                   self.start_person.get_main_parents_family_handle():
+                   self.person.get_main_parents_family_handle():
                 continue
             
             family = self.database.get_family_from_handle(family_handle)
@@ -228,7 +201,7 @@ class IndivCompleteReport(Report):
             # Get the mother and father relationships
             frel = ""
             mrel = ""
-            child_handle = self.start_person.get_handle()
+            child_handle = self.person.get_handle()
             child_ref_list = family.get_child_ref_list()
             for child_ref in child_ref_list:
                 if child_ref.ref == child_handle:
@@ -259,10 +232,10 @@ class IndivCompleteReport(Report):
 
     def write_alt_names(self):
 
-        if len(self.start_person.get_alternate_names()) < 1:
+        if len(self.person.get_alternate_names()) < 1:
             return
         
-        self.doc.start_table("altparents","IDS-IndTable")
+        self.doc.start_table("altnames","IDS-IndTable")
         self.doc.start_row()
         self.doc.start_cell("IDS-TableHead",2)
         self.doc.start_paragraph("IDS-TableTitle")
@@ -271,14 +244,14 @@ class IndivCompleteReport(Report):
         self.doc.end_cell()
         self.doc.end_row()
         
-        for name in self.start_person.get_alternate_names():
+        for name in self.person.get_alternate_names():
             name_type = str( name.get_type() )
             self.doc.start_row()
             self.normal_cell(name_type)
             text = _nd.display_name(name)
             endnotes = ""
             if self.use_srcs:
-                endnotes = ReportUtils.get_endnotes(self.sref_map,name)
+                endnotes = Endnotes.cite_source(self.bibli, name)
             self.normal_cell(text,endnotes)
             self.doc.end_row()
         self.doc.end_table()
@@ -287,7 +260,7 @@ class IndivCompleteReport(Report):
         
     def write_addresses(self):
         
-        alist = self.start_person.get_address_list()
+        alist = self.person.get_address_list()
 
         if len(alist) == 0:
             return
@@ -306,7 +279,7 @@ class IndivCompleteReport(Report):
             date = DateHandler.get_date(addr)
             endnotes = ""
             if self.use_srcs:
-                endnotes = ReportUtils.get_endnotes(self.sref_map,addr)
+                endnotes = Endnotes.cite_source(self.bibli,addr)
             self.doc.start_row()
             self.normal_cell(date)
             self.normal_cell(text,endnotes)
@@ -317,35 +290,35 @@ class IndivCompleteReport(Report):
         
     def write_families(self):
 
-        if not len(self.start_person.get_family_handle_list()):
+        if not len(self.person.get_family_handle_list()):
             return
         
         self.doc.start_table("three","IDS-IndTable")
         self.doc.start_row()
-        self.doc.start_cell("IDS-TableHead",2)
+        self.doc.start_cell("IDS-TableHead", 2)
         self.doc.start_paragraph("IDS-TableTitle")
         self.doc.write_text(_("Marriages/Children"))
         self.doc.end_paragraph()
         self.doc.end_cell()
         self.doc.end_row()
         
-        for family_handle in self.start_person.get_family_handle_list():
+        for family_handle in self.person.get_family_handle_list():
             family = self.database.get_family_from_handle(family_handle)
-            if self.start_person.get_handle() == family.get_father_handle():
+            if self.person.get_handle() == family.get_father_handle():
                 spouse_id = family.get_mother_handle()
             else:
                 spouse_id = family.get_father_handle()
             self.doc.start_row()
-            self.doc.start_cell("IDS-NormalCell",2)
+            self.doc.start_cell("IDS-NormalCell", 2)
             self.doc.start_paragraph("IDS-Spouse")
             if spouse_id:
                 spouse = self.database.get_person_from_handle(spouse_id)
                 text = _nd.display(spouse)
-                mark = ReportUtils.get_person_mark(self.database,spouse)
+                mark = ReportUtils.get_person_mark(self.database, spouse)
             else:
                 text = _("unknown")
                 mark = None
-            self.doc.write_text(text,mark)
+            self.doc.write_text(text, mark)
             self.doc.end_paragraph()
             self.doc.end_cell()
             self.doc.end_row()
@@ -365,8 +338,8 @@ class IndivCompleteReport(Report):
                     self.doc.start_paragraph("IDS-Normal")
                     child = self.database.get_person_from_handle(child_ref.ref)
                     name = _nd.display(child)
-                    mark = ReportUtils.get_person_mark(self.database,child)
-                    self.doc.write_text(name,mark)
+                    mark = ReportUtils.get_person_mark(self.database, child)
+                    self.doc.write_text(name, mark)
                     self.doc.end_paragraph()
                 self.doc.end_cell()
                 self.doc.end_row()
@@ -374,35 +347,6 @@ class IndivCompleteReport(Report):
         self.doc.start_paragraph('IDS-Normal')
         self.doc.end_paragraph()
 
-    def write_sources(self):
-        keys = self.sref_map.keys()
-        if not keys:
-            return
-        
-        self.doc.start_table("three","IDS-IndTable")
-        self.doc.start_row()
-        self.doc.start_cell("IDS-TableHead",2)
-        self.doc.start_paragraph("IDS-TableTitle")
-        self.doc.write_text(_("Sources"))
-        self.doc.end_paragraph()
-        self.doc.end_cell()
-        self.doc.end_row()
-
-        keys.sort()
-        for key in keys:
-            srcref = self.sref_map[key]
-            base = self.database.get_source_from_handle(
-                srcref.get_reference_handle())
-            self.doc.start_row()
-            self.doc.start_cell('IDS-NormalCell',2)
-            self.doc.start_paragraph("IDS-Normal","%d." % key)
-            self.doc.write_text(base.get_title())
-            self.doc.end_paragraph()
-            self.doc.end_cell()
-            self.doc.end_row()
-
-        self.doc.end_table()
-
     def write_facts(self):
         self.doc.start_table("two","IDS-IndTable")
         self.doc.start_row()
@@ -413,7 +357,7 @@ class IndivCompleteReport(Report):
         self.doc.end_cell()
         self.doc.end_row()
 
-        event_ref_list = self.start_person.get_event_ref_list()
+        event_ref_list = self.person.get_event_ref_list()
         for event_ref in event_ref_list:
             if event_ref:
                 self.write_fact(event_ref)
@@ -441,7 +385,7 @@ class IndivCompleteReport(Report):
             
         count = 0
         for person_handle in ind_list:
-            self.start_person = self.database.get_person_from_handle(
+            self.person = self.database.get_person_from_handle(
                 person_handle)
             self.write_person(count)
             count = count + 1
@@ -449,11 +393,10 @@ class IndivCompleteReport(Report):
     def write_person(self,count):
         if count != 0:
             self.doc.page_break()
-        self.slist = []
-        self.sref_map = {}
+        self.bibli = Bibliography(Bibliography.MODE_PAGE)
         
-        media_list = self.start_person.get_media_list()
-        name = _nd.display(self.start_person)
+        media_list = self.person.get_media_list()
+        name = _nd.display(self.person)
         title = _("Summary of %s") % name
         mark = BaseDoc.IndexMark(title,BaseDoc.INDEX_TYPE_TOC,1)
         self.doc.start_paragraph("IDS-Title")
@@ -468,10 +411,10 @@ class IndivCompleteReport(Report):
             object = self.database.get_object_from_handle(object_handle)
             mime_type = object.get_mime_type()
             if mime_type and mime_type.startswith("image"):
-                filename = object.get_path()
+                filename = media_path_full(self.database, object.get_path())
                 if os.path.exists(filename):
                     self.doc.start_paragraph("IDS-Normal")
-                    self.doc.add_media_object(filename,"row",4.0,4.0)
+                    self.doc.add_media_object(filename, "right", 4.0, 4.0)
                     self.doc.end_paragraph()
                 else:
                     WarningDialog(_("Could not add photo to page"),
@@ -481,24 +424,26 @@ class IndivCompleteReport(Report):
 
         self.doc.start_row()
         self.normal_cell("%s:" % _("Name"))
-        name = self.start_person.get_primary_name()
+        name = self.person.get_primary_name()
         text = _nd.display_name(name)
-        mark = ReportUtils.get_person_mark(self.database, self.start_person)
+        mark = ReportUtils.get_person_mark(self.database, self.person)
         endnotes = ""
         if self.use_srcs:
-            endnotes = ReportUtils.get_endnotes(self.sref_map,name)
+            endnotes = Endnotes.cite_source(self.bibli, name)
         self.normal_cell(text,endnotes,mark)
         self.doc.end_row()
 
         self.doc.start_row()
         self.normal_cell("%s:" % _("Gender"))
-        if self.start_person.get_gender() == RelLib.Person.MALE:
+        if self.person.get_gender() == gen.lib.Person.MALE:
             self.normal_cell(_("Male"))
-        else:
+        elif self.person.get_gender() == gen.lib.Person.FEMALE:
             self.normal_cell(_("Female"))
+        else:
+            self.normal_cell(_("Unknown"))
         self.doc.end_row()
 
-        family_handle = self.start_person.get_main_parents_family_handle()
+        family_handle = self.person.get_main_parents_family_handle()
         if family_handle:
             family = self.database.get_family_from_handle(family_handle)
             father_inst_id = family.get_father_handle()
@@ -545,91 +490,71 @@ class IndivCompleteReport(Report):
         self.write_families()
         self.write_addresses()
         self.write_note()
-        self.write_sources()
-
+        if self.use_srcs:
+            Endnotes.write_endnotes(self.bibli,self.database,self.doc)
+            
 #------------------------------------------------------------------------
 #
-# 
+# IndivCompleteOptions
 #
 #------------------------------------------------------------------------
-class IndivCompleteOptions(ReportOptions):
-
+class IndivCompleteOptions(MenuReportOptions):
     """
     Defines options and provides handling interface.
     """
-
-    def __init__(self,name,person_id=None):
-        ReportOptions.__init__(self,name,person_id)
-
-    def set_new_options(self):
-        # Options specific for this report
-        self.options_dict = {
-            'cites'    : 1,
-        }
-        self.options_help = {
-            'cites'    : ("=0/1","Whether to cite sources.",
-                            ["Do not cite sources","Cite sources"],
-                            True),
-        }
-
-    def enable_options(self):
-        # Semi-common options that should be enabled for this report
-        self.enable_dict = {
-            'filter'    : 0,
-        }
-
-    def get_report_filters(self,person):
-        """Set up the list of possible content filters."""
-        if person:
-            name = _nd.display(person)
-            gramps_id = person.get_gramps_id()
-        else:
-            name = 'PERSON'
-            gramps_id = ''
-
-        filt_id = GenericFilter()
-        filt_id.set_name(name)
-        filt_id.add_rule(Rules.Person.HasIdOf([gramps_id]))
-
-        all = GenericFilter()
-        all.set_name(_("Entire Database"))
-        all.add_rule(Rules.Person.Everyone([]))
-
-        des = GenericFilter()
-        des.set_name(_("Descendants of %s") % name)
-        des.add_rule(Rules.Person.IsDescendantOf([gramps_id,1]))
-
-        ans = GenericFilter()
-        ans.set_name(_("Ancestors of %s") % name)
-        ans.add_rule(Rules.Person.IsAncestorOf([gramps_id,1]))
-
-        com = GenericFilter()
-        com.set_name(_("People with common ancestor with %s") % name)
-        com.add_rule(Rules.Person.HasCommonAncestorWith([gramps_id]))
-
-        the_filters = [filt_id,all,des,ans,com]
-        from Filters import CustomFilters
-        the_filters.extend(CustomFilters.get_filters('Person'))
-        return the_filters
-
-    def add_user_options(self,dialog):
-        """
-        Override the base class add_user_options task to add a menu that allows
-        the user to select the sort method.
-        """
+    def __init__(self, name, dbase):
+        self.__db = dbase
+        self.__pid = None
+        self.__filter = None
+        MenuReportOptions.__init__(self, name, dbase)
         
-        self.use_srcs = gtk.CheckButton(_('Include Source Information'))
-        self.use_srcs.set_active(self.options_dict['cites'])
-        dialog.add_option('',self.use_srcs)
+    def add_menu_options(self, menu):
+        ################################
+        category_name = _("Report Options")
+        ################################
+        
+        self.__filter = FilterOption(_("Filter"), 0)
+        self.__filter.set_help(
+                           _("Select the filter to be applied to the report"))
+        menu.add_option(category_name, "filter", self.__filter)
+        self.__filter.connect('value-changed', self.__filter_changed)
 
-    def parse_user_options(self,dialog):
+        self.__pid = PersonOption(_("Filter Person"))
+        self.__pid.set_help(_("The center person for the filter"))
+        menu.add_option(category_name, "pid", self.__pid)
+        self.__pid.connect('value-changed', self.__update_filters)
+        
+        self.__update_filters()
+        
+        cites = BooleanOption(_("Include Source Information"), True)
+        cites.set_help(_("Whether to cite sources."))
+        menu.add_option(category_name, "cites", cites)
+        
+    def __update_filters(self):
         """
-        Parses the custom options that we have added.
+        Update the filter list based on the selected person
         """
-        self.options_dict['cites'] = int(self.use_srcs.get_active ())
+        gid = self.__pid.get_value()
+        person = self.__db.get_person_from_gramps_id(gid)
+        filter_list = ReportUtils.get_person_filters(person, True)
+        self.__filter.set_filters(filter_list)
+        
+    def __filter_changed(self):
+        """
+        Handle filter change. If the filter is not specific to a person,
+        disable the person option
+        """
+        filter_value = self.__filter.get_value()
+        if filter_value in [0, 2, 3, 4, 5]:
+            # Filters 0, 2, 3, 4 and 5 rely on the center person
+            self.__pid.set_available(True)
+        else:
+            # The rest don't
+            self.__pid.set_available(False)
 
     def make_default_style(self,default_style):
         """Make the default output style for the Individual Complete Report."""
+        # Paragraph Styles
         font = BaseDoc.FontStyle()
         font.set_bold(1)
         font.set_type_face(BaseDoc.FONT_SANS_SERIF)
@@ -640,7 +565,7 @@ class IndivCompleteOptions(ReportOptions):
         p.set_bottom_margin(ReportUtils.pt2cm(8))
         p.set_font(font)
         p.set_description(_("The style used for the title of the page."))
-        default_style.add_style("IDS-Title",p)
+        default_style.add_paragraph_style("IDS-Title",p)
     
         font = BaseDoc.FontStyle()
         font.set_bold(1)
@@ -652,7 +577,7 @@ class IndivCompleteOptions(ReportOptions):
         p.set_top_margin(ReportUtils.pt2cm(3))
         p.set_bottom_margin(ReportUtils.pt2cm(3))
         p.set_description(_("The style used for category labels."))
-        default_style.add_style("IDS-TableTitle",p)
+        default_style.add_paragraph_style("IDS-TableTitle",p)
 
         font = BaseDoc.FontStyle()
         font.set_bold(1)
@@ -663,7 +588,7 @@ class IndivCompleteOptions(ReportOptions):
         p.set_top_margin(ReportUtils.pt2cm(3))
         p.set_bottom_margin(ReportUtils.pt2cm(3))
         p.set_description(_("The style used for the spouse's name."))
-        default_style.add_style("IDS-Spouse",p)
+        default_style.add_paragraph_style("IDS-Spouse",p)
 
         font = BaseDoc.FontStyle()
         font.set_size(12)
@@ -672,7 +597,36 @@ class IndivCompleteOptions(ReportOptions):
         p.set_top_margin(ReportUtils.pt2cm(3))
         p.set_bottom_margin(ReportUtils.pt2cm(3))
         p.set_description(_('The basic style used for the text display.'))
-        default_style.add_style("IDS-Normal",p)
+        default_style.add_paragraph_style("IDS-Normal",p)
+        
+        # Table Styles
+        tbl = BaseDoc.TableStyle()
+        tbl.set_width(100)
+        tbl.set_columns(2)
+        tbl.set_column_width(0,20)
+        tbl.set_column_width(1,80)
+        default_style.add_table_style("IDS-IndTable",tbl)
+
+        tbl = BaseDoc.TableStyle()
+        tbl.set_width(100)
+        tbl.set_columns(2)
+        tbl.set_column_width(0,50)
+        tbl.set_column_width(1,50)
+        default_style.add_table_style("IDS-ParentsTable",tbl)
+
+        cell = BaseDoc.TableCellStyle()
+        cell.set_top_border(1)
+        cell.set_bottom_border(1)
+        default_style.add_cell_style("IDS-TableHead",cell)
+
+        cell = BaseDoc.TableCellStyle()
+        default_style.add_cell_style("IDS-NormalCell",cell)
+
+        cell = BaseDoc.TableCellStyle()
+        cell.set_longlist(1)
+        default_style.add_cell_style("IDS-ListCell",cell)
+        
+        Endnotes.add_endnote_styles(default_style)
 
 #------------------------------------------------------------------------
 #
@@ -686,8 +640,8 @@ register_report(
     options_class = IndivCompleteOptions,
     modes = MODE_GUI | MODE_BKI | MODE_CLI,
     translated_name = _("Complete Individual Report"),
-    status=(_("Stable")),
-    author_name="Donald N. Allingham",
-    author_email="don@gramps-project.org",
-    description=_("Produces a complete report on the selected people."),
+    status = _("Stable"),
+    author_name = "Donald N. Allingham",
+    author_email = "don@gramps-project.org",
+    description = _("Produces a complete report on the selected people"),
     )
