@@ -18,9 +18,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: PatchNames.py 7349 2006-10-04 02:46:32Z dallingham $
+# $Id: PatchNames.py 10152 2008-03-01 22:47:48Z pez4brian $
 
-"Database Processing/Extract information from names"
+"""Tools/Database Processing/Extract Information from Names"""
 
 #-------------------------------------------------------------------------
 #
@@ -37,7 +37,8 @@ from gettext import gettext as _
 #
 #-------------------------------------------------------------------------
 import gtk
-import gtk.glade
+from gtk import glade
+import gobject
 
 #-------------------------------------------------------------------------
 #
@@ -49,7 +50,7 @@ from PluginUtils import Tool, register_tool
 from QuestionDialog import OkDialog
 import ManagedWindow
 import GrampsDisplay
-import RelLib
+import gen.lib
 
 #-------------------------------------------------------------------------
 #
@@ -103,7 +104,7 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
         self.prefix2_list = []
 
         self.progress = Utils.ProgressMeter(
-            _('Extracting information from names'),'')
+            _('Extracting Information from Names'),'')
         self.progress.set_pass(_('Analyzing names'),
                                self.db.get_number_of_people())
 
@@ -144,7 +145,7 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
             if match:
                 groups = match.groups()
                 self.prefix1_list.append((key,groups[0],
-                                          " ".join([groups[1],old_prefix]))
+                                          " ".join([groups[1], old_prefix]))
                                          )
                 continue
             
@@ -165,7 +166,7 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
             OkDialog(_('No modifications made'),
                      _("No titles or nicknames were found"))
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (self.label,None)
 
     def toggled(self,cell,path_string):
@@ -179,7 +180,7 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
         base = os.path.dirname(__file__)
         glade_file = os.path.join(base,"patchnames.glade")
         
-        self.top = gtk.glade.XML(glade_file,"top","gramps")
+        self.top = glade.XML(glade_file,"top","gramps")
         window = self.top.get_widget('top')
         self.top.signal_autoconnect({
             "destroy_passed_object" : self.close,
@@ -190,7 +191,9 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
         self.list = self.top.get_widget("list")
         self.set_window(window,self.top.get_widget('title'),self.label)
 
-        self.model = gtk.ListStore(bool, str, str, str, str)
+        self.model = gtk.ListStore(gobject.TYPE_BOOLEAN, gobject.TYPE_STRING, 
+                                   gobject.TYPE_STRING, gobject.TYPE_STRING, 
+                                   gobject.TYPE_STRING)
 
         r = gtk.CellRendererToggle()
         r.connect('toggled',self.toggled)
@@ -227,7 +230,7 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
             self.model.set_value(handle,0,1)
             self.model.set_value(handle,1,gid)
             self.model.set_value(handle,2,_('Nickname'))
-            self.model.set_value(handle,3,nick)
+            self.model.set_value(handle,3, nick)
             self.model.set_value(handle,4,p.get_primary_name().get_name())
             self.nick_hash[pid] = handle
             self.progress.step()
@@ -271,11 +274,11 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
         self.progress.close()
         self.show()
 
-    def on_help_clicked(self,obj):
+    def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
         GrampsDisplay.help('tools-db')
 
-    def on_ok_clicked(self,obj):
+    def on_ok_clicked(self, obj):
         self.trans = self.db.transaction_begin("",batch=True)
         self.db.disable_signals()
         for grp in self.nick_list:
@@ -286,8 +289,8 @@ class PatchNames(Tool.BatchTool, ManagedWindow.ManagedWindow):
                 name = p.get_primary_name()
                 name.set_first_name(grp[1].strip())
                 nick_name = grp[2].strip()
-                attr = RelLib.Attribute()
-                attr.set_type(RelLib.AttributeType.NICKNAME)
+                attr = gen.lib.Attribute()
+                attr.set_type(gen.lib.AttributeType.NICKNAME)
                 attr.set_value(nick_name)
                 p.add_attribute(attr)
                 self.db.commit_person(p,self.trans)
@@ -339,8 +342,8 @@ class PatchNamesOptions(Tool.ToolOptions):
     Defines options and provides handling interface.
     """
 
-    def __init__(self,name,person_id=None):
-        Tool.ToolOptions.__init__(self,name,person_id)
+    def __init__(self, name,person_id=None):
+        Tool.ToolOptions.__init__(self, name,person_id)
 
 #-------------------------------------------------------------------------
 #
@@ -353,11 +356,11 @@ register_tool(
     tool_class = PatchNames,
     options_class = PatchNamesOptions,
     modes = Tool.MODE_GUI,
-    translated_name = _("Extract information from names"),
-    status=(_("Stable")),
+    translated_name = _("Extract Information from Names"),
+    status = _("Stable"),
     author_name = "Donald N. Allingham",
     author_email = "don@gramps-project.org",
-    description=_("Searches the entire database and attempts to "
-                  "extract titles, nicknames and surname prefixes "
-                  "that may be embedded in a person's given name field.")
+    description = _("Searches the entire database and attempts to "
+                    "extract titles, nicknames and surname prefixes "
+                    "that may be embedded in a person's given name field.")
     )
