@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2003-2006  Donald N. Allingham
+# Copyright (C) 2003-2007 Donald N. Allingham
+# Copyright (C) 2007-2008 Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +19,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: TimeLine.py 7231 2006-08-22 05:28:55Z rshura $
+# $Id: TimeLine.py 10152 2008-03-01 22:47:48Z pez4brian $
 
 """
-Timeline report
+Timeline Chart
 """
 
 #------------------------------------------------------------------------
@@ -31,27 +32,32 @@ Timeline report
 #------------------------------------------------------------------------
 from TransUtils import sgettext as _
 
-#------------------------------------------------------------------------
-#
-# GNOME/gtk
-#
-#------------------------------------------------------------------------
-import gtk
-
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
 from PluginUtils import register_report
-from ReportBase import Report, ReportUtils, ReportOptions, \
+from PluginUtils import FilterOption, EnumeratedListOption, \
+    PersonOption
+from ReportBase import Report, ReportUtils, MenuReportOptions, \
      CATEGORY_DRAW, MODE_GUI, MODE_BKI, MODE_CLI
 pt2cm = ReportUtils.pt2cm
 import BaseDoc
-from Filters import GenericFilter, Rules
 import Sort
 from QuestionDialog import ErrorDialog
-import NameDisplay
+from BasicUtils import name_displayer
+
+#------------------------------------------------------------------------
+#
+# Private Functions
+#
+#------------------------------------------------------------------------
+def _get_sort_functions(sort):
+    return [
+        (_("Birth Date"),sort.by_birthdate),
+        (_("Name"),sort.by_last_name), 
+]
 
 #------------------------------------------------------------------------
 #
@@ -60,9 +66,9 @@ import NameDisplay
 #------------------------------------------------------------------------
 class TimeLine(Report):
 
-    def __init__(self,database,person,options_class):
+    def __init__(self, database, options_class):
         """
-        Creates the Timeline object that produces the report.
+        Create the Timeline object that produces the report.
         
         The arguments are:
 
@@ -76,91 +82,22 @@ class TimeLine(Report):
         filter    - Filter to be applied to the people of the database.
                     The option class carries its number, and the function
                     returning the list of filters.
-        sort_func - function used to sort entries, that returns -1/0/1
-                    when given two personal handles (like cmp).
-                    The option class carries its number, and the function
-                    returning the list of sort functions.
+        sortby -    Sorting method to be used.
         """
 
-        Report.__init__(self,database,person,options_class)
+        Report.__init__(self, database, options_class)
+        menu = options_class.menu
+        self.filter = menu.get_option_by_name('filter').get_filter()
 
-        filter_num = options_class.get_filter_number()
-        filters = options_class.get_report_filters(person)
-        self.filter = filters[filter_num]
+        self.title = _("Timeline Graph for %s") % self.filter.get_name()
 
-        name = NameDisplay.displayer.display_formal(person)
-        self.title = _("Timeline Graph for %s") % name
-
-        sort_func_num = options_class.handler.options_dict['sortby']
-        sort_functions = options_class.get_sort_functions(Sort.Sort(database))
+        sort_func_num = menu.get_option_by_name('sortby').get_value()
+        sort_functions = _get_sort_functions(Sort.Sort(database))
         self.sort_func = sort_functions[sort_func_num][1]
 
-    def define_graphics_styles(self):
-        """
-        Define the graphics styles used by the report. Paragraph definitions
-        have already been defined in the document. The styles used are:
-
-        TLG-grid  - 0.5pt wide line dashed line. Used for the lines that make up
-                the grid.
-        TLG-line  - 0.5pt wide line. Used for the line connecting two endpoints
-                and for the birth marker.
-        TLG-solid - 0.5pt line with a black fill color. Used for the date of
-                death marker.
-        TLG-text  - Contains the TLG-Name paragraph style used for the individual's
-                name
-        TLG-title - Contains the TLG-Title paragraph style used for the title of
-                the document
-        TLG-label - Contains the TLG-Label paragraph style used for the year label's
-                in the document.
-        """
-        g = BaseDoc.GraphicsStyle()
-        g.set_line_width(0.5)
-        g.set_color((0,0,0))
-        self.doc.add_draw_style("TLG-line",g)
-
-        g = BaseDoc.GraphicsStyle()
-        g.set_line_width(0.5)
-        g.set_color((0,0,0))
-        g.set_fill_color((0,0,0))
-        self.doc.add_draw_style("TLG-solid",g)
-
-        g = BaseDoc.GraphicsStyle()
-        g.set_line_width(0.5)
-        g.set_color((0,0,0))
-        g.set_fill_color((255,255,255))
-        self.doc.add_draw_style("open",g)
-
-        g = BaseDoc.GraphicsStyle()
-        g.set_line_width(0.5)
-        g.set_line_style(BaseDoc.DASHED)
-        g.set_color((0,0,0))
-        self.doc.add_draw_style("TLG-grid",g)
-
-        g = BaseDoc.GraphicsStyle()
-        g.set_paragraph_style("TLG-Name")
-        g.set_color((255,255,255))
-        g.set_fill_color((255,255,255))
-        g.set_line_width(0)
-        self.doc.add_draw_style("TLG-text",g)
-
-        g = BaseDoc.GraphicsStyle()
-        g.set_paragraph_style("TLG-Title")
-        g.set_color((255,255,255))
-        g.set_fill_color((255,255,255))
-        g.set_line_width(0)
-        g.set_width(self.doc.get_usable_width())
-        self.doc.add_draw_style("TLG-title",g)
-
-        g = BaseDoc.GraphicsStyle()
-        g.set_paragraph_style("TLG-Label")
-        g.set_color((255,255,255))
-        g.set_fill_color((255,255,255))
-        g.set_line_width(0)
-        self.doc.add_draw_style("TLG-label",g)
-
     def write_report(self):
 
-        (low,high) = self.find_year_range()
+        (low, high) = self.find_year_range()
 
         if low == high:
             if self.standalone:
@@ -171,7 +108,8 @@ class TimeLine(Report):
 
         st_size = self.name_size()
 
-        font = self.doc.style_list['TLG-Name'].get_font()
+        style_sheet = self.doc.get_style_sheet()
+        font = style_sheet.get_paragraph_style('TLG-Name').get_font()
         
         incr = pt2cm(font.get_size())
         pad =  incr*.75
@@ -194,22 +132,20 @@ class TimeLine(Report):
         
         for p_id in self.plist:
             p = self.database.get_person_from_handle(p_id)
-            b_ref = p.get_birth_ref()
-            if b_ref:
-                birth = self.database.get_event_from_handle(b_ref.ref)
+            birth = ReportUtils.get_birth_or_fallback(self.database, p)
+            if birth:
                 b = birth.get_date_object().get_year()
             else:
                 b = None
 
-            d_ref = p.get_death_ref()
-            if d_ref:
-                death = self.database.get_event_from_handle(d_ref.ref)
+            death = ReportUtils.get_death_or_fallback(self.database, p)
+            if death:
                 d = death.get_date_object().get_year()
             else:
                 d = None
 
-            n = p.get_primary_name().get_name()
-            self.doc.draw_text('TLG-text',n,incr+pad,self.header + (incr+pad)*index)
+            n = name_displayer.display_formal(p)
+            self.doc.draw_text('TLG-text', n,incr+pad,self.header + (incr+pad)*index)
             
             y1 = self.header + (pad+incr)*index
             y2 = self.header + ((pad+incr)*index)+incr
@@ -238,17 +174,17 @@ class TimeLine(Report):
 
             if (y2 + incr) >= self.doc.get_usable_height():
                 if current != length:
-                    self.build_grid(low,high,start,stop)
+                    self.build_grid(low, high,start,stop)
                     self.doc.end_page()
                     self.doc.start_page()
-                    self.build_grid(low,high,start,stop)
+                    self.build_grid(low, high,start,stop)
                 index = 1
                 x1,x2,y1,y2 = (0,0,0,0)
             else:
                 index += 1;
             current += 1
             
-        self.build_grid(low,high,start,stop)
+        self.build_grid(low, high,start,stop)
         self.doc.end_page()    
 
     def build_grid(self,year_low,year_high,start_pos,stop_pos):
@@ -264,9 +200,10 @@ class TimeLine(Report):
         """
         width = self.doc.get_usable_width()
 
-        title_font = self.doc.style_list['TLG-Title'].get_font()
-        normal_font = self.doc.style_list['TLG-Name'].get_font()
-        label_font = self.doc.style_list['TLG-Label'].get_font()
+        style_sheet = self.doc.get_style_sheet()
+        title_font = style_sheet.get_paragraph_style('TLG-Title').get_font()
+        normal_font = style_sheet.get_paragraph_style('TLG-Name').get_font()
+        label_font = style_sheet.get_paragraph_style('TLG-Label').get_font()
 
         self.doc.center_text('TLG-title',self.title,width/2.0,0)
         
@@ -293,16 +230,14 @@ class TimeLine(Report):
 
         for p_id in self.plist:
             p = self.database.get_person_from_handle(p_id)
-            b_ref = p.get_birth_ref()
-            if b_ref:
-                birth = self.database.get_event_from_handle(b_ref.ref)
+            birth = ReportUtils.get_birth_or_fallback(self.database, p)
+            if birth:
                 b = birth.get_date_object().get_year()
             else:
                 b = None
 
-            d_ref = p.get_death_ref()
-            if d_ref:
-                death = self.database.get_event_from_handle(d_ref.ref)
+            death = ReportUtils.get_death_or_fallback(self.database, p)
+            if death:
                 d = death.get_date_object().get_year()
             else:
                 d = None
@@ -328,63 +263,94 @@ class TimeLine(Report):
         if high == None:
             high = low
         
-        return (low,high)
+        return (low, high)
 
     def name_size(self):
         self.plist = self.filter.apply(self.database,
                                        self.database.get_person_handles(sort_handles=False))
 
-        style_name = self.doc.draw_styles['TLG-text'].get_paragraph_style()
-        font = self.doc.style_list[style_name].get_font()
+        style_sheet = self.doc.get_style_sheet()
+        gstyle = style_sheet.get_draw_style('TLG-text')
+        pname = gstyle.get_paragraph_style()
+        pstyle = style_sheet.get_paragraph_style(pname)
+        font = pstyle.get_font()
         
         size = 0
         for p_id in self.plist:
             p = self.database.get_person_from_handle(p_id)
-            n = p.get_primary_name().get_name()
-            size = max(self.doc.string_width(font,n),size)
+            n = name_displayer.display_formal(p)
+            size = max(self.doc.string_width(font, n),size)
         return pt2cm(size)
 
 #------------------------------------------------------------------------
 #
-# 
+# TimeLineOptions
 #
 #------------------------------------------------------------------------
-class TimeLineOptions(ReportOptions):
+class TimeLineOptions(MenuReportOptions):
 
-    """
-    Defines options and provides handling interface.
-    """
-
-    def __init__(self,name,person_id=None):
-        ReportOptions.__init__(self,name,person_id)
-
-    def set_new_options(self):
-        # Options specific for this report
-        self.options_dict = {
-            'sortby'    : 0,
-        }
-        self.options_help = {
-            'sortby'    : ("=num","Number of a sorting function",
-                            [item[0] for item in 
-                                    self.get_sort_functions(Sort.Sort(None))],
-                            True),
-        }
-
-    def enable_options(self):
-        # Semi-common options that should be enabled for this report
-        self.enable_dict = {
-            'filter'    : 0,
-        }
+    def __init__(self, name, dbase):
+        self.__pid = None
+        self.__filter = None
+        self.__db = dbase
+        MenuReportOptions.__init__(self, name, dbase)
+        
+    def add_menu_options(self, menu):
+        category_name = _("Report Options")
 
+        self.__filter = FilterOption(_("Filter"), 0)
+        self.__filter.set_help(
+                         _("Determines what people are included in the report"))
+        menu.add_option(category_name, "filter", self.__filter)
+        self.__filter.connect('value-changed', self.__filter_changed)
+        
+        self.__pid = PersonOption(_("Filter Person"))
+        self.__pid.set_help(_("The center person for the filter"))
+        menu.add_option(category_name, "pid", self.__pid)
+        self.__pid.connect('value-changed', self.__update_filters)
+        
+        self.__update_filters()
+        
+        sortby = EnumeratedListOption(_('Sort by'), 0 )
+        idx = 0
+        for item in _get_sort_functions(Sort.Sort(self.__db)):
+            sortby.add_item(idx,item[0])
+            idx += 1
+        sortby.set_help( _("Sorting method to use"))
+        menu.add_option(category_name,"sortby",sortby)
+        
+    def __update_filters(self):
+        """
+        Update the filter list based on the selected person
+        """
+        gid = self.__pid.get_value()
+        person = self.__db.get_person_from_gramps_id(gid)
+        filter_list = ReportUtils.get_person_filters(person, False)
+        self.__filter.set_filters(filter_list)
+        
+    def __filter_changed(self):
+        """
+        Handle filter change. If the filter is not specific to a person,
+        disable the person option
+        """
+        filter_value = self.__filter.get_value()
+        if filter_value in [1, 2, 3, 4]:
+            # Filters 1, 2, 3 and 4 rely on the center person
+            self.__pid.set_available(True)
+        else:
+            # The rest don't
+            self.__pid.set_available(False)
+        
     def make_default_style(self,default_style):
         """Make the default output style for the Timeline report."""
+        # Paragraph Styles
         f = BaseDoc.FontStyle()
         f.set_size(10)
         f.set_type_face(BaseDoc.FONT_SANS_SERIF)
         p = BaseDoc.ParagraphStyle()
         p.set_font(f)
         p.set_description(_("The style used for the person's name."))
-        default_style.add_style("TLG-Name",p)
+        default_style.add_paragraph_style("TLG-Name",p)
 
         f = BaseDoc.FontStyle()
         f.set_size(8)
@@ -393,7 +359,7 @@ class TimeLineOptions(ReportOptions):
         p.set_font(f)
         p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
         p.set_description(_("The style used for the year labels."))
-        default_style.add_style("TLG-Label",p)
+        default_style.add_paragraph_style("TLG-Label",p)
 
         f = BaseDoc.FontStyle()
         f.set_size(14)
@@ -402,65 +368,66 @@ class TimeLineOptions(ReportOptions):
         p.set_font(f)
         p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
         p.set_description(_("The style used for the title of the page."))
-        default_style.add_style("TLG-Title",p)
-    
-    def get_report_filters(self,person):
-        """Set up the list of possible content filters."""
-        if person:
-            name = person.get_primary_name().get_name()
-            gramps_id = person.get_gramps_id()
-        else:
-            name = 'PERSON'
-            gramps_id = ''
-
-        all = GenericFilter()
-        all.set_name(_("Entire Database"))
-        all.add_rule(Rules.Person.Everyone([]))
-
-        des = GenericFilter()
-        des.set_name(_("Descendants of %s") % name)
-        des.add_rule(Rules.Person.IsDescendantOf([gramps_id,1]))
-
-        ans = GenericFilter()
-        ans.set_name(_("Ancestors of %s") % name)
-        ans.add_rule(Rules.Person.IsAncestorOf([gramps_id,1]))
-
-        com = GenericFilter()
-        com.set_name(_("People with common ancestor with %s") % name)
-        com.add_rule(Rules.Person.HasCommonAncestorWith([gramps_id]))
-
-        the_filters = [all,des,ans,com]
-        from Filters import CustomFilters
-        the_filters.extend(CustomFilters.get_filters('Person'))
-        return the_filters
-
-    def get_sort_functions(self,sort):
-        return [
-            (_("Birth Date"),sort.by_birthdate),
-            (_("Name"),sort.by_last_name), 
-        ]
-
-    def add_user_options(self,dialog):
-        """
-        Override the base class add_user_options task to add a menu that allows
-        the user to select the sort method.
-        """
+        default_style.add_paragraph_style("TLG-Title",p)
         
-        self.sort_menu = gtk.combo_box_new_text()
-
-        sort_functions = self.get_sort_functions(Sort.Sort(dialog.db))
-        for item in sort_functions:
-            self.sort_menu.append_text(item[0])
-
-        self.sort_menu.set_active(self.options_dict['sortby'])
-
-        dialog.add_option(_('Sort by'),self.sort_menu)
-
-    def parse_user_options(self,dialog):
         """
-        Parses the custom options that we have added.
+        Graphic Styles
+            TLG-grid  - 0.5pt wide line dashed line. Used for the lines that 
+                        make up the grid.
+            TLG-line  - 0.5pt wide line. Used for the line connecting two 
+                        endpoints and for the birth marker.
+            TLG-solid - 0.5pt line with a black fill color. Used for the date of
+                        death marker.
+            TLG-text  - Contains the TLG-Name paragraph style used for the 
+                        individual's name.
+            TLG-title - Contains the TLG-Title paragraph style used for the
+                        title of the document.
+            TLG-label - Contains the TLG-Label paragraph style used for the year
+                        label's in the document.
         """
-        self.options_dict['sortby'] = self.sort_menu.get_active()
+        g = BaseDoc.GraphicsStyle()
+        g.set_line_width(0.5)
+        g.set_color((0,0,0))
+        default_style.add_draw_style("TLG-line",g)
+
+        g = BaseDoc.GraphicsStyle()
+        g.set_line_width(0.5)
+        g.set_color((0,0,0))
+        g.set_fill_color((0,0,0))
+        default_style.add_draw_style("TLG-solid",g)
+
+        g = BaseDoc.GraphicsStyle()
+        g.set_line_width(0.5)
+        g.set_color((0,0,0))
+        g.set_fill_color((255,255,255))
+        default_style.add_draw_style("open",g)
+
+        g = BaseDoc.GraphicsStyle()
+        g.set_line_width(0.5)
+        g.set_line_style(BaseDoc.DASHED)
+        g.set_color((0,0,0))
+        default_style.add_draw_style("TLG-grid",g)
+
+        g = BaseDoc.GraphicsStyle()
+        g.set_paragraph_style("TLG-Name")
+        g.set_color((0,0,0))
+        g.set_fill_color((255,255,255))
+        g.set_line_width(0)
+        default_style.add_draw_style("TLG-text",g)
+
+        g = BaseDoc.GraphicsStyle()
+        g.set_paragraph_style("TLG-Title")
+        g.set_color((0,0,0))
+        g.set_fill_color((255,255,255))
+        g.set_line_width(0)
+        default_style.add_draw_style("TLG-title",g)
+
+        g = BaseDoc.GraphicsStyle()
+        g.set_paragraph_style("TLG-Label")
+        g.set_color((0,0,0))
+        g.set_fill_color((255,255,255))
+        g.set_line_width(0)
+        default_style.add_draw_style("TLG-label",g)
 
 #------------------------------------------------------------------------
 #
@@ -473,9 +440,9 @@ register_report(
     report_class = TimeLine,
     options_class = TimeLineOptions,
     modes = MODE_GUI | MODE_BKI | MODE_CLI,
-    translated_name = _("Timeline Graph"),
+    translated_name = _("Timeline Chart"),
     status = _("Stable"),
     author_name = "Donald N. Allingham",
     author_email = "don@gramps-project.org",
-    description = _("Generates a timeline graph.")
+    description = _("Produces a timeline chart.")
     )
