@@ -2,7 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2004  Martin Hawlisch
-# Copyright (C) 2004-2006 Donald N. Allingham
+# Copyright (C) 2004-2006, 2008 Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: WriteGeneWeb.py 7391 2006-10-11 04:59:26Z rshura $
+# $Id:WriteGeneWeb.py 9912 2008-01-22 09:17:46Z acraphae $
 
-"Export to GeneWeb"
+"Export to GeneWeb."
 
 #-------------------------------------------------------------------------
 #
@@ -35,8 +35,7 @@ from gettext import gettext as _
 # GNOME/GTK modules
 #
 #-------------------------------------------------------------------------
-import gtk
-import gtk.glade
+from gtk import glade
 
 #------------------------------------------------------------------------
 #
@@ -51,9 +50,9 @@ log = logging.getLogger(".WriteGeneWeb")
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import RelLib
+import gen.lib
 from Filters import GenericFilter, Rules, build_filter_menu
-import const
+#import const
 import Utils
 import Errors
 from QuestionDialog import ErrorDialog
@@ -67,9 +66,10 @@ from PluginUtils import register_export
 class GeneWebWriterOptionBox:
     """
     Create a VBox with the option widgets and define methods to retrieve
-    the options. 
+    the options.
+     
     """
-    def __init__(self,person):
+    def __init__(self, person):
         self.person = person
 
     def get_option_box(self):
@@ -80,7 +80,7 @@ class GeneWebWriterOptionBox:
         if not os.path.isfile(glade_file):
             glade_file = "plugins/genewebexport.glade"
 
-        self.topDialog = gtk.glade.XML(glade_file,"genewebExport","gramps")
+        self.topDialog = glade.XML(glade_file, "genewebExport", "gramps")
         self.topDialog.signal_autoconnect({
                 "on_restrict_toggled": self.on_restrict_toggled
                 })
@@ -113,7 +113,7 @@ class GeneWebWriterOptionBox:
             com.add_rule(Rules.Person.HasCommonAncestorWith(
                 [self.person.get_gramps_id()]))
 
-            the_filters += [all,des,ans,com]
+            the_filters += [des, ans, com]
 
         from Filters import CustomFilters
         the_filters.extend(CustomFilters.get_filters('Person'))
@@ -126,7 +126,7 @@ class GeneWebWriterOptionBox:
         self.topDialog.get_widget("genewebExport").destroy()
         return the_box
 
-    def on_restrict_toggled(self,restrict):
+    def on_restrict_toggled(self, restrict):
         active = restrict.get_active ()
         map (lambda x: x.set_sensitive (active),
              [self.topDialog.get_widget("living"),
@@ -153,8 +153,8 @@ class GeneWebWriterOptionBox:
             self.images_path = ""
 
 class GeneWebWriter:
-    def __init__(self,database,person,cl=0,filename="",
-                 option_box=None,callback=None):
+    def __init__(self, database, person, cl=0, filename="", option_box=None, 
+                 callback=None):
         self.db = database
         self.person = person
         self.option_box = option_box
@@ -195,8 +195,8 @@ class GeneWebWriter:
                     for p in self.option_box.cfilter.apply(self.db, self.db.get_person_handles(sort_handles=False)):
                         self.plist[p] = 1
                 except Errors.FilterError, msg:
-                    (m1,m2) = msg.messages()
-                    ErrorDialog(m1,m2)
+                    (m1, m2) = msg.messages()
+                    ErrorDialog(m1, m2)
                     return
 
             self.flist = {}
@@ -244,25 +244,25 @@ class GeneWebWriter:
             for family_handle in p.get_family_handle_list():
                 self.flist[family_handle] = 1
 
-    def writeln(self,text):
+    def writeln(self, text):
         self.g.write(self.iso8859('%s\n' % (text)))
 
     def export_data(self):
 
         self.dirname = os.path.dirname (self.filename)
         try:
-            self.g = open(self.filename,"w")
+            self.g = open(self.filename, "w")
         except IOError,msg:
             msg2 = _("Could not create %s") % self.filename
-            ErrorDialog(msg2,str(msg))
-            return 0
+            ErrorDialog(msg2, str(msg))
+            return False
         except:
             ErrorDialog(_("Could not create %s") % self.filename)
-            return 0
+            return False
 
         if len(self.flist) < 1:
             ErrorDialog(_("No families matched by selected filter"))
-            return 0
+            return False
         
         self.count = 0
         self.oldval = 0
@@ -272,9 +272,9 @@ class GeneWebWriter:
             self.writeln("")
         
         self.g.close()
-        return 1
+        return True
     
-    def write_family(self,family_handle):
+    def write_family(self, family_handle):
         family = self.db.get_family_from_handle(family_handle)
         if family:
             self.update()
@@ -290,7 +290,12 @@ class GeneWebWriter:
                     self.write_children( family, father)
                     self.write_notes( family, father, mother)
                     if not (self.restrict and self.exclnotes):
-                        note = family.get_note()
+                        notelist = family.get_note_list()
+                        note = ""
+                        for notehandle in notelist:
+                            noteobj = self.db.get_note_from_handle(notehandle)
+                            note += noteobj.get(False)
+                            note += " "
                         if note and note != "":
                             note = note.replace('\n\r',' ')
                             note = note.replace('\r\n',' ')
@@ -298,7 +303,7 @@ class GeneWebWriter:
                             note = note.replace('\r',' ')
                             self.writeln("comm %s" % note)
                     
-    def write_witness(self,family):
+    def write_witness(self, family):
         # FIXME: witnesses are not in events anymore
         return
         
@@ -307,17 +312,17 @@ class GeneWebWriter:
         event_ref_list = family.get_event_ref_list()
         for event_ref in event_ref:
             event = self.db.get_event_from_handle(event_ref.ref)
-            if int(event.get_type()) == RelLib.EventType.MARRIAGE:
+            if int(event.get_type()) == gen.lib.EventType.MARRIAGE:
                 w_list = event.get_witness_list()
                 if w_list:
                     for witness in w_list:
-                        if witness and witness.type == RelLib.Event.ID:
+                        if witness and witness.type == gen.lib.Event.ID:
                             person = self.db.get_person_from_handle(witness.get_value())
                             if person:
                                 gender = ""
-                                if person.get_gender() == RelLib.Person.MALE:
+                                if person.get_gender() == gen.lib.Person.MALE:
                                     gender = "h"
-                                elif person.get_gender() == RelLib.Person.FEMALE:
+                                elif person.get_gender() == gen.lib.Person.FEMALE:
                                     gender = "f"
                                 self.writeln("wit %s %s %s" % (gender, self.get_ref_name(person), self.get_full_person_info_fam(person)))
                             
@@ -327,7 +332,7 @@ class GeneWebWriter:
             return
             
         if reflist:
-           for sr in reflist:
+            for sr in reflist:
                 sbase = sr.get_reference_handle()
                 if sbase:
                     source = self.db.get_source_from_handle(sbase)
@@ -343,9 +348,9 @@ class GeneWebWriter:
                 child = self.db.get_person_from_handle(child_ref.ref)
                 if child:
                     gender = ""
-                    if child.get_gender() == RelLib.Person.MALE:
+                    if child.get_gender() == gen.lib.Person.MALE:
                         gender = "h"
-                    elif child.get_gender() == RelLib.Person.FEMALE:
+                    elif child.get_gender() == gen.lib.Person.FEMALE:
                         gender = "f"
                     self.writeln("- %s %s %s" % (gender, self.get_child_ref_name(child, father_lastname), self.get_full_person_info_child(child)))
             self.writeln("end")
@@ -366,11 +371,11 @@ class GeneWebWriter:
 ##         event_ref_list = family.get_event_ref_list()
 ##         for event_ref in event_ref_list:
 ##             event = self.db.get_event_from_handle(event_ref.ref)
-##             if int(event.get_type()) == RelLib.EventType.MARRIAGE:
+##             if int(event.get_type()) == gen.lib.EventType.MARRIAGE:
 ##                 w_list = event.get_witness_list()
 ##                 if w_list:
 ##                     for witness in w_list:
-##                         if witness and witness.type == RelLib.Event.ID:
+##                         if witness and witness.type == gen.lib.Event.ID:
 ##                             person = self.db.get_person_from_handle(witness.get_value())
 ##                             if person:
 ##                                 self.write_note_of_person(person)
@@ -378,7 +383,14 @@ class GeneWebWriter:
     def write_note_of_person(self,person):
         if self.persons_notes_done.count(person.get_handle()) == 0:
             self.persons_notes_done.append(person.get_handle())
-            note = person.get_note()
+            
+            notelist = person.get_note_list()
+            note = ""
+            for notehandle in notelist:
+                noteobj = self.db.get_note_from_handle(notehandle)
+                note += noteobj.get(False)
+                note += " "
+
             if note and note != "":
                 self.writeln("")
                 self.writeln("notes %s" % self.get_ref_name(person))
@@ -428,7 +440,11 @@ class GeneWebWriter:
         return retval
 
     def get_full_person_info_fam(self, person):
-        """Output full person data of a family member only if the person is not listed as a child"""
+        """Output full person data of a family member.
+        
+        This is only done if the person is not listed as a child.
+         
+        """
         retval = ""
         if self.persons_details_done.count(person.get_handle()) == 0:
             is_child = 0
@@ -444,7 +460,7 @@ class GeneWebWriter:
                     
 
     def get_full_person_info_child(self, person):
-        """Output full person data for a child, if not printed somewhere else"""
+        """Output full person data for a child, if not printed somewhere else."""
         retval = ""
         if self.persons_details_done.count(person.get_handle()) == 0:
             self.persons_details_done.append(person.get_handle())
@@ -456,7 +472,7 @@ class GeneWebWriter:
     
     def get_ref_name(self,person):
         surname = self.rem_spaces( person.get_primary_name().get_surname())
-        firstname = "Living"
+        firstname = _("Living")
         if not (Utils.probably_alive(person,self.db) and self.restrict and self.living):
             firstname = self.rem_spaces( person.get_primary_name().get_first_name())
         if not self.person_ids.has_key(person.get_handle()):
@@ -466,7 +482,7 @@ class GeneWebWriter:
 
     def get_child_ref_name(self,person,father_lastname):
         surname = self.rem_spaces( person.get_primary_name().get_surname())
-        firstname = "Living"
+        firstname = _("Living")
         if not (Utils.probably_alive(person,self.db) and self.restrict and self.living):
             firstname = self.rem_spaces( person.get_primary_name().get_first_name())
         if not self.person_ids.has_key(person.get_handle()):
@@ -492,7 +508,7 @@ class GeneWebWriter:
         divorced = 0
         for event_ref in event_ref_list:
             event = self.db.get_event_from_handle(event_ref.ref)
-            if event.get_type() == RelLib.EventType.MARRIAGE:
+            if event.get_type() == gen.lib.EventType.MARRIAGE:
                 married = 1
                 m_date = self.format_date( event.get_date_object())
                 place_handle = event.get_place_handle()
@@ -500,7 +516,7 @@ class GeneWebWriter:
                     place = self.db.get_place_from_handle(place_handle)
                     m_place = place.get_title()
                 m_source = self.get_primary_source( event.get_source_references())
-            if event.get_type() == RelLib.EventType.ENGAGEMENT:
+            if event.get_type() == gen.lib.EventType.ENGAGEMENT:
                 engaged = 1
                 eng_date = self.format_date( event.get_date_object())
                 place_handle = event.get_place_handle()
@@ -508,7 +524,7 @@ class GeneWebWriter:
                     place = self.db.get_place_from_handle(place_handle)
                     eng_place = place.get_title()
                 eng_source = self.get_primary_source( event.get_source_references())
-            if event.get_type() == RelLib.EventType.DIVORCE:
+            if event.get_type() == gen.lib.EventType.DIVORCE:
                 divorced = 1
                 div_date = self.format_date( event.get_date_object())
         if married == 1:
@@ -533,7 +549,7 @@ class GeneWebWriter:
             if eng_source != "":
                 ret = ret + "#ms %s " % self.rem_spaces( m_source)
         else:
-            if family.get_relationship() != RelLib.FamilyRelType.MARRIED:
+            if family.get_relationship() != gen.lib.FamilyRelType.MARRIED:
                 """Not married or engaged"""
                 ret = ret + " #nm "
 
@@ -558,24 +574,24 @@ class GeneWebWriter:
                         ret = ret + source.get_title()
         return ret
     
-    def format_single_date(self,subdate,cal,mode):
+    def format_single_date(self, subdate, cal, mode):
         retval = ""
-        (day,month,year,sl) = subdate
+        (day, month, year, sl) = subdate
         
         cal_type = ""
-        if cal == RelLib.Date.CAL_HEBREW:
+        if cal == gen.lib.Date.CAL_HEBREW:
             cal_type = "H"
-        elif cal == RelLib.Date.CAL_FRENCH:
+        elif cal == gen.lib.Date.CAL_FRENCH:
             cal_type = "F"
-        elif cal == RelLib.Date.CAL_JULIAN:
+        elif cal == gen.lib.Date.CAL_JULIAN:
             cal_type = "J"
         
         mode_prefix = ""
-        if mode == RelLib.Date.MOD_ABOUT:
+        if mode == gen.lib.Date.MOD_ABOUT:
             mode_prefix = "~"
-        elif mode == RelLib.Date.MOD_BEFORE:
+        elif mode == gen.lib.Date.MOD_BEFORE:
             mode_prefix = "<"
-        elif mode == RelLib.Date.MOD_AFTER:
+        elif mode == gen.lib.Date.MOD_AFTER:
             mode_prefix = ">"
             
         if year > 0:
@@ -591,14 +607,12 @@ class GeneWebWriter:
     
     def format_date(self,date):
         retval = ""
-        
-        strval = date.get_text()
-        if strval:
-            retval = "0(%s)" % self.rem_spaces(strval)
+        if date.get_modifier() == gen.lib.Date.MOD_TEXTONLY:
+            retval = "0(%s)" % self.rem_spaces(date.get_text())
         elif not date.is_empty():
             mod = date.get_modifier()
             cal = cal = date.get_calendar()
-            if mod == RelLib.Date.MOD_SPAN or mod == RelLib.Date.MOD_RANGE:
+            if mod == gen.lib.Date.MOD_SPAN or mod == gen.lib.Date.MOD_RANGE:
                 retval = "%s..%s" % (
                     self.format_single_date(date.get_start_date(), cal,mod),
                     self.format_single_date(date.get_stop_date(),cal,mod))
@@ -614,20 +628,18 @@ class GeneWebWriter:
 #
 #
 #-------------------------------------------------------------------------
-def exportData(database,filename,person,option_box,callback=None):
-    ret = 0
-    gw = GeneWebWriter(database,person,0,filename,option_box,callback)
-    ret = gw.export_data()
-    return ret
+def exportData(database,filename,person, option_box,callback=None):
+    gw = GeneWebWriter(database,person,0,filename, option_box,callback)
+    return gw.export_data()
 
 #-------------------------------------------------------------------------
 #
 #
 #
 #-------------------------------------------------------------------------
-_title = _('G_eneWeb')
+_title = _('_GeneWeb')
 _description = _('GeneWeb is a web based genealogy program.')
-_config = (_('GeneWeb export options'),GeneWebWriterOptionBox)
+_config = (_('GeneWeb export options'), GeneWebWriterOptionBox)
 _filename = 'gw'
 
-register_export(exportData,_title,_description,_config,_filename)
+register_export(exportData, _title, _description, _config, _filename)
