@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: rel_fi.py,v 1.5.2.1 2005/06/23 03:09:56 rshura Exp $
+# $Id: rel_fi.py 10103 2008-02-24 13:55:55Z acraphae $
 
 # Written by Alex Roitman, largely based on Relationship.py by Don Allingham
 # and on valuable input from Eero Tamminen
@@ -30,10 +30,10 @@
 #
 #-------------------------------------------------------------------------
 
-import RelLib
+import gen.lib
 import Relationship
 import types
-from gettext import gettext as _
+from PluginUtils import register_relcalc
 
 #-------------------------------------------------------------------------
 #
@@ -51,8 +51,8 @@ _parents_level = [ "", "vanhemmat", "isovanhemmat", "isoisovanhemmat",
 #-------------------------------------------------------------------------
 class RelationshipCalculator(Relationship.RelationshipCalculator):
 
-    def __init__(self,db):
-        Relationship.RelationshipCalculator.__init__(self,db)
+    def __init__(self):
+        Relationship.RelationshipCalculator.__init__(self)
 
     def get_cousin(self,level):
         if level == 0:
@@ -87,7 +87,7 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
                 result.append('isän')
             else:
                 result.append('äidin')
-        if person.get_gender() == RelLib.Person.MALE:
+        if person.get_gender() == gen.lib.Person.MALE:
             result.append('isä')
         else:
             result.append('äiti')
@@ -102,9 +102,9 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
                 result.append('tyttären')
             else:
                 result.append('lapsen')
-        if person.get_gender() == RelLib.Person.MALE:
+        if person.get_gender() == gen.lib.Person.MALE:
             result.append('poika')
-        elif person.get_gender() == RelLib.Person.FEMALE:
+        elif person.get_gender() == gen.lib.Person.FEMALE:
             result.append('tytär')
         else:
             result.append('lapsi')
@@ -139,9 +139,9 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
                 result.append('tyttären')
             else:
                 result.append('lapsen')
-        if person.get_gender() == RelLib.Person.MALE:
+        if person.get_gender() == gen.lib.Person.MALE:
             result.append('poika')
-        elif person.get_gender() == RelLib.Person.FEMALE:
+        elif person.get_gender() == gen.lib.Person.FEMALE:
             result.append('tytär')
         else:
             result.append('lapsi')
@@ -168,9 +168,9 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         return ' '.join(result)
 
 
-    def get_relationship(self,orig_person,other_person):
+    def get_relationship(self,db, orig_person, other_person):
         """
-        Returns a string representing the relationshp between the two people,
+        Return a string representing the relationshp between the two people,
         along with a list of common ancestors (typically father,mother) 
         
         Special cases: relation strings "", "undefined" and "spouse".
@@ -182,13 +182,17 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         if orig_person.get_handle() == other_person.get_handle():
             return ('', [])
 
-        is_spouse = self.is_spouse(orig_person,other_person)
+        is_spouse = self.is_spouse(db, orig_person, other_person)
         if is_spouse:
             return (is_spouse,[])
 
-        (firstRel,secondRel,common) = self.get_relationship_distance(orig_person,other_person)
+        #get_relationship_distance changed, first data is relation to 
+        #orig person, apperently secondRel in this function
+        (secondRel,firstRel,common) = \
+                     self.get_relationship_distance(db, orig_person, other_person)
 
-        if type(common) == types.StringType or type(common) == types.UnicodeType:
+        if type(common) == types.StringType or \
+           type(common) == types.UnicodeType:
             return (common,[])
         elif common:
             person_handle = common[0]
@@ -203,7 +207,7 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         elif not secondRel:
             return (self.get_direct_descendant(other_person,firstRel),common)
         elif len(firstRel) == 1:
-            if other_person.get_gender() == RelLib.Person.MALE:
+            if other_person.get_gender() == gen.lib.Person.MALE:
                 return (self.get_ancestors_brother(secondRel),common)
             else:
                 return (self.get_ancestors_sister(secondRel),common)
@@ -217,8 +221,6 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
 # Register this class with the Plugins system 
 #
 #-------------------------------------------------------------------------
-from PluginMgr import register_relcalc
-
 register_relcalc(RelationshipCalculator,
     ["fi","FI","fi_FI","finnish","Finnish","fi_FI.UTF8","fi_FI@euro","fi_FI.UTF8@euro",
             "suomi","Suomi", "fi_FI.UTF-8", "fi_FI.utf-8", "fi_FI.utf8"])
