@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: rel_ru.py 6133 2006-03-11 01:12:06Z rshura $
+# $Id:rel_ru.py 9912 2008-01-22 09:17:46Z acraphae $
 
 # Written by Alex Roitman, largely based on Relationship.py by Don Allingham.
 
@@ -29,7 +29,7 @@
 #
 #-------------------------------------------------------------------------
 
-import RelLib
+import gen.lib
 import Relationship
 import types
 from PluginUtils import register_relcalc
@@ -112,8 +112,8 @@ _niece_level = [
 #-------------------------------------------------------------------------
 class RelationshipCalculator(Relationship.RelationshipCalculator):
 
-    def __init__(self,db):
-        Relationship.RelationshipCalculator.__init__(self,db)
+    def __init__(self):
+        Relationship.RelationshipCalculator.__init__(self)
 
     def get_parents(self,level):
         if level>len(_parents_level)-1:
@@ -193,9 +193,9 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         else:
             return _niece_level[level]
 
-    def get_relationship(self,orig_person,other_person):
+    def get_relationship(self,db, orig_person, other_person):
         """
-        Returns a string representing the relationshp between the two people,
+        Return a string representing the relationshp between the two people,
         along with a list of common ancestors (typically father,mother) 
         
         Special cases: relation strings "", "undefined" and "spouse".
@@ -207,13 +207,17 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         if orig_person.get_handle() == other_person.get_handle():
             return ('', [])
 
-        is_spouse = self.is_spouse(orig_person,other_person)
+        is_spouse = self.is_spouse(db, orig_person, other_person)
         if is_spouse:
             return (is_spouse,[])
 
-        (firstRel,secondRel,common) = self.get_relationship_distance(orig_person,other_person)
+        #get_relationship_distance changed, first data is relation to 
+        #orig person, apperently secondRel in this function
+        (secondRel,firstRel,common) = \
+                     self.get_relationship_distance(db, orig_person, other_person)
         
-        if type(common) == types.StringType or type(common) == types.UnicodeType:
+        if type(common) == types.StringType or \
+           type(common) == types.UnicodeType:
             return (common,[])
         elif common:
             person_handle = common[0]
@@ -226,32 +230,32 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         if firstRel == 0:
             if secondRel == 0:
                 return ('',common)
-            elif other_person.get_gender() == RelLib.Person.MALE:
+            elif other_person.get_gender() == gen.lib.Person.MALE:
                 return (self.get_father(secondRel),common)
             else:
                 return (self.get_mother(secondRel),common)
         elif secondRel == 0:
-            if other_person.get_gender() == RelLib.Person.MALE:
+            if other_person.get_gender() == gen.lib.Person.MALE:
                 return (self.get_son(firstRel),common)
             else:
                 return (self.get_daughter(firstRel),common)
         elif firstRel == 1:
-            if other_person.get_gender() == RelLib.Person.MALE:
+            if other_person.get_gender() == gen.lib.Person.MALE:
                 return (self.get_uncle(secondRel),common)
             else:
                 return (self.get_aunt(secondRel),common)
         elif secondRel == 1:
-            if other_person.get_gender() == RelLib.Person.MALE:
+            if other_person.get_gender() == gen.lib.Person.MALE:
                 return (self.get_nephew(firstRel-1),common)
             else:
                 return (self.get_niece(firstRel-1),common)
         elif secondRel > firstRel:
-            if other_person.get_gender() == RelLib.Person.MALE:
+            if other_person.get_gender() == gen.lib.Person.MALE:
                 return (self.get_senior_male_cousin(firstRel-1,secondRel-firstRel),common)
             else:
                 return (self.get_senior_female_cousin(firstRel-1,secondRel-firstRel),common)
         else:
-            if other_person.get_gender() == RelLib.Person.MALE:
+            if other_person.get_gender() == gen.lib.Person.MALE:
                 return (self.get_junior_male_cousin(secondRel-1,firstRel-secondRel),common)
             else:
                 return (self.get_junior_female_cousin(secondRel-1,firstRel-secondRel),common)
